clear
set more off

cd "Wave III"

***WHO software sometimes has a problem being rerun and will say "variable __00000`x'" can't be found
***This refers to a local within the program which is calling a variable that does in fact exist
***If stata is closed and reopened, this problem disappears

/*In this file, data in the files T_IM1TYPE, T, and T_IM13 from the section of the survey 'Book 1D: Children 0-36 Months' and the WHO igrowup macro to determine the following variables:
imm_age_complete:				whether or not immunizations complete for given age
imm_total_complete:			whether or not total package of immunizations received
imm_total_comp10month:			whether or not total package of immunizations received in children at least 10 months of age
z_weightforage:				z-score for weight-for-age measure
z_heightforage:				z-score for height-for-age measure
z_weightforheight:			z-score for weight-for-height measure
notmal_weightforage:			whether child is not malnourished by weight-for-age measure
mal_weightforage:				whether child is malnourished (<2SD)by weight-for-age measure
severe_weightforage:			whether child is severely malnourished (<3SD) by weight-for-age measure
notmal_heightforage:			whether child is not malnourished by height-for-age measure
mal_heightforage:				whether child is malnourished (<2SD)by height-for-age measure
severe_heightforage:			whether child is severely malnourished (<3SD) by height-for-age measure
notmal_weightforheight:			whether child is not malnourished by weight-for-height measure
mal_weightforheight:			whether child is malnourished (<2SD) by weight-for-height measure
severe_weightforheight:			whether child is severely malnourished (<3SD) by weight-for-height measure
weigh_last_calendarmonth:		whehter or not child was weighed in the current or previous calendar month
visit_and_weigh_lastmonth:		whether or not the child visited a health post and was weighed in the last month (last 30.4375 days)
times_weighed_last2months:		total number of times the child was weighed in the last two months
vitA_total:					total number of times the child received vitamin A
vitA_dummy:					whether or not the child is receiving vitamin A at the rate of at least 2 per year from age 6 months to 5 years
vitA_opp:					total number of times the child had the opportunity to receive vitamin A via the 2x year official distributions
vitA_uptak_percent:			the rate of uptak of vitamin A from the official distributions (vitA_total/vitA_opp)

imm_uptak_pct_23mons_all 	percent of immunizations received which should have up to 11 months (actually everything should be gotten by 9 months), kids 23 months and below; includes all immunizations in numerator
imm_uptak_diff_23mons_all 	difference in number of immunizations received and should have received by age, kids 23 months and below; includes all immunizations in numerator
imm_uptak_pct_23mons		percent of immunizations received which should have up to 11 months (actually everything should be gotten by 9 months), kids 23 months and below; includes only age required immunizations in numerator
imm_uptak_diff_23mons 		difference in number of immunizations received and should have received by age, kids 23 months and below; includes only age required immunizations in numerator

times_weighed_last3months		total number of times child was weighed in the last two months (using POS05 & POS07)
vitA_total_6mons_2years			number of vitamin A supplements received, for all kids above 6 months and below age 2*/

//Load relevant variables from data set
use Data\T_IM1TYPE


keep tid tim1type tim07 tim09 tim09_dd tim09_mm tim09_yy

//Condense immunization info to single line per id
reshape wide tim07 tim09 tim09_dd tim09_mm tim09_yy, i(tid) j(tim1type)
drop tim0713 tim0714 tim0715 *13 *14 *15
**Not counting hepb_4 since not included in wave1 count


//Rename immunizations more clearly and recode Tidaks from 3 to 0
rename tim071 bcg
rename tim072 polio_1
rename tim073 polio_2
rename tim074 polio_3
rename tim075 polio_4
rename tim076 dpt_1
rename tim077 dpt_2
rename tim078 dpt_3
rename tim079 measles
rename tim0710 hepb_1
rename tim0711 hepb_2
rename tim0712 hepb_3
foreach x of var bcg polio_1 polio_2 polio_3 polio_4 dpt_1 dpt_2 dpt_3 measles hepb_1 hepb_2 hepb_3{
replace `x'=0 if `x'==3
}

gen num_imm_true_miss = 0
foreach x of var bcg polio_1 polio_2 polio_3 polio_4 dpt_1 dpt_2 dpt_3 measles hepb_1 hepb_2 hepb_3{
replace num_imm_true_miss = num_imm_true_miss + 1 if `x' == 8
}

gen num_imm_receive = 0
foreach x of var bcg polio_1 polio_2 polio_3 polio_4 dpt_1 dpt_2 dpt_3 measles hepb_1 hepb_2 hepb_3{
replace num_imm_receive=num_imm_receive + 1 if `x'==1
}

gen get_bcg 	= mdy(tim09_mm1, tim09_dd1, tim09_yy1)
gen get_polio_1 = mdy(tim09_mm2, tim09_dd2, tim09_yy2)
gen get_polio_2 = mdy(tim09_mm3, tim09_dd3, tim09_yy3)
gen get_polio_3 = mdy(tim09_mm4, tim09_dd4, tim09_yy4)
gen get_polio_4 = mdy(tim09_mm5, tim09_dd5, tim09_yy5)
gen get_dpt_1 	= mdy(tim09_mm6, tim09_dd6, tim09_yy6)
gen get_dpt_2 	= mdy(tim09_mm7, tim09_dd7, tim09_yy7)
gen get_dpt_3 	= mdy(tim09_mm8, tim09_dd8, tim09_yy8)
gen get_measles = mdy(tim09_mm9, tim09_dd9, tim09_yy9)
gen get_hepb_1 	= mdy(tim09_mm10, tim09_dd10, tim09_yy10)
gen get_hepb_2 	= mdy(tim09_mm11, tim09_dd11, tim09_yy11)
gen get_hepb_3 	= mdy(tim09_mm12, tim09_dd12, tim09_yy12)

drop tim09*

sort tid
tempfile temp1
save `temp1'
clear



//Load relevant variables from data set
use Data\T

duplicates drop

duplicates drop tid, force

gen panel_2007 = (tcov3 == 1)
gen panel_2008 = (tcov3 == 2)


//Replace missing days with 15 if neither month nor year values for children's birth dates missing
replace tir03_dd=15 if tir03_dd==. & tir03_mm!=. & tir03_yy!=.

//Replace nonleap year February 29's with February 28's
replace tir03_dd=28 if tir03_dd==29 & tir03_mm==2 & tir03_yy!=2004 & tir03_yy!=2008

//Generate child's birth dates
gen birth_date=mdy(tir03_mm,tir03_dd,tir03_yy)


//Generate survey dates
gen survey_start_day = substr(tstart_d,1,2)
destring survey_start_day, replace 
gen survey_start_mon = substr(tstart_d,4,2)
destring survey_start_mon, replace 
gen survey_start_year = substr(tstart_d,7,2)
destring survey_start_year, replace 
replace survey_start_year = survey_start_year + 2000

gen survey_finish_day = substr(tfinish_d,1,2)
destring survey_finish_day, replace 
gen survey_finish_mon = substr(tfinish_d,4,2)
destring survey_finish_mon, replace 
gen survey_finish_year = substr(tfinish_d,7,2)
destring survey_finish_year, replace 
replace survey_finish_year = survey_finish_year + 2000

gen survey_start_date=	mdy(survey_start_mon, survey_start_day, survey_start_year) 
gen survey_finish_date=	mdy(survey_finish_mon, survey_finish_day, survey_finish_year)
gen survey_days_elapse = survey_finish_date - survey_start_date

summ survey_days_elapse, d

gen survey_date = survey_start_date
gen survey_month = ym(survey_start_year, survey_start_mon) 

drop survey_start* survey_finish*

//codebook survey_date

//Generate child's age at time of survey
generate age= survey_date-birth_date

//Drop unneeded variables
keep tid birth_date survey_date age tim06 tim06_1 tim06_2 tim01 survey_month tcov3 panel_2007 panel_2008

//Generate total number of times Vitamin A taken
gen vitA_total=tim06_1
replace vitA_total=tim06_2 if tim06_1==.
//Recode total times received to 7 if >7 & <20, to . if >=20 (no child was found to be old enough to have had more than 7 opportunities to receive vitA)
replace vitA_total=7 if vitA_total>7 & vitA_total<20
replace vitA_total=. if vitA_total>=20

gen vitA_total_6mons_2years = vitA_total if age >= 182.625 & age <  730.5

//Generate dummy for Vitamin A taken twice a year
gen lagged_age_years=(age-182.625)/365.25 if age>182.625

//Though for young children, vitA_per_year can generate seemingly implausibly high values, this is more of an indication of whether or not the 2 yearly provisions of Vit A will be taken or not versus an exact measure
gen vitA_per_year=vitA_total/lagged_age_years
gen vitA_dummy=1 if vitA_per_year>=2 & vitA_per_year<.
replace vitA_dummy=0 if vitA_per_year<2
//Junko advised to use alternative measure of opportunities taken rather than the above dummy measure 

//Generate alternative rate based on official opportunities for uptak available versus taken (vitamin A provided February and August of each year)
gen Feb1_2005=mdy(2,1,2005)
gen Feb1_2006=mdy(2,1,2006)
gen Feb1_2007=mdy(2,1,2007)
gen Feb1_2008=mdy(2,1,2008)
gen Feb1_2009=mdy(2,1,2009)
gen Aug1_2005=mdy(8,1,2005)
gen Aug1_2006=mdy(8,1,2006)
gen Aug1_2007=mdy(8,1,2007)
gen Aug1_2008=mdy(8,1,2008)
gen Aug1_2009=mdy(8,1,2009)

gen vitA_opp=.
replace vitA_opp=0 if birth_date<. & birth_date>=Aug1_2009
replace vitA_opp=1 if birth_date<Aug1_2009 & birth_date>=Feb1_2009
replace vitA_opp=2 if birth_date<Feb1_2009 & birth_date>=Aug1_2008
replace vitA_opp=3 if birth_date<Aug1_2008 & birth_date>=Feb1_2008
replace vitA_opp=4 if birth_date<Feb1_2008 & birth_date>=Aug1_2007
replace vitA_opp=5 if birth_date<Aug1_2007 & birth_date>=Feb1_2007
replace vitA_opp=6 if birth_date<Feb1_2007 & birth_date>=Aug1_2006
replace vitA_opp=7 if birth_date<Aug1_2006 & birth_date>=Feb1_2006
replace vitA_opp=8 if birth_date<Feb1_2006
replace vitA_opp=0 if age <= 182.625

gen vitA_uptak_percent=vitA_total/vitA_opp
replace vitA_uptak_percent = .y if vitA_opp == 0
gen vitA_uptak_diff = vitA_total - vitA_opp

//Merge data sets
sort tid
merge tid using `temp1', unique
tab _merge tcov3, m

tempfile temp1a
save `temp1a'

use Data\R_AR_01, clear
duplicates drop

tostring rar00_07 rar00, replace format(%02.0f)
gen tid = substr(rid,1,3) + "4" + substr(rid,5,9) + rar00

keep rar00 rar00_07 rar01a tid

merge tid using `temp1a', sort _merge(_ind_roster_info_merge)
tab _ind_roster_info_merge
keep if _ind_roster_info_merge == 3

gen panel_id_w3 = tid
replace panel_id_w3 = substr(panel_id,1,9) + "00" + "00" + rar00_07 if rar00_07 != "00" & rar00_07 != ""

tempfile temp1b
save `temp1b'


//Generate variable for complete immunization given age
generate imm_age_complete=.
replace imm_age_complete=1 if age>=7 & age<30.4375 & hepb_1==1
replace imm_age_complete=0 if age>=7 & age<30.4375 & hepb_1==0
replace imm_age_complete=1 if age>=30.4375 & age<60.875 & hepb_1==1 & bcg==1
replace imm_age_complete=0 if age>=30.4375 & age<60.875 & (hepb_1==0 | bcg==0)
replace imm_age_complete=1 if age>=60.875 & age<91.3125 & hepb_1==1 & bcg==1 & hepb_2==1 & dpt_1==1 & polio_1==1
replace imm_age_complete=0 if age>=60.875 & age<91.3125 & (hepb_1==0 | bcg==0 | hepb_2==0 | dpt_1==0 | polio_1==0)
replace imm_age_complete=1 if age>=91.3125 & age<121.75 & hepb_1==1 & bcg==1 & hepb_2==1 & dpt_1==1 & polio_1==1 & hepb_3==1 & dpt_2==1 & polio_2==1
replace imm_age_complete=0 if age>=91.3125 & age<121.75 & (hepb_1==0 | bcg==0 | hepb_2==0 | dpt_1==0 | polio_1==0 | hepb_3==0 | dpt_2==0 | polio_2==0)
replace imm_age_complete=1 if age>=121.75 & age<273.9375 & hepb_1==1 & bcg==1 & hepb_2==1 & dpt_1==1 & polio_1==1 & hepb_3==1 & dpt_2==1 & polio_2==1 & dpt_3==1 & polio_3==1
replace imm_age_complete=0 if age>=121.75 & age<273.9375 & (hepb_1==0 | bcg==0 | hepb_2==0 | dpt_1==0 | polio_1==0 | hepb_3==0 | dpt_2==0 | polio_2==0 | dpt_3==0 | polio_3==0)
replace imm_age_complete=1 if age>=273.9375 & age<. & hepb_1==1 & bcg==1 & hepb_2==1 & dpt_1==1 & polio_1==1 & hepb_3==1 & dpt_2==1 & polio_2==1 & dpt_3==1 & polio_3==1 & measles==1 & polio_4==1
replace imm_age_complete=0 if age>=273.9375 & age<. & (hepb_1==0 | bcg==0 | hepb_2==0 | dpt_1==0 | polio_1==0 | hepb_3==0 | dpt_2==0 | polio_2==0 | dpt_3==0 | polio_3==0 | measles==0 | polio_4==0)


//Calculating the total number of immunizations received ahead of schedule
//Also calculating the total number of immunizations received, restricting to those supposed to have received at that age
gen imm_age_receive_early = 0
gen num_imm_receive_for_age = 0
foreach x of var bcg polio_1 polio_2 polio_3 polio_4 dpt_1 dpt_2 dpt_3 measles hepb_1 hepb_2 hepb_3{
	replace imm_age_receive_early = imm_age_receive_early + `x' if `x' == 1 & (age>=7 & age<30.4375 ) & 		"`x'" != "hepb_1"
	replace imm_age_receive_early = imm_age_receive_early + `x' if `x' == 1 & (age>=30.4375 & age<60.875) &	"`x'" != "hepb_1" & "`x'" != "bcg"
	replace imm_age_receive_early = imm_age_receive_early + `x' if `x' == 1 & (age>=60.875 & age<91.3125) &	"`x'" != "hepb_1" & "`x'" != "bcg" & "`x'" != "hepb_2" & "`x'" != "dpt_1" & "`x'" != "polio_1"
	replace imm_age_receive_early = imm_age_receive_early + `x' if `x' == 1 & (age>=91.3125 & age<121.75) &	"`x'" != "hepb_1" & "`x'" != "bcg" & "`x'" != "hepb_2" & "`x'" != "dpt_1" & "`x'" != "polio_1" & "`x'" != "hepb_3" & "`x'" != "dpt_2" & "`x'" != "polio_2"
	replace imm_age_receive_early = imm_age_receive_early + `x' if `x' == 1 & (age>=121.75 & age<273.9375) &	"`x'" != "hepb_1" & "`x'" != "bcg" & "`x'" != "hepb_2" & "`x'" != "dpt_1" & "`x'" != "polio_1" & "`x'" != "hepb_3" & "`x'" != "dpt_2" & "`x'" != "polio_2" & "`x'" != "dpt_3" & "`x'" != "polio_3"

	replace num_imm_receive_for_age = num_imm_receive_for_age + `x' if `x' == 1 & (age>=7 & age<30.4375 ) & 		 "`x'" == "hepb_1"
	replace num_imm_receive_for_age = num_imm_receive_for_age + `x' if `x' == 1 & (age>=30.4375 & age<60.875) &		("`x'" == "hepb_1" | "`x'" == "bcg")
	replace num_imm_receive_for_age = num_imm_receive_for_age + `x' if `x' == 1 & (age>=60.875 & age<91.3125) &		("`x'" == "hepb_1" | "`x'" == "bcg" | "`x'" == "hepb_2" | "`x'" == "dpt_1" | "`x'" == "polio_1")
	replace num_imm_receive_for_age = num_imm_receive_for_age + `x' if `x' == 1 & (age>=91.3125 & age<121.75) &		("`x'" == "hepb_1" | "`x'" == "bcg" | "`x'" == "hepb_2" | "`x'" == "dpt_1" | "`x'" == "polio_1" | "`x'" == "hepb_3" | "`x'" == "dpt_2" | "`x'" == "polio_2")
	replace num_imm_receive_for_age = num_imm_receive_for_age + `x' if `x' == 1 & (age>=121.75 & age<273.9375) &	("`x'" == "hepb_1" | "`x'" == "bcg" | "`x'" == "hepb_2" | "`x'" == "dpt_1" | "`x'" == "polio_1" | "`x'" == "hepb_3" | "`x'" == "dpt_2" | "`x'" == "polio_2" | "`x'" == "dpt_3" | "`x'" == "polio_3")	
	replace num_imm_receive_for_age = num_imm_receive_for_age + `x' if `x' == 1 & (age>=273.9375 & age<.) &		("`x'" == "hepb_1" | "`x'" == "bcg" | "`x'" == "hepb_2" | "`x'" == "dpt_1" | "`x'" == "polio_1" | "`x'" == "hepb_3" | "`x'" == "dpt_2" | "`x'" == "polio_2" | "`x'" == "dpt_3" | "`x'" == "polio_3" | "`x'" == "measles" | "`x'" == "polio_4")

}	

//To avoid false zeros from way we calc
replace num_imm_receive_for_age = . if num_imm_receive == .


gen imm_age_number_req = .
replace imm_age_number_req = 1  if age>=7        & age<30.4375 
replace imm_age_number_req = 2  if age>=30.4375  & age<60.875 
replace imm_age_number_req = 5  if age>=60.875   & age<91.3125 
replace imm_age_number_req = 8  if age>=91.3125  & age<121.75 
replace imm_age_number_req = 10 if age>=121.75   & age<273.9375 
replace imm_age_number_req = 12  if age>=273.9375 & age<. 

//Generate variable for percent of immunization received by age (for children up to 11 months of age and 23 months old and below)
gen imm_age_uptak_percent_all = num_imm_receive / imm_age_number_req
gen imm_age_uptak_diff_all = num_imm_receive - imm_age_number_req

gen imm_age_uptak_percent_only = num_imm_receive_for_age / imm_age_number_req
gen imm_age_uptak_diff_only = num_imm_receive_for_age - imm_age_number_req

gen imm_uptak_pct_23mons_all = imm_age_uptak_percent_all if age < 700.0625
gen imm_uptak_diff_23mons_all = imm_age_uptak_diff_all if age < 700.0625

gen imm_uptak_pct_23mons = imm_age_uptak_percent_only if age < 700.0625
gen imm_uptak_diff_23mons = imm_age_uptak_diff_only if age < 700.0625


//Generate variable for total immunization
generate imm_total_complete=.
replace imm_total_complete=1 if hepb_1==1 & bcg==1 & hepb_2==1 & dpt_1==1 & polio_1==1 & hepb_3==1 & dpt_2==1 & polio_2==1 & dpt_3==1 & polio_3==1 & measles==1 & polio_4==1
replace imm_total_complete=0 if hepb_1==0 | bcg==0 | hepb_2==0 | dpt_1==0 | polio_1==0 | hepb_3==0 | dpt_2==0 | polio_2==0 | dpt_3==0 | polio_3==0 | measles==0 | polio_4==0

//Generate variable for total immunization in children at least 10 months of age
generate imm_total_comp10month=.
replace imm_total_comp10month=1 if age>=304.375 & age<. & hepb_1==1 & bcg==1 & hepb_2==1 & dpt_1==1 & polio_1==1 & hepb_3==1 & dpt_2==1 & polio_2==1 & dpt_3==1 & polio_3==1 & measles==1 & polio_4==1
replace imm_total_comp10month=0 if age>=304.375 & age<. & (hepb_1==0 | bcg==0 | hepb_2==0 | dpt_1==0 | polio_1==0 | hepb_3==0 | dpt_2==0 | polio_2==0 | dpt_3==0 | polio_3==0 | measles==0 | polio_4==0)


gen bcg_last12m = 1 if bcg==1 & survey_date-get_bcg<=365.25
gen polio_1_last12m = 1 if polio_1==1 & survey_date-get_polio_1<=365.25
gen polio_2_last12m = 1 if polio_2==1 & survey_date-get_polio_2<=365.25
gen polio_3_last12m = 1 if polio_3==1 & survey_date-get_polio_3<=365.25
gen polio_4_last12m = 1 if polio_4==1 & survey_date-get_polio_4<=365.25
gen dpt_1_last12m = 1 if dpt_1==1 & survey_date-get_dpt_1<=365.25
gen dpt_2_last12m = 1 if dpt_2==1 & survey_date-get_dpt_2<=365.25
gen dpt_3_last12m = 1 if dpt_3==1 & survey_date-get_dpt_3<=365.25
gen measles_last12m = 1 if measles==1 & survey_date-get_measles<=365.25
gen hepb_1_last12m = 1 if hepb_1==1 & survey_date-get_hepb_1<=365.25
gen hepb_2_last12m = 1 if hepb_2==1 & survey_date-get_hepb_2<=365.25
gen hepb_3_last12m = 1 if hepb_3==1 & survey_date-get_hepb_3<=365.25

foreach x of var bcg polio_1 polio_2 polio_3 polio_4 dpt_1 dpt_2 dpt_3 measles hepb_1 hepb_2 hepb_3{
replace `x'_last12m = 0 if `x'_last12m == .
}

gen imm_total= hepb_1_last12m + hepb_2_last12m + hepb_3_last12m + bcg_last12m + dpt_1_last12m + dpt_2_last12m + dpt_3_last12m + polio_1_last12m + polio_2_last12m +polio_3_last12m + polio_4_last12m + measles_last12m


drop _merge
sort tid
tempfile temp2
save `temp2'


use Data\R_US, clear

keep if rus_row == 4

destring rus03_cb rus03_cd rus01_b rus01_d, replace force

replace rus03_cd = rus03_cd /100
replace rus01_d = rus01_d /100

gen r_weight = rus03_cb
replace r_weight = rus03_cb + rus03_cd if rus03_cd != .

gen r_height = rus01_b
replace r_height = rus01_b + rus01_d if rus01_d != .


tostring rus01a, replace format(%02.0f) 
gen tid = substr(rid,1,3) + "4" + substr(rid,5,9) + rus01a

duplicates tag tid, gen(tag)
replace r_height = . if tag == 1
replace r_weight = . if tag == 1

keep tid r_height r_weight 
duplicates drop
sort tid

tempfile temp_anthro
save `temp_anthro'

use Data\T, clear

duplicates drop
**$$
duplicates drop tid, force

merge tid using `temp_anthro', sort
tab _m
drop if _m == 2
drop _m

keep tid r_weight r_height tir02

 
//Recode female variable value for use in WHO command
replace tir02=2 if tir02==3
label define sex 1 "Laki-Laki" 2 "Perempuan"
label values tir02 sex

//Merge data sets
sort tid
merge tid using `temp2', unique
sort tid
tab _merge
drop if _merge == 1
drop _merge

//Generate variable for measurement type for WHO command, standing height(h) or recumbent length (l)

//Rename variables for use in WHO command
rename tir02 gender
rename r_weight weight
rename r_height height 
gen measure = "h"


replace weight=. if weight>=35 

save children36month, replace

clear

set more 1
//set mem 400m
// Indicate where ado file located
adopath + "..\WHO igrowup STATA/"

//Load necessary data
use children36month, clear

//Generate first three parameters for WHO command
gen str60 reflib="..\WHO igrowup STATA"
lab var reflib "Directory of reference tables"

gen str60 datalib="..\Wave III"
lab var datalib "Directory for datafiles"

gen str30 datalab="children36months_plus_nutrtion"
lab var datalab "Working file"

//Define age unit
gen str6 ageunit="days"

//Define oedema variable
gen str1 oedema="n"

//Define sampling weight variable
gen sw=1

//Run WHO command
igrowup_restricted reflib datalib datalab gender age ageunit weight height measure oedema sw

clear

//Load data set containing original variables plus WHO output
use "..\Wave III\children36months_plus_nutrtion_z_rc.dta", clear

//Drop irrelevant variables
drop reflib datalib datalab ageunit measure oedema sw _agedays _cbmi _zbmi

//Changing to missing those weight for age obs with _zwei implausible
replace _zwei = . if _fwei == 1
replace _zlen = . if _flen == 1
replace _zwfl = . if _fwfl == 1


gen notmal_weightforage=.
replace notmal_weightforage=1 if _zwei>-2 & _zwei<.
replace notmal_weightforage=0 if _zwei<=-2

gen mal_weightforage=.
replace mal_weightforage=0 if _zwei>-2 & _zwei<.
replace mal_weightforage=1 if _zwei<=-2

gen severe_weightforage=.
replace severe_weightforage=0 if _zwei>-3 & _zwei<.
replace severe_weightforage=1 if _zwei<=-3

gen notmal_heightforage=.
replace notmal_heightforage=1 if _zlen>-2 & _zlen<.
replace notmal_heightforage=0 if _zlen<=-2

gen mal_heightforage=.
replace mal_heightforage=0 if _zlen>-2 & _zlen<.
replace mal_heightforage=1 if _zlen<=-2

gen severe_heightforage=.
replace severe_heightforage=0 if _zlen>-3 & _zlen<.
replace severe_heightforage=1 if _zlen<=-3

gen notmal_weightforheight=.
replace notmal_weightforheight=1 if _zwfl>-2 & _zwfl<.
replace notmal_weightforheight=0 if _zwfl<=-2

gen mal_weightforheight=.
replace mal_weightforheight=0 if _zwfl>-2 & _zwfl<.
replace mal_weightforheight=1 if _zwfl<=-2

gen severe_weightforheight=.
replace severe_weightforheight=0 if _zwfl>-3 & _zwfl<.
replace severe_weightforheight=1 if _zwfl<=-3

rename _zwei z_weightforage
rename _zlen z_heightforage
rename _zwfl z_weightforheight

foreach x in weightforage heightforage weightforheight{
	gen notmal_`x'_age0to1 = notmal_`x' if age <= 365.25
	gen mal_`x'_age0to1 = mal_`x' if age <= 365.25
	gen severe_`x'_age0to1 = severe_`x' if age <= 365.25
	gen notmal_`x'_age1to2 = notmal_`x' if age > 365.25 & age <= 730.5
	gen mal_`x'_age1to2 = mal_`x' if age > 365.25 & age <= 730.5
	gen severe_`x'_age1to2 = severe_`x' if age > 365.25 & age <= 730.5
	gen notmal_`x'_age2to3 = notmal_`x' if age > 730.5 & age < .
	gen mal_`x'_age2to3 = mal_`x' if age > 730.5 & age < .
	gen severe_`x'_age2to3 =  severe_`x' if age > 730.5 & age < .
	}

foreach x in z_weightforage z_heightforage z_weightforheight{
	gen `x'_age0to1 = `x' if age <= 365.25
	gen `x'_age1to2 = `x' if age > 365.25 & age <= 730.5
	gen `x'_age2to3 = `x' if age > 730.5 & age < .
	gen `x'_age0to3 = `x' if age < .
	}

sort tid
save "..\Wave III\children36months.dta", replace
clear


//Load necessary data
use Data\T_IM13


//Keep relevant variables
keep tid tim13_line tim14 tim14_dd tim14_mm tim14_yy tim15 

duplicates drop tid tim13_line, force

//Condense card/book recorded last three health post visits weighing info to single line per ID
reshape wide tim14 tim14_dd tim14_mm tim14_yy tim15, i(tid) j(tim13_line)
keep tid tim141 tim14_dd1 tim14_mm1 tim14_yy1 tim151 tim142 tim14_dd2 tim14_mm2 tim14_yy2 tim152 tim143 tim143 tim14_dd3 tim14_mm3 tim14_yy3 tim153

//Replace missing days with 15 if neither nor month nor year values missing for recorded health post visit dates
replace tim14_dd1=15 if tim14_dd1==. & tim14_mm1!=. & tim14_yy1!=.
replace tim14_dd2=15 if tim14_dd2==. & tim14_mm2!=. & tim14_yy2!=.
replace tim14_dd3=15 if tim14_dd3==. & tim14_mm3!=. & tim14_yy3!=.

//Generate recorded dates for last three visits
gen recorded_visit_date1=mdy(tim14_mm1, tim14_dd1, tim14_yy1)
gen recorded_visit_date2=mdy(tim14_mm2, tim14_dd2, tim14_yy2)
gen recorded_visit_date3=mdy(tim14_mm3, tim14_dd3, tim14_yy3)

gen recorded_visit_month1=ym(tim14_yy1, tim14_mm1)
gen recorded_visit_month2=ym(tim14_yy2, tim14_mm2)
gen recorded_visit_month3=ym(tim14_yy3, tim14_mm3)


sort tid
tempfile temp3
save `temp3'
clear


//Load necessary data
use Data\T

duplicates drop

duplicates drop tid, force

sort tid


//Replace missing days with 15 if neither month nor year values missing for asked last health post visit date
replace tpos06_dd=15 if tpos06_dd==. & tpos06_mm!=. & tpos06_yy!=.

//Generate asked date of last visit
gen last_visit_date_asked=mdy(tpos06_mm, tpos06_dd, tpos06_yy)
gen last_visit_month_asked = ym(tpos06_yy, tpos06_mm)

//Merge data sets
merge tid using `temp3', unique
sort tid
tab _merge


//Merge data sets
drop _merge
merge tid using children36months
sort tid
tab _merge, missing
 
//Generate time since last visit according to asked date
gen time_since_visit_asked = survey_date - last_visit_date_asked
gen month_since_visit_asked = survey_month - last_visit_month_asked

//Generate dummy for child weighed in last month
gen visit_and_weigh_lastmonth=.
replace visit_and_weigh_lastmonth = 1 if time_since_visit_asked <= 30.4375 & tpos07a == 1
replace visit_and_weigh_lastmonth = 0 if time_since_visit_asked <= 30.4375 & tpos07a == 3
replace visit_and_weigh_lastmonth = 0 if time_since_visit_asked > 30.4375 & time_since_visit_asked < .
replace visit_and_weigh_lastmonth = 0 if tpos01 == 3
tab visit_and_weigh_lastmonth, missing

//Generate dummy for child weight in current or previous calendar month
gen weigh_last_calendarmonth = .
replace weigh_last_calendarmonth = 1 if month_since_visit_asked <= 1 & tpos07a == 1
replace weigh_last_calendarmonth = 0 if month_since_visit_asked <= 1 & tpos07a == 3
replace weigh_last_calendarmonth = 0 if month_since_visit_asked > 1 & month_since_visit_asked < .
replace weigh_last_calendarmonth = 0 if tpos01 == 3
tab weigh_last_calendarmonth, missing


//Generate time since last recorded visit
gen time_since_recorded_visit1 = survey_date - recorded_visit_date1
gen time_since_recorded_visit2 = survey_date - recorded_visit_date2
gen time_since_recorded_visit3 = survey_date - recorded_visit_date3

gen month_since_recorded_visit1 = survey_month - recorded_visit_month1
gen month_since_recorded_visit2 = survey_month - recorded_visit_month2
gen month_since_recorded_visit3 = survey_month - recorded_visit_month3


//Change dummy for child weighed in last month if additional information revealed in recorded dates
replace visit_and_weigh_lastmonth=1 if time_since_recorded_visit1<=30.4375 & tim151==1
replace visit_and_weigh_lastmonth=1 if time_since_recorded_visit2<=30.4375 & tim152==1
replace visit_and_weigh_lastmonth=1 if time_since_recorded_visit3<=30.4375 & tim153==1

replace weigh_last_calendarmonth = 1 if month_since_recorded_visit1 <= 1 & tim151 == 1
replace weigh_last_calendarmonth = 1 if month_since_recorded_visit2 <= 1 & tim151 == 1
replace weigh_last_calendarmonth = 1 if month_since_recorded_visit3 <= 1 & tim151 == 1

//Generate variables for times weighed in last two months according to asked and recorded dates
gen two_month_visit_weigha=.
replace two_month_visit_weigha=1 if time_since_visit_asked<=60.875 & tpos07a==1
replace two_month_visit_weigha=0 if time_since_visit_asked<=60.875 & tpos07a==3
replace two_month_visit_weigha=0 if time_since_visit_asked>60.875 & time_since_visit<.

gen two_month_visit_weighb=.
replace two_month_visit_weighb=1 if time_since_recorded_visit1<=60.875 & tim151==1 & time_since_recorded_visit1!=time_since_visit_asked
replace two_month_visit_weighb=0 if time_since_recorded_visit1<=60.875 & tim151==1 & time_since_recorded_visit1==time_since_visit_asked
replace two_month_visit_weighb=0 if time_since_recorded_visit1<=60.875 & tim151==3 
replace two_month_visit_weighb=0 if time_since_recorded_visit1>60.875 & time_since_recorded_visit1<.

gen two_month_visit_weighc=.
replace two_month_visit_weighc=1 if time_since_recorded_visit2<=60.875 & tim152==1 & time_since_recorded_visit2!=time_since_visit_asked & time_since_recorded_visit2!=time_since_recorded_visit1
replace two_month_visit_weighc=0 if time_since_recorded_visit2<=60.875 & tim152==1 & (time_since_recorded_visit2==time_since_visit_asked |time_since_recorded_visit2==time_since_recorded_visit1)
replace two_month_visit_weighc=0 if time_since_recorded_visit2<=60.875 & tim152==3 
replace two_month_visit_weighc=0 if time_since_recorded_visit2>60.875 & time_since_recorded_visit2<.

gen two_month_visit_weighd=.
replace two_month_visit_weighd=1 if time_since_recorded_visit3<=60.875 & tim153==1 & time_since_recorded_visit3!=time_since_visit_asked & time_since_recorded_visit2!=time_since_recorded_visit1 & time_since_recorded_visit3!=time_since_recorded_visit2
replace two_month_visit_weighd=0 if time_since_recorded_visit3<=60.875 & tim153==1 & (time_since_recorded_visit3==time_since_visit_asked |time_since_recorded_visit3==time_since_recorded_visit1 | time_since_recorded_visit3==time_since_recorded_visit2)
replace two_month_visit_weighd=0 if time_since_recorded_visit3<=60.875 & tim153==3 
replace two_month_visit_weighd=0 if time_since_recorded_visit3>60.875 & time_since_recorded_visit3<.

//Generate total times weighed in last two months
gen times_weighed_last2months=0
foreach x of var two_month_visit_weigha two_month_visit_weighb two_month_visit_weighc two_month_visit_weighd{
replace times_weighed_last2months=times_weighed_last2months+`x' if `x'<.
}
replace times_weighed_last2months=. if visit_and_weigh_lastmonth==. & two_month_visit_weigha==. & two_month_visit_weighb==. & two_month_visit_weighc==. & two_month_visit_weighd==. 


//Generate total times weight in last 3 months (use mom's recall of # posyandu visits in last 3 months (POS05) but 0 if was not weighed at last visit)
gen times_weighed_last3months = tpos05
replace times_weighed_last3months = 0 if tpos01 == 3
replace times_weighed_last3months = . if times_weighed_last3months > 5 & times_weighed_last3months  != .


//Explain missings
tab1 imm_age_complete imm_total_complete mal_weightforage mal_heightforage mal_weightforheight, missing
codebook height
codebook weight
codebook age 
tab visit_and_weigh_lastmonth, missing
tab tpos01 visit_and_weigh_lastmonth, missing
tab times_weighed_last2months, missing
tab tpos01 times_weighed_last2months, missing
tab vitA_dummy, missing
tab vitA_dummy if age<182.625, missing 
tab vitA_dummy tim06 if age>182.625, missing
tab vitA_total vitA_opp, missing
tab vitA_uptak_percent, missing

//Keeping only observations within desired age range (0-36 months)
keep if age >= 0 & age <= 1095.75


//Generate variable for observation type (Child 0-36 months == 2)
gen obs_type = 7
label define obstype_label 7 "Child 0-36 months"
label values obs_type obstype_label


//Rename variables for consistency in future merges
rename tid id


foreach x of var imm_age_complete imm_total_complete imm_total_comp10month z_weightforage z_heightforage z_weightforheight notmal_weightforage mal_weightforage severe_weightforage notmal_heightforage mal_heightforage severe_heightforage notmal_weightforheight mal_weightforheight severe_weightforheight weigh_last_calendarmonth visit_and_weigh_lastmonth times_weighed_last2months times_weighed_last3months vitA_total vitA_total_6mons_2years vitA_dummy vitA_opp vitA_uptak_percent imm_uptak_pct_23mons_all  imm_uptak_pct_23mons imm_total{
	rename `x' `x'_w3
}


//Generating variables to look panel individuals across waves
gen rid= substr(id,1,3) + "1" + substr(id,5,9)
sort rid
tempfile temp
save `temp'

****

use Data\R, clear

duplicates drop


gen panel_hh = (rar00x == 1 | rar00x == 2)
gen panel_hh_id_w3 = substr(rid, 1,3) + substr(rid,5,9)

keep rid panel_hh panel_hh_id_w3 rar00x
sort rid

duplicates drop rid, force

merge rid using `temp', uniqmaster _merge(_mx)
tab _mx
keep if _mx == 3

drop _ind_roster_info_merge panel_id

tempfile temp2
save `temp2'

****

use Data\R_AR_01, clear
duplicates drop

tostring rar00_07 rar00, replace format(%02.0f)
gen id = substr(rid,1,3) + "4" + substr(rid,5,9) + rar00

keep rar00 rar00_07 rar01a id

merge id using `temp2', sort _merge(_ind_roster_info_merge)
tab _ind_roster_info_merge
keep if _ind_roster_info_merge == 3




//Generating Variables for identification to check in merges
gen hh_serial_no_w3 = tir01_cd
gen birth_year_w3 = tir03_yy
gen birth_mon_w3 = tir03_mm
gen birth_day_w3 = tir03_dd
gen gender_w3 = tir02

gen birth_date_w3 = birth_date
gen survey_date_w3 = survey_date

//Generating age in years for children 0-36months
gen age_years = floor(age/365.25) if obs_type == 7

gen panel_id_w3 = id
gen art_split_w3 = substr(id,10,2)

replace panel_id_w3 = substr(panel_id_w3,1,9) + "00" + "00" + rar00_07 if rar00_07 != "00" & rar00_07 != ""

order id panel_id_w3
sort id

compress
save children0to36months_w3, replace
