clear
set more off

cd "Wave II"

/*In this file, data in the files A and A_DLA1TYPE from the section of the survey 'Book 1C: Children 6-15 Years' to determine the following variables:
enroll_age7to12:				whether or not the child age 7 to 12 is enrolled in school
enroll_age7to12_SD:				whether or not the child age 7 to 12 is enrolled in primary school
enroll_age13to15:				whether or not the child age 13 to 15 is enrolled in school
enroll_age13to15_SMP:			whether or not the child age 13 to 15 is enrolled in middle school
enroll_age13to15_other:			whether or not the child age 13 to 15 is enrolled in non-middle school
enroll_SD:					whether or not the child age 7 to 15 is enrolled in primary school
enroll_SMP:					whether or not the child age 7 to 15 is enrolled in middle school
gross_SD_enroll_kec:			# children in SD age 7 to 15 in kec / # kids age 7-12 in kec
gross_SMP_enroll_kec:			# children in SMP age 7 to 15 in kec / # kids age 13-15 in kec
age7to12_pct_lastweek:			the pct of the time the child age 7 to 12 atttended school based on answers regarding the previous week
age13to15_pct_lastweek:			the pct of the time the child age 13 to 15 atttended school based on answers regarding the previous week
age7to12_pct_twoweeks			the pct of time the child age 7 to 12 attended school based on answers regarding the previous two weeks, includes non-enrolled as 0
age13to15_pct_twoweeks			the pct of time the child age 13 to 15 attended school based on answers regarding the previous two weeks, includes non-enrolled as 0
age7to12_85_twoweeks:			whether or not the child age 7 to12 attended school at least 85% of the time based on answers regarding the previous two weeks
age13to15_85_twoweeks:			whether or not the child age 13 to 15 attended school at least 85% of the time based on answers regarding the previous two weeks
age7to12_fullattend_twoweeks:		whether or not the child age 7 to 12 attended school without missing any days in the last two weeks
age13to15_fullattend_twoweeks:		whether or not the child age 13 to 15 attended school without missing any days in the last two weeks
labor_no_home_dummy:				whether or not the child works more than 20 hours a month, not including work around the household such as cleaning
labor_yes_home_dummy:			whether or not the child works more than 20 hours a month, including work around the household

*/




//Load relevant variables
use Data\A

gen panel_2007 = (acov3 == 1)

//Replace missing days with 15 if neither month nor year values for children's birth dates missing
replace air03_dd=15 if air03_dd==. & air03_mm!=. & air03_yy!=.

//Replace nonleap year February 29's with February 28's
replace air03_dd=28 if air03_dd==29 & air03_mm==2 & air03_yy!=1992 & air03_yy!=1996 & air03_yy!=2000

//Generate child's birth dates
gen birth_date=mdy(air03_mm,air03_dd,air03_yy)

//Generate survey dates using first survey attempt with at least partial completion
gen survey_date=mdy(aivw_mm_1, aivw_dd_1, aivw_yy_1) if ahkw_1==1 | ahkw_1==2
replace survey_date=mdy(aivw_mm_2, aivw_dd_2, aivw_yy_2) if survey_date==. & (ahkw_2==1 | ahkw_2==2)
replace survey_date=mdy(aivw_mm_3, aivw_dd_3, aivw_yy_3) if survey_date==. & (ahkw_3==1 | ahkw_3==2)

//codebook survey_date

//Generate child's age at time of survey
gen age = survey_date - birth_date
gen age_years = floor(age / 365.25)
gen age_mons = floor(age/ 30.4375)

//Generate age 7 to 12 enrollment dummy
gen enroll_age7to12 = .
replace enroll_age7to12 = 1 if adla09 == 1 & age_years >= 7 & age_years <= 12
replace enroll_age7to12 = 0 if adla01 == 3 & age_years >= 7 & age_years <= 12
replace enroll_age7to12 = 0 if adla04 == 96 & age_years >= 7 & age_years <= 12
replace enroll_age7to12 = 0 if adla09 == 3 & age_years >= 7 & age_years <= 12
replace enroll_age7to12 = 0 if (air04b == 1 | air04b == 4) & age_years >= 7 & age_years <= 12

//Generate age 7 to 12 and primary school enrollment dummy
gen enroll_age7to12_SD = .
replace enroll_age7to12_SD = 1 if adla09 == 1 & age_years >= 7 & age_years <= 12 & (adla04 == 1 | adla04 == 2)
replace enroll_age7to12_SD = 0 if adla01 == 3 & age_years >= 7 & age_years <= 12
replace enroll_age7to12_SD = 0 if adla04 == 96 & age_years >= 7 & age_years <= 12
replace enroll_age7to12_SD = 0 if adla09 == 1 & age_years >= 7 & age_years <= 12 & adla04 != 1 & adla04 != 2
replace enroll_age7to12_SD = 0 if adla09 == 3 & age_years >= 7 & age_years <= 12
replace enroll_age7to12_SD = 0 if (air04b == 1 | air04b == 4) & age_years >= 7 & age_years <= 12

//Generate age 13 to 15 enrollment dummy
gen enroll_age13to15 = .
replace enroll_age13to15 = 1 if adla09 == 1 & age_years >= 13 & age_years <= 15
replace enroll_age13to15 = 0 if adla01 == 3 & age_years >= 13 & age_years <= 15
replace enroll_age13to15 = 0 if adla04 == 96 & age_years >= 13 & age_years <= 15
replace enroll_age13to15 = 0 if adla09 == 3 & age_years >= 13 & age_years <= 15
replace enroll_age13to15 = 0 if (air04b == 1 | air04b == 4) & age_years >= 13 & age_years <= 15

//Generate age 13 to 15 and middle school enrollment dummy
gen enroll_age13to15_SMP = .
replace enroll_age13to15_SMP = 1 if adla09 == 1 & age_years >= 13 & age_years <= 15 & (adla04 == 3 | adla04 == 4)
replace enroll_age13to15_SMP = 0 if adla01 == 3 & age_years >= 13 & age_years <= 15
replace enroll_age13to15_SMP = 0 if adla04 == 96 & age_years >= 13 & age_years <= 15
replace enroll_age13to15_SMP = 0 if adla09 == 1 & age_years >= 13 & age_years <= 15 & adla04 != 3 & adla04 != 4 
replace enroll_age13to15_SMP = 0 if adla09 == 3 & age_years >= 13 & age_years <= 15
replace enroll_age13to15_SMP = 0 if (air04b == 1 | air04b == 4) & age_years >= 13 & age_years <= 15

//Generate age 13 to 15 and other (non-middle) school enrollment dummy
gen enroll_age13to15_other = .
replace enroll_age13to15_other = 1 if adla09 == 1 & age_years >= 13 & age_years <= 15 & (adla04 != 3 & adla04 != 4)
replace enroll_age13to15_other = 0 if adla01 == 3 & age_years >= 13 & age_years <= 15
replace enroll_age13to15_other = 0 if adla04 == 96 & age_years >= 13 & age_years <= 15
replace enroll_age13to15_other = 0 if adla09 == 1 & age_years >= 13 & age_years <= 15 & (adla04 == 3 | adla04 == 4) 
replace enroll_age13to15_other = 0 if adla09 == 3 & age_years >= 13 & age_years <= 15
replace enroll_age13to15_other = 0 if (air04b == 1 | air04b == 4) & age_years >= 13 & age_years <= 15

//Generate primary school enrollment dummy (non-age restricted)
gen enroll_SD = .
replace enroll_SD = 1 if adla09 == 1 & (adla04 == 1 | adla04 == 2)
replace enroll_SD = 0 if adla01 == 3
replace enroll_SD = 0 if adla04 == 96
replace enroll_SD = 0 if adla09 == 1 & adla04 != 1 & adla04 != 2
replace enroll_SD = 0 if adla09 == 3
replace enroll_SD = 0 if (air04b == 1 | air04b == 4)

//Generate middle school enrollment dummy (non-age restricted)
gen enroll_SMP = .
replace enroll_SMP = 1 if adla09 == 1 & (adla04 == 3 | adla04 == 4)
replace enroll_SMP = 0 if adla01 == 3
replace enroll_SMP = 0 if adla04 == 96
replace enroll_SMP = 0 if adla09 == 1 & adla04 != 3 & adla04 != 4
replace enroll_SMP = 0 if adla09 == 3
replace enroll_SMP = 0 if (air04b == 1 | air04b == 4)

//Generate age 7-12 dummy
gen age_7to12 = (age_years >=7 & age_years <=12)
replace age_7to12 = . if age_years == .

//Generate age 13-15 dummy
gen age_13to15 = (age_years >=13 & age_years <=15)
replace age_13to15 = . if age_years == .


//Drop irrelevant variables
keep aid birth_date survey_date age age_years age_mons enroll_age7to12* enroll_age13to15* adla01 adla04 adla09 age_7to12 age_13to15 enroll_SD enroll_SMP panel_2007

sort aid
tempfile temp4
save `temp4', replace
clear

use Data\A_DLA1TYPE

//Recode values for 'No' entries for school open and school attendance
replace adla17=0 if adla17==3
replace adla18=0 if adla18==3

//Drop irrelevant variables
keep aid adla1type adla17 adla18

//Condense information on school open and attendance for each day of the week to single line per id
reshape wide adla17 adla18, i(aid) j(adla1type)

//Generate the total number of days school open in the last week
gen days_open_lastweek=0
foreach x of var adla171 adla172 adla173 adla174 adla175 adla176 adla177{
replace days_open_lastweek=days_open_lastweek+`x' if `x'<.
}
replace days_open_lastweek=. if adla171==. & adla172==. & adla173==. & adla174==. & adla175==. & adla176==. & adla177==.

//tab days_open_lastweek, missing

//Generate the total number of days school attended in the last week
gen days_attend_lastweek=0
foreach x of var adla181 adla182 adla183 adla184 adla185 adla186 adla187{
replace days_attend_lastweek=days_attend_lastweek+`x' if `x'<.
}
replace days_attend_lastweek=. if adla181==. & adla182==. & adla183==. & adla184==. & adla185==. & adla186==. & adla187==.
replace days_attend_lastweek=. if days_open_lastweek==0


//tab days_attend_lastweek, missing

//tab pct_attended_lastweek, missing

//keep aid days_open_lastweek days_attend_lastweek pct_attended_lastweek

sort aid
merge aid using "`temp4'", unique
tab _merge
drop _merge
sort aid
tempfile temp5
save `temp5', replace
clear

use Data\A

//Keep variables for days attended last two weeks and days school open in last two weeks
keep aid adla21_n adla22_an


sort aid
merge aid using "`temp5'", unique
sort aid
tab _merge
drop _merge

//Generate the pct school was attended in the last week
gen pct_attended_lastweek=days_attend_lastweek/days_open_lastweek
gen age7to12_pct_lastweek=pct_attended_lastweek if age_years>=7 & age_years<=12
gen age13to15_pct_lastweek=pct_attended_lastweek if age_years>=13 & age_years<=15

//Generate the pct school was attended in the last two weeks		
gen pct_attended_twoweeks = adla22_an/adla21_n

//Take into account cases in which replied more days school attended than days school open
replace pct_attended_twoweeks=1 if pct_attended_twoweeks>1 & pct_attended_twoweeks<.

gen age7to12_pct_twoweeks=pct_attended_twoweeks if age_years>=7 & age_years<=12
replace age7to12_pct_twoweeks = 0 if enroll_age7to12 == 0
gen age13to15_pct_twoweeks=pct_attended_twoweeks if age_years>=13 & age_years<=15
replace age13to15_pct_twoweeks = 0 if enroll_age13to15 == 0

gen cond_age13to15_pct_2wks = pct_attended_twoweeks if age_years >= 13 & age_years <= 15 & enroll_age13to15 == 1

***Correcting the attendance percentages to take into kecamatan where days school open is 0 at kec level avg
gen kec_temp = substr(aid,1,3)
bys kec_temp: egen kec_days_open_7to12 = mean(adla21_n) if age_years >= 7 & age_years <= 12
bys kec_temp: egen kec_days_open_13to15 = mean(adla21_n) if age_years >= 13 & age_years <= 15

replace age7to12_pct_twoweeks = . if kec_days_open_7to12 == 0
replace age13to15_pct_twoweeks = . if kec_days_open_13to15 == 0
replace cond_age13to15_pct_2wks = . if kec_days_open_13to15 == 0

drop kec_temp


//Generate the dummy variable for greater than 85 pct attendance to primary school in the last two weeks
generate age7to12_85_twoweeks=.
replace age7to12_85_twoweeks=0 if enroll_age7to12==0
replace age7to12_85_twoweeks=1 if pct_attended_twoweeks>=0.85 & pct_attended_twoweeks<. & age_years>=7 & age_years<=12
replace age7to12_85_twoweeks=0 if pct_attended_twoweeks<0.85 & age_years>=7 & age_years<=12

generate age7to12_fullattend_twoweeks = . 
replace age7to12_fullattend_twoweeks = 0 if enroll_age7to12 == 0
replace age7to12_fullattend_twoweeks = 1 if pct_attended_twoweeks >= 1 & pct_attended_twoweeks < . & age_years >= 7 & age_years <= 12
replace age7to12_fullattend_twoweeks = 0 if pct_attended_twoweeks < 1 & age_years >= 7 & age_years <= 12

//Generate the dummy variable for greater than 85 pct attendance to middle school in the last two weeks
generate age13to15_85_twoweeks=.
replace age13to15_85_twoweeks=0 if enroll_age13to15 ==0
replace age13to15_85_twoweeks=1 if pct_attended_twoweeks>=0.85 & pct_attended_twoweeks<. & age_years>=13 & age_years<=15
replace age13to15_85_twoweeks=0 if pct_attended_twoweeks<0.85 & age_years>=13 & age_years<=15

generate age13to15_fullattend_twoweeks = . 
replace age13to15_fullattend_twoweeks = 0 if enroll_age13to15 == 0
replace age13to15_fullattend_twoweeks = 1 if pct_attended_twoweeks >= 1 & pct_attended_twoweeks < . & age_years >= 13 & age_years <= 15
replace age13to15_fullattend_twoweeks = 0 if pct_attended_twoweeks < 1 & age_years >= 13 & age_years <= 15



sort aid
tempfile temp6
save `temp6', replace
clear

//Generate child labor dummies
use Data\A

gen weeks_work_wage = atka03_n
gen hrs_wage = atka04_h
gen hrs_wage_frac = atka04_m / 60
gen weeks_work_fam = atka10_n
gen hrs_fam = atka11_h
gen hrs_fam_frac = atka11_m / 60
gen weeks_work_home = 13/3 
gen hrs_home = atka15_h
gen hrs_home_frac = atka15_m / 60

//No missing hours if minutes not missing and vice versa, so just add and multiply (no issue with missings in part of equation but not other part)
//Rule out highly unreasonable entries (>70hrs/week)
gen week_wage_hrs = hrs_wage + hrs_wage_frac
replace week_wage_hrs = . if week_wage_hrs > 70
gen week_fam_hrs = hrs_fam + hrs_fam_frac
replace week_fam_hrs = .  if week_fam_hrs > 70
gen week_home_hrs = hrs_home + hrs_home_frac
replace week_home_hrs = . if week_home_hrs > 70

gen total_wage_hrs = week_wage_hrs * weeks_work_wage 
gen total_fam_hrs =  week_fam_hrs * weeks_work_fam
gen total_home_hrs = week_home_hrs * weeks_work_home

replace total_wage_hrs = 0 if atka01 == 3 | atka02 == 3
replace total_fam_hrs = 0 if atka08 == 3 | atka09 == 3
replace total_home_hrs = 0 if atka14 == 3 | atka15 == 3


gen labor_nohome = 0
gen labor_yeshome = 0

foreach X of var total_wage_hrs total_fam_hrs{
	replace labor_nohome = labor_nohome + `X' if `X' < .
	}
foreach X of var total_wage_hrs total_fam_hrs total_home_hrs{
	replace labor_yeshome = labor_yeshome + `X' if `X' < .
	}

replace labor_nohome = . if total_wage_hrs == . & total_fam_hrs == .
replace labor_yeshome = . if total_wage_hrs == . & total_fam_hrs == . & total_home_hrs == .

gen labor_nohome_dummy = . 
replace labor_nohome_dummy = 1 if labor_nohome >= 20 & labor_nohome < .
replace labor_nohome_dummy = 0 if labor_nohome < 20

gen labor_yeshome_dummy = .
replace labor_yeshome_dummy = 1 if labor_yeshome >= 20 & labor_yeshome < .
replace labor_yeshome_dummy = 0 if labor_yeshome < 20

sort aid
merge aid using `temp6', unique
tab _merge
drop _merge

//Generate variable indicating what type of observation (child 6-15 years == 10)
gen obs_type = 10

//keep aid asup_cd aedit_cd obs_type age enroll_age7to12 enroll_age13to15 enroll_age13to15_SMP age7to12_pct_lastweek age13to15_pct_lastweek age7to12_pct_twoweeks age13to15_pct_twoweeks age7to12_85_twoweeks age13to15_85_twoweeks age_years

//Rename name these for uniformity when merging with other data sets
rename aid id
/*rename asup_cd sup_code
rename aedit_cd editor_code*/
sort id
compress
save children6to15years_w2, replace

*****
* School fees
*****

*** get current school
use Data\A,clear
keep aid adla04 adla05
tempfile temp1
sort aid
save `temp1', replace

use Data\A_DLA2type,clear

drop adla2type_v

sort aid
merge aid using `temp1', uniqusing
assert _merge != 1
keep if _merge == 3
drop _merge

* noramlize to be annual
g annualfee = adla28 if adla29 == 4
replace annualfee = adla28 * 2 if adla29 == 3
replace annualfee = adla28 * 11 if adla29 == 2
replace annualfee = adla28 * 210 if adla29 == 1 /*Approx num school days in Indonesia--verify*/
replace annualfee = adla28 / 6 if adla29 == 5 & (adla04 == 1 | adla04 == 2) /*primary school is 6 years*/
replace annualfee = adla28 / 3 if adla29 == 5 & (adla04 == 3 | adla04 == 4) /*middle school is 3 years*/
replace annualfee = adla28 / 3 if adla29 == 5 & (adla04 == 6 | adla04 == 6) /*high  school is 3 years*/
replace annualfee = adla28 / 6 if adla29 == 5 & (adla04 == 7) /*pesantren we will count as 6 years*/
replace annualfee = 0 if adla28 == 0


reshape wide annualfee adla28 adla29, i(aid adla04) j(adla2type)

g schoolfees = annualfee1 + annualfee2 + annualfee3 + annualfee4 + annualfee5 + annualfee6 + annualfee13
g schoolothercosts = annualfee7 + annualfee8 + annualfee9 + annualfee10 + annualfee11 + annualfee13
g schoolfeesspending = annualfee12

for var schoolfees schoolothercosts schoolfeesspending: g X_SD = X if adla04 == 1 | adla04 == 2
for var schoolfees schoolothercosts schoolfeesspending: g X_SMP = X if adla04 == 3 | adla04 == 4
keep aid school*

ren aid id
sort id 
merge id using children6to15years_w2
tab _merge
assert _merge != 1
drop _merge


//Generating variables to look at panel individuals across waves
gen rid= substr(id,1,3) + "1" + substr(id,5,7)
sort rid
tempfile temp
save `temp', replace

use Data\R, clear

gen panel_hh = (rar00x == 1 | rar00x == 2)
gen panel_hh_id_w2 = substr(rid, 1,3) + substr(rid,5,7)

keep rid panel_hh panel_hh_id_w2 rar00x
sort rid

merge rid using `temp', uniqmaster _merge(_mx)
tab _mx
keep if _mx == 3

tempfile temp2
save `temp2'

***

use Data\R_AR_01, clear
duplicates drop

tostring rar00_07 rar00, replace format(%02.0f)
gen id = substr(rid,1,3) + "3" + substr(rid,5,7) + rar00

keep rar00 rar00_07 rar01a id

merge id using `temp2', sort _merge(_ind_roster_info_merge)
tab _ind_roster_info_merge
keep if _ind_roster_info_merge == 3


//Generating Variables for identification to check in merges
gen hh_serial_no_w2 = air01_cd
gen birth_year_w2 = air03_yy
gen birth_mon_w2 = air03_mm
gen birth_day_w2 = air03_dd
gen gender_w2 = air02

gen panel_id_w2 = id
gen art_split = substr(id,10,2)

**
replace panel_id_w2 = substr(panel_id,1,9) + "00" + rar00_07 if rar00_07 != "00" & rar00_07 != ""
sort panel_id_w2
**

keep if age_years >= 7 & age_years <= 15

gen ea_code = substr(id,1,3)

foreach x in 7to12 13to15{
	bys ea_code: egen tot_age`x'_kec = total(age_`x')

	gen age_`x'_crosssec = age_`x' if panel_hh == 0
	bys ea_code: egen tot_age`x'_kec_crosssec = total(age_`x'_crosssec)
}

foreach x in SD SMP{
	bys ea_code: egen tot_`x'_enroll_kec = total(enroll_`x')

	gen enroll_`x'_crosssec = enroll_`x' if panel_hh == 0
	bys ea_code: egen tot_`x'_enroll_kec_crosssec = total(enroll_`x'_crosssec)
}

gen gross_SD_enroll_kec = tot_SD_enroll_kec / tot_age7to12_kec
gen gross_SMP_enroll_kec = tot_SMP_enroll_kec / tot_age13to15_kec

gen gross_SD_enroll_kec_crsec = tot_SD_enroll_kec_crosssec / tot_age7to12_kec_crosssec
gen gross_SMP_enroll_kec_crsec = tot_SMP_enroll_kec_crosssec / tot_age13to15_kec_crosssec


foreach x of var enroll_age7to12 enroll_age7to12_SD enroll_age13to15 enroll_age13to15_SMP enroll_age13to15_other enroll_SD enroll_SMP gross_SD_enroll_kec gross_SMP_enroll_kec gross_SD_enroll_kec_crsec gross_SMP_enroll_kec_crsec age7to12_pct_lastweek age13to15_pct_lastweek age7to12_pct_twoweeks age13to15_pct_twoweeks age7to12_85_twoweeks age7to12_fullattend_twoweeks age13to15_85_twoweeks age13to15_fullattend_twoweeks cond_age13to15_pct_2wks{
	rename `x' `x'_w2
	} 

order id
sort id

compress
save children6to15years_w2,replace




