set more off
cd "Wave I"

local do_1_2_old_1_1 = 1
local do_1_3_old_1_2 = 1
local do_1_4_old_1_3 = 1


*****************************************************************************
//Creating indicators dataset for Table 1.2
*****************************************************************************
if `do_1_2_old_1_1' == 1{
use marriedwoman16to49years_w1, clear

//Combine the three data sets
append using children0to36months_w1
append using children6to15years_w1


label define obs_labelx 6 "Married Woman 16-49 years old" 7 "Child 0-36 months" 10 "Child 6-15 years old"
label values obs_type obs_labelx

//Generate additional ID numbers for future merges (substr_id = id for subdistrict 
foreach x of var id{
	gen subdistr_id=substr(`x',1,3)
	}

sort id

drop _merge*

//Generate household identification variable
gen HH_id= substr(id,1,3)+substr(id,5,5)
sort HH_id

tempfile indicators_1
save `indicators_1', replace

clear

****

use Data\R
keep rid rlk12


//Generate variable identifying kecamatan specifically
gen Location_ID=substr(rid,1,3) 

gen HH_id = substr(rid,1,3) + substr(rid,5,5) 
keep HH_id Location_ID rlk12

//Generate household type variable
rename rlk12 HH_type



****

sort HH_id
merge HH_id using `indicators_1', uniqmaster
tab _merge

drop if _merge==1
tab _merge
rename _merge _mergex


sort Location_ID
tempfile indicators_2
save `indicators_2', replace

****

use ..\kecs_info_clean
egen generasi = rowmax(gen_year1 gen_year2)
gen type = 3



gen kab_id = llk02_cd
gen prov_id = llk01_cd

keep Location_ID type kab_id prov_id
sort Location_ID

//Combine kecamatan type info with indicator info
merge Location_ID using `indicators_2', uniqmaster
tab _merge
drop if _merge==1
codebook id if _merge==2
tab _merge


sort Location_ID 


compress
save table_1_2_vars_w1, replace


//order id prov dist subd HH_id Location_ID obs_type tresp_nm tresp_cd tenum_nm tenum_cd  tedit_nm tedit_cd tsup_nm tsup_cd iresp_nm iresp_cd ienum_nm ienum_cd iedit_nm editor_code isup_nm sup_code  pre_natal_visits pre_natal_dummy iron_pills_dummy good_assisted_delivery post_natal_visits post_natal_dummy vitA_total vitA_per_year vitA_opp vitA_percent_uptake times_weighed_last2months visit_and_weigh_lastmonth imm_age_complete imm_total_complete imm_total_comp10month z_weightforage z_heightforage z_weightforheight _fwfl _flen _fwei notmal_weightforage mal_weightforage severe_weightforage  notmal_heightforage mal_heightforage severe_heightforage notmal_weightforheight mal_weightforheight severe_weightforheight days_open_lastweek days_attend_lastweek enroll_age7to12 enroll_age13to15 enroll_age13to15_middle percent_attended_lastweek age7to12_percent_lastweek age13to15_percent_lastweek percent_attended_twoweeks age7to12_percent_twoweeks age13to15_percent_twoweeks age7to12_85_twoweeks age13to15_85_twoweeks  gender height weight birth_date survey_date age

//Generasi only
keep if type==3
save table_1_2_vars_generasi_w1, replace
}


**********************************************************************************
//Creating indicators dataset for Table 1.3
*****************************************************************************
if `do_1_3_old_1_2' == 1{

use infant_mortality_w1, clear
gen obs_type = 1
tempfile infant_mortality
save `infant_mortality'

use infant_morbidity_w1, clear
gen obs_type = 2
tempfile infant_morbidity
save `infant_morbidity'

use children0to36months_w1, clear
drop obs_type
gen obs_type = 3


append using `infant_mortality'
append using `infant_morbidity'

tempfile temp_table
save `temp_table'

append using test_results_w1

label define obs_labelx 1 "Infant Mortality" 2 "Infant Morbidity" 3 "Nourishment" 4 "Test scores"
label values obs_type obs_labelx

sort id

drop _merge*

//Generate household identification variable
drop HH_id
gen HH_id= substr(id,1,3)+substr(id,5,5)
sort HH_id

tempfile indicators_a
save `indicators_a', replace

clear

use Data\R
duplicates drop rid, force


keep rid rlk12 



//Generate variable identifying kecamatan specifically
gen Location_ID=substr(rid,1,3)

gen HH_id = substr(rid,1,3) + substr(rid,5,5) 
keep HH_id Location_ID rlk12 

//Generate household type variable
rename rlk12 HH_type

sort HH_id
merge HH_id using `indicators_a', uniqmaster
tab _merge

drop if _merge==1

tab _merge
rename _merge _mergex


sort Location_ID
tempfile indicators_b
save `indicators_b', replace

use ..\kecs_info_clean
egen generasi = rowmax(gen_year1 gen_year2)
gen type = 3



gen ea = hhea
gen kab_id = llk02_cd
gen prov_id = llk01_cd

keep Location_ID type ea kab_id prov_id

sort Location_ID

//Combine kecamatan type info with indicator info
merge Location_ID using `indicators_b', uniqmaster
tab _merge
drop if _merge==1


sort Location_ID 

compress
save table_1_3_vars_w1, replace

**

use `temp_table', clear

append using test_results_generasi_w1

label define obs_labelx 1 "Infant Mortality" 2 "Infant Morbidity" 3 "Nourishment" 4 "Test scores"
label values obs_type obs_labelx

sort id

drop _merge*

//Generate household identification variable
drop HH_id
gen HH_id= substr(id,1,3)+substr(id,5,5)
sort HH_id

tempfile indicators_a
save `indicators_a', replace

clear

use Data\R
duplicates drop rid, force


keep rid  rlk12 



//Generate variable identifying kecamatan specifically
gen Location_ID=substr(rid,1,3)

gen HH_id = substr(rid,1,3) + substr(rid,5,5) 
keep HH_id Location_ID rlk12 

//Generate household type variable
rename rlk12 HH_type

sort HH_id
merge HH_id using `indicators_a', uniqmaster
tab _merge

drop if _merge==1

tab _merge
rename _merge _mergex


sort Location_ID
tempfile indicators_b
save `indicators_b', replace

use ..\kecs_info_clean
egen generasi = rowmax(gen_year1 gen_year2)
gen type = 3



gen ea = hhea
gen kab_id = llk02_cd
gen prov_id = llk01_cd

keep Location_ID type ea kab_id prov_id

sort Location_ID

//Combine kecamatan type info with indicator info
merge Location_ID using `indicators_b', uniqmaster
tab _merge
drop if _merge==1


sort Location_ID

keep if type == 3

save table_1_3_vars_generasi_w1, replace
}


*****************************************************************************
//Creating indicators dataset for Table 1.4
*****************************************************************************
if `do_1_4_old_1_3' == 1 {

***

***Women variables


//Fertility Rate Calculations & Info for who to include in Knowledge Question
use Data\I_RH07, clear

drop if irh08_yy < 2003
drop if irh08_yy >= .

//Generate child's birth months
gen birth_month_live_away=ym(irh08_yy, irh08_mm)

rename iid id
keep id birth_month_live_away
sort id

tempfile live_away
save `live_away'

use Data\I_RH13, clear


drop if irh13_mm >= .
drop if irh13_yy < 2003
drop if irh13_yy >= .

//Generate child's birth months
gen birth_month_live_died=ym(irh13_yy,irh13_mm)

rename iid id
keep id birth_month_live_died
sort id

tempfile live_died
save `live_died'

use Data\R_AR_01, clear

drop if rar04_mm >= .
drop if rar06 == 51 | rar06 == 52
drop if rar04_yy >= .

gen birth_month_live_in=ym(rar04_yy,rar04_mm)

//Generating mother's id for merge
tostring rar06, replace format(%02.0f) force
gen id = substr(rid,1,3) + "2" + substr(rid,5,7) + rar06
sort id

tempfile live_in
save `live_in'

use Data\R_AR_01, clear
//Generating panel id for merge across waves
tostring rar00, replace format(%02.0f) force
gen id = substr(rid,1,3) + "2" + substr(rid,5,7) + rar00
sort id

keep id rar04*
duplicates drop

tempfile panel_info
save `panel_info'



use Data\I, clear

rename iid id

gen rid = substr(id,1,3) + "1" + substr(id,5,5)

gen survey_month = ym(iivw_yy_1, iivw_mm_1) if ihkw_1==1 | ihkw_1==2
replace survey_month= ym(iivw_yy_2, iivw_mm_2) if survey_month==. & ihkw_2==1 | ihkw_2==2
replace survey_month= ym(iivw_yy_3, iivw_mm_3) if survey_month==. & ihkw_3==1 | ihkw_3==2

//Family Planning (restricted to age 15-45 years)
gen contr_receipt_month = ym(ikb04_yy,ikb04_mm)
gen contr_receipt_diff = survey_month - contr_receipt_month

gen family_planning = (ikb02 == 1 & ((ikb03 >=6 & ikb03 <= 9) | (ikb03 <=5 & contr_receipt_diff <= 6)))
replace family_planning = . if ikb03 <=5 & contr_receipt_diff == .

//Woman has role in decisions relating to kids
multparse isp01a isp01a
multparse isp01b isp01b
multparse isp01c isp01c
multparse isp01d isp01d

gen mom_child_decisions = ((isp01a_A == 1 | isp01a_W == 1) & (isp01b_A == 1 | isp01b_W == 1) & (isp01c_A == 1 | isp01c_W == 1) & (isp01d_A == 1 | isp01d_W == 1))
replace mom_child_decisions = . if isp01a_W == 1 & isp01b_W == 1 & isp01c_W == 1 & isp01d_W == 1

//Woman has role in decisions relating to purchases
gen mom_purch_decisions = ((isp02a == 1 | isp02a == 6) & (isp02b == 1 | isp02b == 6) & (isp02c == 1 | isp02c == 6) & (isp02d == 1 | isp02d == 6))
replace mom_purch_decisions = . if (isp02a == 6 & isp02b == 6 & isp02c == 6 & isp02d == 6) | (isp02a == . & isp02b == . & isp02c == . & isp02d == .)

sort id
merge id using `live_away', uniqmaster
tab _m
drop _m

gen elapse_live_away = survey_month - birth_month_live_away
gen live_birth_away_x = (elapse_live_away <= 12)
bys id: egen live_away_12 = max(live_birth_away_x)
drop elapse_live_away birth_month_live_away live_birth_away_x
duplicates drop

sort id
merge id using `live_died', uniqmaster
tab _m
drop _m

gen elapse_live_died = survey_month - birth_month_live_died
gen live_birth_died_x = (elapse_live_died <= 12)
bys id: egen live_died_12 = max(live_birth_died_x)
drop elapse_live_died birth_month_live_died live_birth_died_x
duplicates drop

sort id
merge id using `live_in', uniqmaster
tab _m
drop if _m == 2
drop _m


gen elapse_live_in = survey_month - birth_month_live_in
gen live_birth_in_x = (elapse_live_in <= 12)
bys id: egen live_in_12 = max(live_birth_in_x)

gen mom_0to3y_x = (elapse_live_in <= 36)
bys id: egen mom_0to3y = max(mom_0to3y_x)

drop elapse_live_in birth_month_live_in live_birth_in_x mom_0to3y_x
duplicates drop

gen live_birth_12mon = (live_away_12 == 1 | live_died_12 == 1 | live_in_12 == 1)

keep rid id live_birth_12mon mom_0to3y survey_month family_planning mom_child_decisions mom_purch_decisions
duplicates drop

sort id
merge id using `panel_info', sort
tab _m
drop if _m == 2
drop _m

sort rid
merge rid using Data\R, uniqusing
tab _m
drop if _m == 2
drop _m

gen birth_month = ym(rar04_yy,rar04_mm)
gen age_mon = survey_month - birth_month
gen age_years = floor(age_mon/12)

//Making restrictions on obs included
replace family_planning = . if age_years < 15 | age_years > 45
replace live_birth_12mon = . if age_years < 15 | age_years > 45

gen panel_id_w2 = substr(id,1,4) + substr(id,5,5) + "00" + substr(id,10,2) 
gen panel_id_w3 = substr(id,1,4) + substr(id,5,5) + "00" + "00" + substr(id,10,2)


**
sort panel_id*
**


keep rid id panel_id* age_years live_birth_12mon age_years family_planning mom_0to3y mom_child_decisions mom_purch_decisions
gen obs_type = 9

foreach x of var live_birth_12mon family_planning mom_child_decisions mom_purch_decisions{
	rename `x' `x'_w1
}

tempfile woman_fert_w1
save `woman_fert_w1'


use marriedwoman16to49years_w1, clear

bys id: gen counter = _n

gen prenatal_serv_num = 0

//Total number of services received
foreach x in 15a 15b 15c 15d 15e 15f 15g 15h 16 18{
	replace prenatal_serv_num = prenatal_serv_num + ich`x' if ich`x' == 1
}

//Quality of prenatal care services
replace prenatal_serv_num = . if ich15a == 8 & ich15b == 8 & ich15c == 8 & ich15d == 8 & ich15e == 8 & ich15f == 8 & ich15g == 8 & ich15h == 8
gen prenatal_serv_qual = prenatal_serv_num / 10
drop prenatal_serv_num

//Facility-based delivery
gen facility_deliv = (ich24 != 7 & ich24 != 8 & ich24 != 95)
replace facility_deliv = . if ich02 == 1 | ich02 == 2

//Excess prenatal visits (> 4 times)
gen excess_pre_natal = (pre_natal_visits_w1 > 4)
replace excess_pre_natal = . if pre_natal_visits_w1 >= .


keep rid id panel_id* prenatal_serv_qual facility_deliv excess_pre_natal

foreach x of var prenatal_serv_qual facility_deliv excess_pre_natal{
	rename `x' `x'_w1
}

gen obs_type = 6

tempfile women_w1
save `women_w1'

***

**Child 7-15 years variables


use children6to15years_w1, clear

//SMP transition rate
//Child in SMP grade 1 now and not repeated it before vs child graduated from SD last year but not in school now
gen SMP_transition = 1 if (adla04 == 3 | adla04 == 4) & adla05 == 1 & adla09 == 1 & adla08g == .
replace SMP_transition = 0 if (adla04 == 1 | adla04 == 2) & adla05 == 7 & adla10 == 2007

gen SMP_transition_def2 = 1 if (adla04 == 3 | adla04 == 4) & adla05 == 1 & adla09 == 1 & adla08g == .
replace SMP_transition_def2 = 0 if (adla04 == 1 | adla04 == 2) & (adla05 == 6 |adla05 == 7) & adla10 == 2007

//Hours worked in wage and households work in last week
gen hrs_work_wage = hrs_wage + hrs_wage_frac
replace hrs_work_wage = 0 if atka01 == 3 | atka02 == 3 | atka04 == 3
replace hrs_work_wage = . if hrs_work_wage > 70

gen hrs_work_fam = hrs_fam + hrs_fam_frac
replace hrs_work_fam = 0 if atka08 == 3 | atka09 == 3 | atka11 == 3
replace hrs_work_fam = . if hrs_work_fam > 70

gen hrs_work_home = hrs_home + hrs_home_frac
replace hrs_work_home = 0 if atka14 == 3 | atka15 == 3
replace hrs_work_home = . if hrs_work_home > 70

gen hrs_work_house = hrs_work_fam
replace hrs_work_house = hrs_work_fam + hrs_work_home if hrs_work_home != .
replace hrs_work_house = hrs_work_home if hrs_work_fam == .
replace hrs_work_house = . if hrs_work_fam > 70

gen hrs_work_wage_dummy = (hrs_work_wage > 0)
replace hrs_work_wage_dummy = . if hrs_work_wage >= .
gen hrs_work_house_dummy = (hrs_work_house > 0)
replace hrs_work_house_dummy = . if hrs_work_house >= .

//Distance to SMP attended in kilometers
destring adla13_nd, replace
gen SMP_distance = adla13_nd if enroll_SMP_w1 == 1
codebook adla13 if SMP_distance == . & enroll_SMP_w1 == 1

//Time spent one way to SMP
gen SMP_time_oneway = adla14_h + adla14_m / 60 if enroll_SMP_w1 == 1
codebook adla14 if SMP_time_oneway == . & enroll_SMP_w1 == 1

//Transportation cost one way to SMP
gen SMP_transcost_oneway = adla16_n if enroll_SMP_w1 == 1
codebook adla16 if SMP_transcost_oneway == . & enroll_SMP_w1 == 1

gen aid = id
sort aid

tempfile temp
save `temp'

//Hours of school per week
use Data\A_DLA1TYPE, clear

gen school_start = adla19_h
replace school_start = school_start + (adla19_m / 60) if adla19_m < .

gen school_end = adla20_h
replace school_end = school_end + (adla20_m / 60) if adla20_m < .

gen hours_school_day = school_end - school_start

bys aid: egen hrs_school = total(hours_school_day)
keep aid hrs_school

duplicates drop
sort aid
merge aid using `temp', sort
tab _merge
drop if _merge == 1
drop _m*

replace hrs_school = 0 if adla01 == 3 | adla09 == 3 
replace hrs_school = . if adla09 == 3 & (adla04 == 5 | adla04 == 6)
replace hrs_school = . if adla09 == 3 & ((adla04 == 3 | adla04 == 4) & adla05 == 7)
replace hrs_school = . if adla09 == 3 & ((adla04 == 3 | adla04 == 4) & adla05 == 98)
replace hrs_school = . if adla09 == 3 & adla04 == 98

gen hrs_school_enroll_only = hrs_school
replace hrs_school_enroll_only = . if (enroll_age7to12_w1 == 0 & age_7to12 == 1)| (enroll_age13to15_w1 == 0 & age_13to15 == 1)

gen dropout = 1 if adla09 == 3 & (adla10 == 2006 | adla10 == 2007)
replace dropout = 0 if adla09 == 1
replace dropout = 0 if adla09 == 3 & (adla04 == 5 | adla04 == 6)
replace dropout = 0 if adla09 ==3 & ((adla04 == 3 | adla04 == 4) & adla05 == 7)
replace dropout = . if adla09 ==3 & ((adla04 == 3 | adla04 == 4) & adla05 == 98)
replace dropout = . if adla09 == 3 & adla04 == 98

//Remaining missings either never went to school or still in kindergarten or dropped out more than 2 years before


keep rid id panel_id* age_years hrs_work_wage hrs_work_house hrs_work_wage_dummy hrs_work_house_dummy hrs_school hrs_school_enroll_only dropout SMP_transition SMP_transition_def2 SMP_distance SMP_time_oneway SMP_transcost_oneway
sort id


foreach x of var hrs_work_wage hrs_work_house hrs_work_wage_dummy hrs_work_house_dummy hrs_school hrs_school_enroll_only dropout SMP_transition SMP_transition_def2 SMP_distance SMP_time_oneway SMP_transcost_oneway{
	rename `x' `x'_w1
}

gen obs_type = 10

tempfile kids_6to15_w1
save `kids_6to15_w1'

*****
//Household migration

use Data\R, clear

duplicates drop rid, force

gen migrate_12_mons_hh_w1 = rar17_n
replace migrate_12_mons_hh_w1 = 0 if rar17 == 3


gen panel_hh_id_w2 = substr(rid,1,3) + substr(rid,5,5) + "00"
gen panel_hh_id_back_w2 = substr(rid,1,3) + substr(rid,5,5) + "00"

gen panel_hh_id_w3 = substr(rid,1,3) + substr(rid,5,5) + "00" + "00"
gen panel_hh_id_back_w3 = substr(rid,1,3) + substr(rid,5,5) + "00" + "00"

gen obs_type = 8

keep rid migrate_12_mons_hh_w1 panel_hh_id* obs_type
sort rid

tempfile households_w1
save `households_w1'


***
//BCG Scar Misreporting
use Data\T_IM1TYPE, clear

keep if tim1type == 1
duplicates drop

gen bcg_card_yes = 1 if tim08 == 1
replace bcg_card_yes = 0 if tim08 == 3
//replace bcg_card_yes = 0 if tim07 == 3

rename tid id
sort id
keep id bcg_card_yes
tempfile temp
save `temp'

use children0to36months_w1, clear
drop _m*
merge id using `temp', sort
tab _m
drop if _m == 2


gen bcg_mark = (tus05 == 1)
replace bcg_mark = . if tus05 >= 6

gen bcg_scar_misreport = 1 if (bcg_mark != bcg_card_yes)
replace bcg_scar_misreport = 0 if (bcg_mark == bcg_card_yes)
replace bcg_scar_misreport = . if (bcg_mark == . | bcg_card_yes == .)


//Breastfeeding within 1 hr
gen breastfed_1hr = 0 if tna01 == 3
replace breastfed_1hr = 1 if tna02_1 < 60
replace breastfed_1hr = 1 if tna02_2 == 1
replace breastfed_1hr = 0 if tna02_2 > 1 & tna02_2 < .
replace breastfed_1hr = 0 if tna02_3 > 0 & tna02_3 < .

//Exlusive breastfeeding up to 3 months

gen exclusive_breastfed = 0 if tna01 == 3
replace exclusive_breastfed = 1 if tna03 == 6
replace exclusive_breastfed = 1 if tna03_n >= 3
replace exclusive_breastfed = . if tna05_u == 8 | tna06_u == 8
replace exclusive_breastfed = . if tna03 == 8
replace exclusive_breastfed = 0 if tna03_n <= 2
replace exclusive_breastfed = 0 if tna05_u == 1 | (tna05_u == 2 & tna05_n <= 13) | (tna05_u == 3 & tna05_n <= 3)
replace exclusive_breastfed = 0 if tna06_u == 1 | (tna06_u == 2 & tna06_n <= 13) | (tna06_u == 3 & tna06_n <= 3)
**XX Added the tna05_n <= 13 , tna06_n <= 16**

//Excess Vitamin A (received > 100%)
gen excess_vit_A = (vitA_uptak_percent_w1 > 1)
replace excess_vit_A = . if vitA_uptak_percent_w1 >= .


keep id rid panel_id* breastfed_1hr exclusive_breastfed bcg_scar_misreport excess_vit_A

foreach x of var breastfed_1hr exclusive_breastfed bcg_scar_misreport excess_vit_A{
	rename `x' `x'_w1
}

gen obs_type = 7

tempfile child_0to36_w1
save `child_0to36_w1'


***

//School dropout

use Data\S_DS4TYPE, clear

egen dropouts = rowtotal(sds17a sds17b)
replace dropouts = . if sds17a >= . & sds17b >= .
bys sid: egen min_dropouts = min(dropouts)
bys sid: egen dropouts_0607_school = total(dropouts)
replace dropouts_0607_school = . if min_dropouts >= .

keep sid dropouts_0607_school
duplicates drop
sort sid

sort sid
merge sid using Data\S, sort
tab _m

keep sid dropouts_0607_school 

foreach x of var dropouts_0607_school{
	rename `x' `x'_w1
}

gen obs_type = 3

sort sid
tempfile schools
save `schools'

//Schools attendance overreporting

use Data\S_AS1TYPE, clear

bys sid: egen num_students_count = total(sas10)
keep sid num_students_count
duplicates drop

sort sid
tempfile temp_school_num
save `temp_school_num'

use Data\S_DS3TYPE, clear

egen students = rowtotal(sds14a sds14b)
bys sid: egen num_students_report = total(students)
keep sid num_students_report
duplicates drop

sort sid
merge sid using `temp_school_num', sort
keep if _m == 3
drop _m

gen SMP_overreport_logs_w1 = log(num_students_report) - log(num_students_count)
keep sid SMP_overreport_logs_w1

sort sid
merge sid using `schools', sort
tab _m
drop _m

tempfile schools_w1
save `schools_w1'



******************************************************

append using `households_w1'
append using `woman_fert_w1'
append using `women_w1'
append using `kids_6to15_w1' 
append using `child_0to36_w1'


label define obs_labelx 1 "Puskesmas" 2 "Bidan" 3 "School" 4 "Posyandu" 5 "Desa" 6 "Married Woman 16-49 years" 7 "Child 0-36 months" 8 "Household" 9 "Woman" 10 "Child 6-15 years" 11 "Child 16-18 years" 
label values obs_type obs_labelx

order id rid sid panel_id* *_w1 age_years


gen ea = substr(rid,1,3)
replace ea = substr(sid,1,3) if obs_type == 3

rename ea ea_code

sort rid

tempfile temp
save `temp'

use Data\R, clear

keep rid rlk12
rename rlk12 HH_type
sort rid
merge rid using `temp', uniqmaster
tab _m obs_type, m
drop if _m == 1
drop _m

gen Location_ID = substr(rid,1,3)
sort Location_ID

tempfile temp
save `temp'

use ..\kecs_info_clean
egen generasi = rowmax(gen_year1 gen_year2)
gen type = 3



gen kab_id = llk02_cd
gen prov_id = llk01_cd

keep Location_ID type kab_id prov_id
sort Location_ID

merge Location_ID using `temp', uniqmaster
tab _m obs_type, m
drop if _m == 1
drop _m

save table_1_4_vars_w1, replace

//Generasi only
keep if type == 3

save table_1_4_vars_generasi_w1, replace

}
