clear
set more off

cd "Wave II"

local do_1_1_old_2_3 = 1
local do_1_2_old_1_1 = 1
local do_1_3_old_1_2 = 1
local do_1_4_old_1_3 = 1



*****************************************************************************
//Creating indicators dataset for Table 1.1
*****************************************************************************

if `do_1_1_old_2_3' == 1 {



set more off
cd ..\
cd "Wave II"


**********************************************************
**Linking individuals (kids and women) across waves info
**********************************************************

use Data\R_AR_01, clear
duplicates drop

tostring rar00_07 rar00, replace format(%02.0f)
gen id = substr(rid,1,3) + "2" + substr(rid,5,7) + rar00
gen obs_type = 6

keep rar00 rar00_07 rar01a id obs_type rid

sort id obs_type
tempfile women_merge
save `women_merge'

replace id = substr(id,1,3) + "4" + substr(id,5,7) + rar00
replace obs_type = 7

sort id obs_type
tempfile kids0to36_merge
save `kids0to36_merge'

replace id = substr(id,1,3) + "3" + substr(id,5,7) + rar00
replace obs_type = 10

sort id obs_type

tempfile kids6to15_merge
save `kids6to15_merge'


*******************



***School direct benefit Variables for Kids 6-15y

use Data\A_DLA23, clear

//Keeping 2007/2008 info (dropping 2006/2007 info)
keep if adla23_line == 2

egen scholarship_ed = rowtotal(adla25_a adla25_d adla25_e)
**Missings for each subgroup are equivalent to zero
**If check egen total = rowtotal(adla25_a-adla25_v) is never missing if indicate receive some scholarship
replace scholarship_ed = 0 if adla23 == 3
replace scholarship_ed = . if adla23 == 8
replace scholarship_ed = . if (adla25_a > . & adla25_d > . & adla25_e > .)


gen uniforms = adla25_c
replace uniforms = 0 if adla23 == 3
replace uniforms = 0 if adla25_c == .
replace uniforms = . if adla23 == 8
replace uniforms = . if adla25_c > .

egen other_school_suppl = rowtotal(adla25_b adla25_f)
replace other_school_suppl = 0 if adla23 == 3
replace other_school_suppl = . if adla23 == 8
replace other_school_suppl = . if (adla25_b > . & adla25_f > .)

gen transport = adla25_g
replace transport = 0 if adla23 == 3
replace transport = 0 if adla25_g == .
replace transport = . if adla23 == 8
replace transport = . if adla25_g > .

egen other_school = rowtotal(adla25_h adla25_v)
replace other_school = 0 if adla23 == 3
replace other_school = . if adla23 == 8
replace other_school = . if (adla25_h > . & adla25_v > .)

gen PMT_school = adla25_i
replace PMT_school = 0 if adla23 == 3
replace PMT_school = 0 if adla25_i == .
replace PMT_school = . if adla23 == 8
replace PMT_school = . if adla25_i > .

keep aid scholarship_ed uniforms other_school_suppl transport other_school PMT_school

gen obs_type = 10

sort aid
merge aid using "Data\A", sort
tab _m
drop if _m == 2

**Excluding those who not currently in school, never went to school, or kindgergarten
tab _m if adla01 != 3 & adla09 != 3 & adla04 != 96 & air04b != 1 & air04b != 4

foreach x of var scholarship_ed uniforms other_school_suppl transport other_school PMT_school{
	replace `x' = 0 if adla01 == 3 | adla09 == 3 | adla04 == 96 | air04b == 1 | air04b == 4
	gen `x'_dum = 1 if `x' > 0 & `x' < .
	replace `x'_dum = 0 if `x' == 0
	rename `x' `x'_w2
	rename `x'_dum `x'_dum_w2
}

//Replace missing days with 15 if neither month nor year values for children's birth dates missing
replace air03_dd=15 if air03_dd==. & air03_mm!=. & air03_yy!=.

//Replace nonleap year February 29's with February 28's
replace air03_dd=28 if air03_dd==29 & air03_mm==2 & air03_yy!=1992 & air03_yy!=1996 & air03_yy!=2000

//Generate child's birth dates
gen birth_date=mdy(air03_mm,air03_dd,air03_yy)

//Generate survey dates using first survey attempt with at least partial completion
gen survey_date=mdy(aivw_mm_1, aivw_dd_1, aivw_yy_1) if ahkw_1==1 | ahkw_1==2
replace survey_date=mdy(aivw_mm_2, aivw_dd_2, aivw_yy_2) if survey_date==. & (ahkw_2==1 | ahkw_2==2)
replace survey_date=mdy(aivw_mm_3, aivw_dd_3, aivw_yy_3) if survey_date==. & (ahkw_3==1 | ahkw_3==2)

//codebook survey_date

//Generate child's age at time of survey
gen age = survey_date - birth_date
gen age_years = floor(age / 365.25)
gen age_mons = floor(age/ 30.4375)

//Generate primary school enrollment dummy (non-age restricted)
gen enroll_SD = .
replace enroll_SD = 1 if adla09 == 1 & (adla04 == 1 | adla04 == 2)
replace enroll_SD = 0 if adla01 == 3
replace enroll_SD = 0 if adla04 == 96
replace enroll_SD = 0 if adla09 == 1 & adla04 != 1 & adla04 != 2
replace enroll_SD = 0 if adla09 == 3
replace enroll_SD = 0 if (air04b == 1 | air04b == 4)

//Generate middle school enrollment dummy (non-age restricted)
gen enroll_SMP = .
replace enroll_SMP = 1 if adla09 == 1 & (adla04 == 3 | adla04 == 4)
replace enroll_SMP = 0 if adla01 == 3
replace enroll_SMP = 0 if adla04 == 96
replace enroll_SMP = 0 if adla09 == 1 & adla04 != 3 & adla04 != 4
replace enroll_SMP = 0 if adla09 == 3
replace enroll_SMP = 0 if (air04b == 1 | air04b == 4)

//Generate age 7-12 dummy
gen age_7to12 = (age_years >=7 & age_years <=12)
replace age_7to12 = . if age_years == .

//Generate age 13-15 dummy
gen age_13to15 = (age_years >=13 & age_years <=15)
replace age_13to15 = . if age_years == .


gen panel = (acov3 == 1)
gen ea_code = substr(aid,1,3)

gen rid = substr(aid,1,3) + "1" + substr(aid,5,7)

order aid rid panel ea_code *_w2 obs_type age_years enroll_SD enroll_SMP
keep aid rid panel ea_code *_w2 obs_type age_years enroll_SD enroll_SMP

************
gen id 	= aid if obs_type == 10

sort id obs_type
merge id obs_type using `kids6to15_merge', uniqmaster _merge(_ind_roster_info_merge1)
tab _ind_roster_info_merge1 obs_type, m
drop if _ind_roster_info_merge1 == 2

*********



tempfile info_scholarships_kid6to15
save `info_scholarships_kid6to15'


************


**************************************************
**Posyandu direct benefit variables for kids 0-36m
**************************************************

use Data\T, clear

gen PMT_pos = 1 if tpos17 == 1
replace PMT_pos = 0 if tpos17 == 3 |tpos01 == 3

gen PMT_intensive = 0 
replace PMT_intensive = 1 if tpos18_u == 1 & tpos18_n >= 1 & tpos18_n < .
replace PMT_intensive = 1 if tpos18_u == 2 & tpos18_n >= 1 & tpos18_n < .
replace PMT_intensive = 1 if tpos18_u == 3 & tpos18_n >= 4 & tpos18_n < .
replace PMT_intensive = . if (PMT_pos == 1 | PMT_pos == .) & tpos18_u >= .

tab PMT*, m

//Replace missing days with 15 if neither month nor year values for children's birth dates missing
replace tir03_dd=15 if tir03_dd==. & tir03_mm!=. & tir03_yy!=.

//Replace nonleap year February 29's with February 28's
replace tir03_dd=28 if tir03_dd==29 & tir03_mm==2 & tir03_yy!=2004

//Generate child's birth dates
gen birth_date=mdy(tir03_mm,tir03_dd,tir03_yy)

//Investigate survey date information
//tab tivw_yy_1, missing
//tab tivw_mm_1, missing
//tab tivw_dd_1, missing
//tab tivw_yy_2, missing
//tab tivw_yy_3, missing
//list tid thkw_1 thkw_2 thkw_3 tivw_yy_1 tivw_yy_2 tivw_yy_3 if thkw_1!=1 & thkw_1!=2

//Generate survey dates using first survey attempt with at least partial completion
gen survey_date=mdy(tivw_mm_1, tivw_dd_1, tivw_yy_1) if thkw_1==1 | thkw_1==2
replace survey_date=mdy(tivw_mm_2, tivw_dd_2, tivw_yy_2) if survey_date==. & thkw_2==1 | thkw_2==2
replace survey_date=mdy(tivw_mm_3, tivw_dd_3, tivw_yy_3) if survey_date==. & thkw_3==1 | thkw_3==2

gen survey_month = ym(tivw_yy_1, tivw_mm_1) if thkw_1==1 | thkw_1==2
replace survey_month= ym(tivw_yy_2, tivw_mm_2) if survey_date==. & thkw_2==1 | thkw_2==2
replace survey_month= ym(tivw_yy_3, tivw_mm_3) if survey_date==. & thkw_3==1 | thkw_3==2

//codebook survey_date

//Generate child's age at time of survey
gen age = survey_date - birth_date
gen age_years = floor(age / 365.25)
gen age_mons = floor(age/ 30.4375)


gen obs_type = 7
gen ea_code = substr(tid,1,3)
gen panel = (tcov3 == 1)

foreach x of var PMT_pos PMT_intensive{
	rename `x' `x'_w2
}

gen rid = substr(tid,1,3) + "1" + substr(tid,5,7)

order tid rid panel ea_code *_w2 obs_type age_years
keep tid rid panel ea_code *_w2 obs_type age_years


************
gen id 	= tid if obs_type == 7

sort id obs_type
merge id obs_type using `kids0to36_merge', uniqmaster _merge(_ind_roster_info_merge2)
tab _ind_roster_info_merge2 obs_type, m
drop if _ind_roster_info_merge2 == 2

*********

tempfile info_pos_kid0to36
save `info_pos_kid0to36'




**************************************************
**Mother direct benefit variables for women 16-49y
**************************************************

//Pregnancy in the last 18 months
use births_18_okay_w2,clear
keep iid
duplicates drop
sort iid
tempfile preg_last18
save `preg_last18' 

use Data\I, clear
sort iid
merge iid using `preg_last18', sort
tab _m
gen preg_18mon = (_m == 3)
drop _m

**Dropping if not have pregnancy within the last 24 months
drop if irh01b == 3
drop if ich01 == 6


gen health_subs = ich42
replace health_subs = 0 if ich36 == 3 | ich38 == 3

codebook health_subs if ich36 != 8
**Missings okay

gen deliv_subs = ich50
replace deliv_subs = 0 if ich44 == 3 | ich46 == 3

//Only obs with pregnancy which resulted in live birth within last 18 months & not indicate Tidak Tahu 
codebook deliv_subs if ich43 == 1 & ich44 != 8
**Missings okay

//Want delivery subsidies only for births in last 18 months
replace deliv_subs = . if preg_18mon != 1


gen obs_type = 6
gen ea_code = substr(iid,1,3)
gen panel = (icov3 == 1)

foreach x of var health_subs deliv_subs{
	gen `x'_dum = 1 if `x' > 0 & `x' < .
	replace `x'_dum = 0 if `x' == 0
	rename `x' `x'_w2
	rename `x'_dum `x'_dum_w2
}


gen rid = substr(iid,1,3) + "1" + substr(iid,5,7)

order iid rid panel ea_code *_w2 obs_type
keep iid rid panel ea_code *_w2 obs_type

**********

gen id = iid if obs_type == 6

sort id obs_type
merge id obs_type using `women_merge', uniqmaster _merge(_ind_roster_info_merge3)
tab _ind_roster_info_merge3 obs_type, m
drop if _ind_roster_info_merge3 == 2



*****************************************
*****************************************

append using `info_scholarships_kid6to15'
append using `info_pos_kid0to36'

label define obs_labelx 1 "Puskesmas" 2 "Bidan" 3 "School" 4 "Posyandu" 5 "Desa" 6 "Married Woman 16-49 years" 7 "Child 0-36 months" 8 "Household" 9 "Woman" 10 "Child 6-15 years"
label values obs_type obs_labelx

order iid tid aid rid ea_code obs_type *_w2 panel

sort rid
tempfile xx
save `xx'

***************************************
use Data\R, clear

//Generate household type variable
rename rlk12 HH_type

keep rid HH_type rar00x
sort rid

merge rid using `xx', uniqmaster
tab _m
drop if _m == 1
drop _m

***************************************


gen panel_id = id
gen art_split = substr(id,10,2)

**
replace panel_id = substr(panel_id,1,9) + "00" + rar00_07 if rar00_07 != "00" & rar00_07 != ""
sort panel_id
**

***************************************

drop _ind_roster_info_merge*
order iid tid aid rid id ea_code obs_type *_w2 panel age_years enroll_SD enroll_SMP
keep iid tid aid rid id ea_code obs_type *_w2 panel* rar00x HH_type age_years enroll_SD enroll_SMP

gen wave = 2

save table_1_1_vars_w2, replace
}


*****************************************************************************
//Creating indicators dataset for Table 1.2
*****************************************************************************

if `do_1_2_old_1_1' == 1 {
use marriedwoman16to49years_w2, clear

//Combine the three data sets
append using children0to36months_w2
append using children6to15years_w2


label define obstype_labelx 6 "Married Woman 16-49 years old" 7 "Child 0-36 months" 10 "Child 6-15 years old"
label values obs_type obstype_labelx


//Generate additional ID numbers for future merges (substr_id = id for subdistrict (BUT does not uniquely identify, need district & province code, etc. ; village_id = id for village)
foreach x of var id{
	gen subdistr_id=substr(`x',1,3)
}

sort id

drop _merge*

//Generate household identification variable
gen HH_id= substr(id,1,3)+substr(id,5,7)
sort HH_id

tempfile indicators_1
save `indicators_1', replace

clear

use Data\R
keep rid rlk12 rar00x


//Generate variable identifying kecamatan specifically
gen Location_ID = substr(rid,1,3)

gen HH_id = substr(rid,1,3) + substr(rid,5,7) 
keep HH_id Location_ID rlk12 rar00x

//Generate household type variable
rename rlk12 HH_type



sort HH_id
merge HH_id using `indicators_1', uniqmaster
tab _merge

drop if _merge==1

tab _merge
rename _merge _mergex


sort Location_ID
tempfile indicators_2
save `indicators_2', replace

use ..\kecs_info_clean
egen generasi = rowmax(gen_year1 gen_year2)
gen type = 3



gen kab_id = llk02_cd
gen prov_id = llk01_cd

keep Location_ID type kab_id prov_id
sort Location_ID

//Combine kecamatan type info with indicator info
merge Location_ID using `indicators_2', uniqmaster
tab _merge
drop if _merge==1


sort Location_ID 

compress
save table_1_2_vars_w2, replace
}

*****************************************************************************
//Creating indicators dataset for Table 1.3
*****************************************************************************
if `do_1_3_old_1_2' == 1 {

use infant_mortality_w2, clear
gen obs_type = 1
tempfile infant_mortality
save `infant_mortality'

use infant_morbidity_w2, clear
gen obs_type = 2
tempfile infant_morbidity
save `infant_morbidity'

use children0to36months_w2, clear
drop obs_type
gen obs_type = 3

**rename mal_weightforage_age0to1 mal_weightforage_age0to1_w2

append using `infant_mortality'
append using `infant_morbidity'

label define obs_labelx 1 "Infant Mortality" 2 "Infant Morbidity" 3 "Nourishment"
label values obs_type obs_labelx

sort id

drop _merge*

//Generate household identification variable
drop HH_id
gen HH_id= substr(id,1,3)+substr(id,5,7)
sort HH_id

tempfile indicators_a
save `indicators_a', replace

clear

use Data\R
keep rid rlk12 rar00x

//Generate variable identifying kecamatan specifically
gen Location_ID = substr(rid,1,3)

gen HH_id = substr(rid,1,3) + substr(rid,5,7) 
keep HH_id Location_ID rlk12 rar00x

//Generate household type variable
rename rlk12 HH_type

sort HH_id
merge HH_id using `indicators_a', uniqmaster
tab _merge

drop if _merge==1

tab _merge
rename _merge _mergex


sort Location_ID
tempfile indicators_b
save `indicators_b', replace

use ..\kecs_info_clean
egen generasi = rowmax(gen_year1 gen_year2)
gen type = 3



gen kab_id = llk02_cd
gen prov_id = llk01_cd

keep Location_ID type kab_id prov_id
sort Location_ID

//Combine kecamatan type info with indicator info
merge Location_ID using `indicators_b', uniqmaster
tab _merge
drop if _merge==1

sort Location_ID 

compress
save table_1_3_vars_w2, replace

}

*****************************************************************************
//Creating indicators dataset for Table 1.3
*****************************************************************************
if `do_1_4_old_1_3' == 1 {


***

***Women variables


//Fertility Rate Calculations & Info for who to include in Knowledge Question
use Data\I_RH07, clear

drop if irh08_yy == .
drop if irh08_yy < 2004

//Generate child's birth months
gen birth_month_live_away=ym(irh08_yy, irh08_mm)

rename iid id
keep id birth_month_live_away
sort id

tempfile live_away
save `live_away'

use Data\I_RH13, clear


drop if irh13_mm >= .
drop if irh13_yy < 2004

//Generate child's birth months
gen birth_month_live_died=ym(irh13_yy,irh13_mm)

rename iid id
keep id birth_month_live_died
sort id

tempfile live_died
save `live_died'

use Data\R_AR_01, clear

drop if rar04_mm >= .
drop if rar06 == 51 | rar06 == 52

gen birth_month_live_in=ym(rar04_yy,rar04_mm)

//Generating mother's id for merge
tostring rar06, replace format(%02.0f) force
gen id = substr(rid,1,3) + "2" + substr(rid,5,7) + rar06
sort id

tempfile live_in
save `live_in'

use Data\R_AR_01, clear

//Generating panel id for merge across waves
tostring rar00, replace format(%02.0f) force
gen id = substr(rid,1,3) + "2" + substr(rid,5,7) + rar00
sort id

keep id rar00_07 rar00 rar04*

tempfile panel_info
save `panel_info'



use Data\I, clear

rename iid id

gen rid = substr(id,1,3) + "1" + substr(id,5,7)

gen survey_month = ym(iivw_yy_1, iivw_mm_1) if ihkw_1==1 | ihkw_1==2
replace survey_month= ym(iivw_yy_2, iivw_mm_2) if survey_month==. & ihkw_2==1 | ihkw_2==2
replace survey_month= ym(iivw_yy_3, iivw_mm_3) if survey_month==. & ihkw_3==1 | ihkw_3==2

//Family Planning (restricted to age 15-45 years)
gen contr_receipt_month = ym(ikb04_yy,ikb04_mm)
gen contr_receipt_diff = survey_month - contr_receipt_month

gen family_planning = (ikb02 == 1 & ((ikb03 >=6 & ikb03 <= 9) | (ikb03 <=5 & contr_receipt_diff <= 6)))
replace family_planning = . if ikb03 <=5 & contr_receipt_diff == .

//Knowledge on breastfeeding and diarrhea (for women with kids under age 3 years)
gen q1 = 1 if ifks01_n >= 4 & ifks01_n < .
replace q1 = 0 if ifks01 == 8 | ifks01_n < 4

gen q2 = (ifks02 == 1)
gen q3 = (ifks03_n == 180)
gen q4 = (ifks04 == 1)
gen q5 = (ifks05 == 2)

egen q_sum = rowtotal(q1 q2 q3 q4 q5)
gen mother_knowledge = q_sum / 5

//Woman has role in decisions relating to kids
multparse isp01a isp01a
multparse isp01b isp01b
multparse isp01c isp01c
multparse isp01d isp01d

gen mom_child_decisions = ((isp01a_A == 1 | isp01a_W == 1) & (isp01b_A == 1 | isp01b_W == 1) & (isp01c_A == 1 | isp01c_W == 1) & (isp01d_A == 1 | isp01d_W == 1))
replace mom_child_decisions = . if isp01a_W == 1 & isp01b_W == 1 & isp01c_W == 1 & isp01d_W == 1

//Woman has role in decisions relating to purchases
gen mom_purch_decisions = ((isp02a == 1 | isp02a == 6) & (isp02b == 1 | isp02b == 6) & (isp02c == 1 | isp02c == 6) & (isp02d == 1 | isp02d == 6))
replace mom_purch_decisions = . if (isp02a == 6 & isp02b == 6 & isp02c == 6 & isp02d == 6) | (isp02a == . & isp02b == . & isp02c == . & isp02d == .)

sort id
merge id using `live_away', uniqmaster
tab _m
drop _m

gen elapse_live_away = survey_month - birth_month_live_away
gen live_birth_away_x = (elapse_live_away <= 12)
bys id: egen live_away_12 = max(live_birth_away_x)
drop elapse_live_away birth_month_live_away live_birth_away_x
duplicates drop

sort id
merge id using `live_died', uniqmaster
tab _m
drop _m

gen elapse_live_died = survey_month - birth_month_live_died
gen live_birth_died_x = (elapse_live_died <= 12)
bys id: egen live_died_12 = max(live_birth_died_x)
drop elapse_live_died birth_month_live_died live_birth_died_x
duplicates drop

sort id
merge id using `live_in', uniqmaster
tab _m
drop if _m == 2
drop _m

gen elapse_live_in = survey_month - birth_month_live_in
gen live_birth_in_x = (elapse_live_in <= 12)
bys id: egen live_in_12 = max(live_birth_in_x)

gen mom_0to3y_x = (elapse_live_in <= 36)
bys id: egen mom_0to3y = max(mom_0to3y_x)

drop elapse_live_in birth_month_live_in live_birth_in_x
duplicates drop

gen live_birth_12mon = (live_away_12 == 1 | live_died_12 == 1 | live_in_12 == 1)

keep rid id live_birth_12mon mom_0to3y survey_month icov3 family_planning mother_knowledge mom_child_decisions mom_purch_decisions
duplicates drop

sort rid
merge rid using Data\R, uniqusing
tab _m
drop if _m == 2
drop _m

sort id
merge id using `panel_info', sort
tab _m
drop if _m == 2
drop _m


gen birth_month = ym(rar04_yy,rar04_mm)
gen age_mon = survey_month - birth_month
gen age_years = floor(age_mon/12)

//Making restrictions on obs included
replace family_planning = . if age_years < 15 | age_years > 45
replace live_birth_12mon = . if age_years < 15 | age_years > 45
replace mother_knowledge = . if mom_0to3y != 1

tostring rar00_07 rar00, replace format(%02.0f)
gen panel_id_w2 = id
gen art_split = substr(id,10,2)
gen panel_hh_id_w2 = substr(rid, 1,3) + substr(rid,5,7)
gen panel_hh = (rar00x == 1 | rar00x == 2)
**
replace panel_id_w2 = substr(panel_id_w2,1,9) + "00" + rar00_07 if rar00_07 != "00" & rar00_07 != ""
sort panel_id_w2
**

gen panel_2007 = (icov3 == 1)

keep rid id panel_id panel_hh_id panel_hh age_years live_birth_12mon panel_2007 age_years family_planning mother_knowledge mom_0to3y mom_child_decisions mom_purch_decisions
gen obs_type = 9

foreach x of var live_birth_12mon family_planning mother_knowledge mom_child_decisions mom_purch_decisions{
	rename `x' `x'_w2
}

tempfile woman_fert_w2
save `woman_fert_w2'


use marriedwoman16to49years_w2, clear

bys id: gen counter = _n

gen prenatal_serv_num = 0

//Total number of services received
foreach x in 15a 15b 15c 15d 15e 15f 15g 15h 18{
	replace prenatal_serv_num = prenatal_serv_num + ich`x' if ich`x' == 1
}

//Quality of prenatal care services
replace prenatal_serv_num = . if ich15a == 8 & ich15b == 8 & ich15c == 8 & ich15d == 8 & ich15e == 8 & ich15f == 8 & ich15g == 8 & ich15h == 8
gen prenatal_serv_qual = prenatal_serv_num / 9
drop prenatal_serv_num

//Facility-based delivery
gen facility_deliv = (ich24 != 7 & ich24 != 8 & ich24 != 95)
replace facility_deliv = . if ich02 == 1 | ich02 == 2

//Excess prenatal visits (> 4 times)
gen excess_pre_natal = (pre_natal_visits_w2 > 4)
replace excess_pre_natal = . if pre_natal_visits_w2 >= .



keep rid id panel_id panel_hh_id panel_hh prenatal_serv_qual facility_deliv excess_pre_natal age_years panel_2007

foreach x of var prenatal_serv_qual facility_deliv excess_pre_natal{
	rename `x' `x'_w2
}

gen obs_type = 6

tempfile women_w2
save `women_w2'

***

**Child 7-15 years variables

use "..\Wave I\children6to15years_w1", clear
rename adla10 dropout_year_w1
keep panel_id_w2 dropout_year_w1
sort panel_id_w2

tempfile temp
save `temp'

use children6to15years_w2, clear

sort panel_id_w2
merge panel_id_w2 using `temp', sort
tab _merge
drop if _merge == 2
drop _merge

//SMP transition rate
//Child in SMP grade 1 now and not repeated it before vs child graduated from SD last year but not in school now
gen SMP_transition = 1 if (adla04 == 3 | adla04 == 4) & adla05 == 1 & adla09 == 1 & adla08g == .
replace SMP_transition = 0 if (adla04 == 1 | adla04 == 2) & adla05 == 7 & adla10 == 2008

gen SMP_transition_def2 = 1 if (adla04 == 3 | adla04 == 4) & adla05 == 1 & adla09 == 1 & adla08g == .
replace SMP_transition_def2 = 0 if (adla04 == 1 | adla04 == 2) & (adla05 == 6 |adla05 == 7) & adla10 == 2008

//Hours worked in wage and households work in last week
gen hrs_work_wage = hrs_wage + hrs_wage_frac
replace hrs_work_wage = 0 if atka01 == 3 | atka02 == 3 | atka04 == 3
replace hrs_work_wage = . if hrs_work_wage > 70

gen hrs_work_fam = hrs_fam + hrs_fam_frac
replace hrs_work_fam = 0 if atka08 == 3 | atka09 == 3 | atka11 == 3
replace hrs_work_fam = . if hrs_work_fam > 70

gen hrs_work_home = hrs_home + hrs_home_frac
replace hrs_work_home = 0 if atka14 == 3 | atka15 == 3
replace hrs_work_home = . if hrs_work_home > 70

gen hrs_work_house = hrs_work_fam
replace hrs_work_house = hrs_work_fam + hrs_work_home if hrs_work_home != .
replace hrs_work_house = hrs_work_home if hrs_work_fam == .
replace hrs_work_house = . if hrs_work_fam > 70

gen hrs_work_wage_dummy = (hrs_work_wage > 0)
replace hrs_work_wage_dummy = . if hrs_work_wage >= .
gen hrs_work_house_dummy = (hrs_work_house > 0)
replace hrs_work_house_dummy = . if hrs_work_house >= .


//Distance to SMP attended in kilometers
gen SMP_distance = adla13_n if enroll_SMP_w2 == 1
codebook adla13 if SMP_distance == . & enroll_SMP_w2 == 1

//Time spent one way to SMP
gen SMP_time_oneway = adla14_h + adla14_m / 60 if enroll_SMP_w2 == 1
codebook adla14 if SMP_time_oneway == . & enroll_SMP_w2 == 1

//Transportation cost one way to SMP
gen SMP_transcost_oneway = adla16_n if enroll_SMP_w2 == 1
codebook adla16 if SMP_transcost_oneway == . & enroll_SMP_w2 == 1

gen aid = id
sort aid

drop _m*

tempfile temp
save `temp'

//Hours of school per week
use Data\A_DLA1TYPE, clear

gen school_start = adla19_h
replace school_start = school_start + (adla19_m / 60) if adla19_m < .

gen school_end = adla20_h
replace school_end = school_end + (adla20_m / 60) if adla20_m < .

gen hours_school_day = school_end - school_start

bys aid: egen hrs_school = total(hours_school_day)
keep aid hrs_school

duplicates drop
sort aid
merge aid using `temp', sort
tab _merge
drop if _merge == 1
drop _m*


replace hrs_school = 0 if air04b == 1 | air04b == 4 | adla01 == 3 | adla09 == 3
replace hrs_school = . if adla09 == 3 & (adla04 == 5 | adla04 == 6)
replace hrs_school = . if adla09 == 3 & ((adla04 == 3 | adla04 == 4) & adla05 == 7)
replace hrs_school = . if adla09 == 3 & ((adla04 == 3 | adla04 == 4) & adla05 == 98)
replace hrs_school = . if adla09 == 3 & adla04 == 98

gen hrs_school_enroll_only = hrs_school
replace hrs_school_enroll_only = . if (enroll_age7to12_w2 == 0 & age_7to12 == 1)| (enroll_age13to15_w2 == 0 & age_13to15 == 1)


gen dropout = 1 if adla09 == 3 & (adla10 == 2007 | adla10 == 2008)
replace dropout = 1 if air04b == 4 & (adla10 == 2007 | adla10 == 2008)
replace dropout = 0 if adla09 == 1
replace dropout = 0 if adla09 == 3 & (adla04 == 5 | adla04 == 6)
replace dropout = 0 if adla09 ==3 & ((adla04 == 3 | adla04 == 4) & adla05 == 7)
replace dropout = . if adla09 ==3 & ((adla04 == 3 | adla04 == 4) & adla05 == 98)
replace dropout = . if adla09 == 3 & adla04 == 98

//Remaining missings either never went to school or still in kindergarten or dropped out more than 2 years before

keep rid id panel_id panel_hh_id panel_hh age_years hrs_work_wage hrs_work_house hrs_work_wage_dummy hrs_work_house_dummy hrs_school hrs_school_enroll_only dropout SMP_transition SMP_transition_def2 age_years SMP_distance SMP_time_oneway SMP_transcost_oneway panel_2007
sort id

foreach x of var hrs_work_wage hrs_work_house hrs_work_wage_dummy hrs_work_house_dummy hrs_school hrs_school_enroll_only dropout SMP_transition SMP_transition_def2 SMP_distance SMP_time_oneway SMP_transcost_oneway{
	rename `x' `x'_w2
}

gen obs_type = 10

tempfile kids_6to15_w2
save `kids_6to15_w2'

***

//High school enrollment (age 16-18)
use Data\R_AR_01, clear

tostring rar00, replace format(%02.0f)
gen id = substr(rid,1,3) + "3" + substr(rid,5,7) + rar00
sort id

gen birth_month = ym(rar04_yy,rar04_mm)

sort rid
merge rid using Data\R, uniqusing
tab _m
drop _m

gen survey_month = ym(rivw_yy_1, rivw_mm_1) if rhkw_1==1 | rhkw_1==2
replace survey_month= ym(rivw_yy_2, rivw_mm_2) if survey_month==. & rhkw_2==1 | rhkw_2==2
replace survey_month= ym(rivw_yy_3, rivw_mm_3) if survey_month==. & rhkw_3==1 | rhkw_3==2

gen age_month = survey_month - birth_month
gen age_years = floor(age_month/12)

tempfile temp
save `temp'

use Data\R_AR_48, clear
tostring rar48_cd, replace format(%02.0f)
gen id = substr(rid,1,3) + "3" + substr(rid,5,7) + rar48_cd
keep id
sort id

merge id using `temp', sort
tab _m

gen SMA_enroll = (_m == 3)
drop _m

keep if age_years >= 16 & age_years <= 18

sort rid
merge rid using Data\R, uniqusing
tab _m
drop if _m == 2

tostring rar00_07 rar00, replace format(%02.0f)
gen panel_id_w2 = id
gen art_split = substr(id,10,2)
gen panel_hh = (rar00x == 1 | rar00x == 2)
**
replace panel_id_w2 = substr(panel_id,1,9) + "00" + rar00_07 if rar00_07 != "00" & rar00_07 != ""
sort panel_id_w2
**

keep rid id panel_id panel_hh SMA_enroll age_years

rename SMA_enroll SMA_enroll_w2

gen obs_type = 11

tempfile kids_16to18_w2
save `kids_16to18_w2'

***

//Health services for curative care
use Data\R_MA, clear

tostring rma04_cd, replace format(%02.0f)
gen id = substr(rid,1,11) + rma04_cd
sort id

bys id: egen visit = rank(rma03)
keep id visit rid
sort id

tempfile temp
save `temp'

use Data\R_RJ2TYPE, clear

gen good_health_serv = (rrj06 != 10)

tostring rrj04_cd, replace format(%02.0f)
gen id = substr(rid,1,11) + rrj04_cd
sort id

bys id: egen visit = rank(rrj2type)

keep id visit good_health_serv
sort id

merge id visit using `temp', sort
tab _m
drop if _m == 1
replace good_health_serv = 0 if _m == 2
drop _m

gen count = 1
bys rid: egen num_sick = total(count)
bys rid: egen num_good_visit = total(good_health_serv)
gen health_service_use = num_good_visit / num_sick

keep rid health_service_use
duplicates drop
sort rid

merge rid using Data\R, sort
tab _m
drop if _m == 2
drop _m


keep rid health_service_use 
rename health_service_use health_service_use_w2

sort rid

tempfile housetemp
save `housetemp'

use Data\R, clear
duplicates drop rid, force

gen migrate_12_mons_hh_w2 = rar17_n
replace migrate_12_mons_hh_w2 = 0 if rar17 == 3

keep rid migrate_12_mons_hh_w2 rar00x
sort rid

merge rid using `housetemp', sort
tab _m
drop _m

gen obs_type = 8

gen panel_hh_id_w2 = substr(rid, 1,3) + substr(rid,5,7)
gen panel_hh = (rar00x == 1 | rar00x == 2)
gen panel_hh_id_back_w2 = substr(rid, 1,3) + substr(rid,5,5) + "00"


tempfile households_w2
save `households_w2'

***

//Breastfeeding within 1 hr

use children0to36months_w2, clear

gen breastfed_1hr = 0 if tna01 == 3
replace breastfed_1hr = 1 if tna02_1 < 60
replace breastfed_1hr = 1 if tna02_2 == 1
replace breastfed_1hr = 0 if tna02_2 > 1 & tna02_2 < .
replace breastfed_1hr = 0 if tna02_3 > 0 & tna02_3 < .

//Exlusive breastfeeding up to 3 months

gen exclusive_breastfed = 0 if tna01 == 3
replace exclusive_breastfed = 1 if tna03 == 6
replace exclusive_breastfed = 1 if tna03_n >= 3
replace exclusive_breastfed = . if tna05_u == 8 | tna06_u == 8
replace exclusive_breastfed = . if tna03 == 8
replace exclusive_breastfed = 0 if tna03_n <= 2
replace exclusive_breastfed = 0 if tna05_u == 1 | (tna05_u == 2 & tna05_n <= 13) | (tna05_u == 3 & tna05_n <= 3)
replace exclusive_breastfed = 0 if tna06_u == 1 | (tna06_u == 2 & tna06_n <= 13) | (tna06_u == 3 & tna06_n <= 3)
**XXIncluded the tna05_n <= 13, tna06_n <= 13 as an correction update, causes shift in mean at 0.0001

//Posyandu Quality

gen quality_pos = (tpos19 == 1)
replace quality_pos = . if tpos01 == 3 | tpos01 == .

//Excess Vitamin A (received > 100%)
gen excess_vit_A = (vitA_uptak_percent_w2 > 1)
replace excess_vit_A = . if vitA_uptak_percent_w2 >= .


keep id rid panel_id panel_hh_id panel_hh breastfed_1hr exclusive_breastfed quality_pos excess_vit_A age_years panel_2007

foreach x of var breastfed_1hr exclusive_breastfed quality_pos excess_vit_A{
	rename `x' `x'_w2
}

gen obs_type = 7

tempfile child_0to36_w2
save `child_0to36_w2'


***

//School dropout

use Data\S_DS4TYPE, clear

egen dropouts = rowtotal(sds17a sds17b)
replace dropouts = . if sds17a >= . & sds17b >= .
bys sid: egen min_dropouts = min(dropouts)
bys sid: egen dropouts_0708_school = total(dropouts)
replace dropouts_0708_school = . if min_dropouts >= .

keep sid dropouts_0708_school
duplicates drop
sort sid

tempfile temp
save `temp'

use Data\S_DS4ATYPE, clear

egen dropouts = rowtotal(sds17a_a sds17a_b)
replace dropouts = . if sds17a_a >= . & sds17a_b >= .
bys sid: egen min_dropouts = min(dropouts)
bys sid: egen dropouts_0809_school = total(dropouts)
replace dropouts_0809_school = . if min_dropouts >= .

keep sid dropouts_0809_school
duplicates drop
sort sid

merge sid using `temp', sort
tab _m
drop _m

sort sid
merge sid using Data\S, sort
tab _m

gen school_type = "SMP" if slk05 <= 3
replace school_type = "SD" if slk05 == 4 | slk05 == 5

keep sid dropouts_0708_school dropouts_0809_school school_type

foreach x of var dropouts_0708_school dropouts_0809_school{
	rename `x' `x'_w2
}

gen obs_type = 3

tempfile schools_w2
save `schools_w2'

**********



******************************************************


append using `woman_fert_w2'
append using `women_w2'
append using `kids_6to15_w2' 
append using `kids_16to18_w2'
append using `households_w2'
append using `child_0to36_w2'

label define obs_labelx 1 "Puskesmas" 2 "Bidan" 3 "School" 4 "Posyandu" 5 "Desa" 6 "Married Woman 16-49 years" 7 "Child 0-36 months" 8 "Household" 9 "Woman" 10 "Child 6-15 years" 11 "Child 16-18 years" 
label values obs_type obs_labelx

replace panel_hh_id_back_w2 = substr(rid, 1,3) + substr(rid,5,5) + "00" if rid != ""

order id rid sid panel_id panel_hh_id_back panel_hh *_w2 age_years

save table_1_4_vars_w2, replace
}
