set more off
clear

cd "Wave I"

//Load relevant variables for infant morbidity variables
use Data\T
rename tid id

//Replace missing days with 15 if neither month nor year values for children's birth dates missing
replace tir03_dd = 15 if tir03_dd == . & tir03_mm != . & tir03_yy != .

//Replace nonleap year February 29's with February 28's
replace tir03_dd = 28 if tir03_dd == 29 & tir03_mm == 2 & tir03_yy != 2004

//Generate child's birth dates
gen birth_date = mdy(tir03_mm,tir03_dd,tir03_yy)

//Investigate survey date information
//tab tivw_yy_1, missing
//tab tivw_mm_1, missing
//tab tivw_dd_1, missing
//tab tivw_yy_2, missing
//tab tivw_yy_3, missing
//list tid thkw_1 thkw_2 thkw_3 tivw_yy_1 tivw_yy_2 tivw_yy_3 if thkw_1 != 1 & thkw_1 != 2

//Generate survey dates using first survey attempt with at least partial completion
gen survey_date = mdy(tivw_mm_1, tivw_dd_1, tivw_yy_1) if thkw_1 == 1 | thkw_1 == 2
replace survey_date = mdy(tivw_mm_2, tivw_dd_2, tivw_yy_2) if survey_date == . & thkw_2 == 1 | thkw_2 == 2
replace survey_date = mdy(tivw_mm_3, tivw_dd_3, tivw_yy_3) if survey_date == . & thkw_3 == 1 | thkw_3 == 2

//Generate child's age at time of survey
gen age = survey_date - birth_date
gen age_mons = floor(age / 30.4375)
gen age_years = floor(age / 365.25)

list if age < 0
//Keeping only observations within desired age range (0-36 months)
keep if age >= 0 & age <= 1095.75


//Generate infant morbidity variables
gen Diarrhea = .
replace Diarrhea = 1 if tmaa01 == 1
replace Diarrhea = 0 if tmaa01 == 3

gen Fever = .
replace Fever = 1 if tmaa07 == 1
replace Fever = 0 if tmaa07 == 3

gen Cough = .
replace Cough = 1 if tmaa08 == 1
replace Cough = 0 if tmaa08 == 3

gen Cough_rapid_breath = .
replace Cough_rapid_breath = 1 if tmaa09 == 1
replace Cough_rapid_breath = 0 if tmaa09 == 3
replace Cough_rapid_breath = 0 if Cough == 0

gen ARI = .
replace ARI = 1 if Fever == 1 & Cough_rapid_breath == 1
replace ARI = 0 if Fever == 0 | Cough_rapid_breath == 0

gen Illness = .
replace Illness = 1 if Diarrhea == 1 | Fever == 1 | Cough == 1
replace Illness = 0 if Diarrhea == 0 & Fever == 0 & Cough == 0

gen diarrhea_or_ARI = .
replace diarrhea_or_ARI = 1 if Diarrhea == 1 | ARI == 1
replace diarrhea_or_ARI = 0 if Diarrhea == 0 & ARI == 0

//keep id age_mons Diarrhea Fever Cough Cough_rapid_breath ARI Illness
sort id
save infant_morbidity, replace

//Generate variable identifying household (absent of 4th digit specific to book) for future merges
gen HH_id= substr(id,1,3) + substr(id,5,5)
sort HH_id

tempfile infant_morb
save `infant_morb', replace

clear

use Data\R
keep rid 
//Generate variables identifying household and subdistrict for future merges
gen Location_ID= substr(rid,1,3)
gen HH_id = substr(rid,1,3) + substr(rid,5,5)
keep HH_id Location_ID 

//Drop misentered duplicates in HH_id
drop if HH_id=="65300601" & Location_ID=="5309073"
drop if HH_id=="65300602" & Location_ID=="5309073"
drop if HH_id=="65300605" & Location_ID=="5309073"

sort HH_id
merge HH_id using `infant_morb', uniqmaster
tab _merge


drop if _merge == 1
codebook id if _merge == 2
tab _merge
rename _merge _merge2

sort Location_ID
tempfile infant_morb2
save `infant_morb2', replace

use ..\kecs_info_clean
egen generasi = rowmax(gen_year1 gen_year2)
gen type = 3



gen kab_id = llk02_cd

keep Location_ID type kab_id

sort Location_ID

//Combine infant morbidity info with info on kecamatan type
merge Location_ID using `infant_morb2', uniqmaster
tab _merge
drop if _merge==1
codebook id if _merge==2
tab _merge

foreach x of var Cough Fever Diarrhea Cough_rapid_breath ARI Illness diarrhea_or_ARI{
	rename `x' `x'_w1
	}


//Generating variables to look panel individuals across waves
gen rid= substr(id,1,3) + "1" + substr(id,5,5)
sort rid
tempfile temp
save `temp', replace

use Data\R, clear

gen panel_hh_id_w2 = substr(rid, 1,3) + substr(rid,5,5) + "00"
gen panel_hh_id_back_w2 = substr(rid, 1,3) + substr(rid,5,5) + "00"

gen panel_hh_id_w3 = substr(rid, 1,3) + substr(rid,5,5) + "00" + "00"
gen panel_hh_id_back_w3 = substr(rid, 1,3) + substr(rid,5,5) + "00" + "00"

keep rid panel_hh_id* panel_hh_id_back*
sort rid

merge rid using `temp', uniqmaster _merge(_mx)
tab _mx
keep if _mx == 3

gen panel_id_w2 = substr(id,1,3) + substr(id,4,6) + "00" + substr(id,10,2)
gen panel_id_w3 = substr(id,1,3) + substr(id,4,6) + "00" + "00" + substr(id,10,2)
sort panel_id_w2

compress
save infant_morbidity_w1, replace

//Generasi only
keep if type==3
tab _merge
tab _merge2
drop _merge _merge2
save infant_morbidity_generasi_w1, replace

