set more off

cd "Wave I"


******************************************************************************************
//Creating mother level information on date of survey for use in determining children's ages
******************************************************************************************

use Data\I, clear


**Almost all survey dates are between Jun-Aug, 2007

//Generate survey dates using first survey attempt with at least partial completion
gen survey_date=mdy(iivw_mm_1, iivw_dd_1, iivw_yy_1) if ihkw_1==1 | ihkw_1==2
replace survey_date=mdy(iivw_mm_2, iivw_dd_2, iivw_yy_2) if survey_date==. & ihkw_2==1 | ihkw_2==2
replace survey_date=mdy(iivw_mm_3, iivw_dd_3, iivw_yy_3) if survey_date==. & ihkw_3==1 | ihkw_3==2

gen survey_mon = ym(iivw_yy_1, iivw_mm_1) if ihkw_1==1 | ihkw_1==2
replace survey_mon= ym(iivw_yy_2, iivw_mm_2) if survey_mon==. & ihkw_2==1 | ihkw_2==2
replace survey_mon= ym(iivw_yy_3, iivw_mm_3) if survey_mon==. & ihkw_3==1 | ihkw_3==2

gen survey_year = iivw_yy_1 if ihkw_1 == 1 | ihkw_1 == 2
replace survey_year = iivw_yy_2 if survey_year == . & ihkw_2 == 1 | ihkw_2 == 2
replace survey_year = iivw_yy_3 if survey_year == . & ihkw_3 == 1 | ihkw_3 == 2

gen survey_month_specif = iivw_mm_1 if ihkw_1 == 1 | ihkw_1 == 2
replace survey_month_specif = iivw_mm_2 if survey_year == . & ihkw_2 == 1 | ihkw_2 == 2
replace survey_month_specif = iivw_mm_3 if survey_year == . & ihkw_3 == 1 | ihkw_3 == 2

**June-August 2007 mostly (06-08)

tempfile survey_date_info
save `survey_date_info'


merge iid using Data\I_CH, uniqmaster
tab _m
tab ich01 _m, m
drop if _m == 1

//If ich03_cd is . means is not in household, still born, miscarriage, or live then died

codebook survey_date
//Only 7 obs missing the date


sort iid
tempfile pregnancy_last24months
save `pregnancy_last24months'


keep iid survey_date survey_month
duplicates drop
tempfile pregnancy_last24months_id
save `pregnancy_last24months_id'


***************************************************************************
//Get info on kids born and remained alive from I_CH 
***************************************************************************

use Data\I_CH, clear
rename iid id

//Keeping only live births
keep if ich02 == 4

//Generating the child level id number for merges using information from the household rosters
tostring(ich03_cd), gen(kid) format(%02.0f)
gen kid_id = substr(id,1,3) + "4" + substr(id,5,5) + kid
duplicates tag kid_id, gen(tagx)

//Dropping births alive and then died (tally elsewhere, where have age at death)
drop if ich03_cd == 52

//Merging using datasets created from marriedwomen16ot49years do file
sort kid_id
merge kid_id using kids_in_house, uniqusing _merge(kid_in_house_merge)
tab kid_in_house_merge


**All but 3 of the kids from household roster marked as being under 18 months merge in, so okay
tab live_in_house_18_ind kid_in_house, m
tab live_in_house_12to24_ind kid_in_house, m
tab live_in_house_21_ind kid_in_house, m
tab live_in_house_24_ind kid_in_house, m
tab live_in_house_12to21_ind kid_in_house, m

tab kid_id if live_in_house_18_ind == 1 & kid_in_house_merge == 2
tab kid_id if live_in_house_12to24_ind == 1 & kid_in_house_merge == 2
tab kid_id if live_in_house_21_ind == 1 & kid_in_house_merge == 2
tab kid_id if live_in_house_24_ind == 1 & kid_in_house_merge == 2
tab kid_id if live_in_house_12to21_ind == 1 & kid_in_house_merge == 2

tab live_in_house_18_ind live_in_house_over18_ind, m

**$$ Added this to look at
tab kid_in_house_merge if live_in_house_18_ind == 1 | live_in_house_12to24_ind == 1, m

drop if kid_in_house_merge == 2

sort kid_id
merge kid_id using kids_out_house, uniqusing _merge(kid_out_house_merge)
tab kid_out_house_merge

**Both children from household roster marked as being under 18 months merge in , so okay

**$$ Added this to look at
tab live_out_house_18_ind kid_out_house, m
tab live_out_house_12to24_ind kid_out_house, m
tab live_out_house_21_ind kid_out_house, m
tab live_out_house_24_ind kid_out_house, m
tab live_out_house_12to21_ind kid_out_house, m

tab kid_id if live_out_house_18_ind == 1 & kid_out_house_merge == 2
tab kid_id if live_out_house_12to24_ind == 1 & kid_out_house_merge == 2
tab kid_id if live_out_house_21_ind == 1 & kid_out_house_merge == 2
tab kid_id if live_out_house_24_ind == 1 & kid_out_house_merge == 2
tab kid_id if live_out_house_12to21_ind == 1 & kid_out_house_merge == 2

tab kid_out_house if live_out_house_18_ind == 1 | live_out_house_12to24_ind == 1, m

tab live_out_house_18_ind live_out_house_over18_ind, m

drop if kid_out_house_merge == 2


**All "" or "51" as would expect
**We have some 51
tab kid live_out_house, m
**All are non "", "51", or "52" as would expect
tab kid live_in_house, m


//For alive and in house
gen within_18 = 1 if live_in_house_18_ind == 1 & ich03_cd < 51
replace within_18 = 0 if live_in_house_over18_ind == 1 & ich03_cd < 51

gen between_12to24 = 1 if live_in_house_12to24_ind == 1 & ich03_cd < 51
gen within_24 = 1 if live_in_house_24_ind == 1 & ich03_cd < 51
gen within_21 = 1 if live_in_house_21_ind == 1 & ich03_cd < 51
gen between_12to21 = 1 if live_in_house_12to21_ind == 1 & ich03_cd < 51

//For alive and out of house
replace within_18 = 1 if live_out_house_18_ind == 1 & ich03_cd == 51
replace within_18 = 0 if live_out_house_over18_ind == 1 & ich03_cd == 51

replace between_12to24 = 1 if live_out_house_12to24_ind == 1 & ich03_cd == 51
replace within_24 = 1 if live_out_house_24_ind == 1 & ich03_cd == 51
replace within_21 = 1 if live_out_house_21_ind == 1 & ich03_cd == 51
replace between_12to21 = 1 if live_out_house_12to21_ind == 1 & ich03_cd == 51

rename id  mother_id
gen id = kid_id

**If mother_id_ind == 0 then "id" is kid's id, if mother_id_ind == 1 then "id" is mother's id 
gen mother_id_ind = 0
gen dead = 0
gen dead_0to28_days = 0
gen dead_0to12_mons = 0
gen dead_1to12_mons = 0
gen within_24_old_version = 1

 
**We have two observation which is neither out of household nor dead, but not match with live in household (now we have 86?????***)
drop if within_24 == .

tempfile kids_alive
save `kids_alive'


*********************************************************
//Get info on children born live but then died from I_RH
*********************************************************

use Data\I_RH13, clear

sort iid

**The survey dates are between June-Aug 2007, so any children born before June 2005 will be beyond 24 months
**We drop these observations for each of analysis below

**drop if irh13_yy < 2005
**$$this was 2006
keep if irh13_yy >= 2006 | (irh13_yy == 2005 & irh13_mm >= 6 & irh13_mm < .)

//Drop empty observations ("." versus ".y" distinguishes true empties, if any)
drop if irh13_yy == .

**Dropping values for which missing years (in final analysis should impute these values- according to Junko)
**Also, very unlikely to have forgotten the year if was within the last 2 years
drop if irh13_yy == .y 

sort iid
//Merge info on survey date
merge iid using `survey_date_info', uniqusing
tab _merge
keep if _merge == 3


//Generate birth month years
gen birth_mon = ym(irh13_yy, irh13_mm)
gen birth_year = irh13_yy

//Generate age in months at death
gen age_died_mon = 0 if irh15_u == 1 | irh15_u == 2 
replace age_died_mon = floor(ibh15_n/30.4735) if irh15_u == 3
replace age_died_mon = ibh15_n if irh15_u == 4
replace age_died_mon = 12*ibh15_n if irh15_u == 5

gen age_died_days = 0 if irh15_u == 1 | irh15_u == 2
replace age_died_days = ibh15_n if irh15_u == 3
replace age_died_days = 30.4375*ibh15_n if irh15_u == 4
replace age_died_days = 365.25*ibh15_n if irh15_u == 5

** Need to impute the missing months from birth_date_mon?
gen elapsed_mon = survey_mon - birth_mon

gen death_elapsed_diff = age_died_mon - elapsed_mon
tab death_elapsed, m


****



//Dealing with implausible age of death children
replace irh15_u = 4 if irh15_u == 5 & age_died_mon > elapsed_mon + 1 & ibh15_n >= 5

gen marker = 1 if irh15_u == 5 & ibh15_n == 1 & elapsed_mon < 12
replace irh15_u = 4 if marker == 1
replace ibh15_n = 11 if marker == 1

drop age_died* elapsed_mon death_elapsed_diff

//Generate age in months at death
gen age_died_mon = 0 if irh15_u == 1 | irh15_u == 2 
replace age_died_mon = floor(ibh15_n/30.4735) if irh15_u == 3
replace age_died_mon = ibh15_n if irh15_u == 4
replace age_died_mon = 12*ibh15_n if irh15_u == 5

gen age_died_days = 0 if irh15_u == 1 | irh15_u == 2
replace age_died_days = ibh15_n if irh15_u == 3
replace age_died_days = 30.4375*ibh15_n if irh15_u == 4
replace age_died_days = 365.25*ibh15_n if irh15_u == 5


gen elapsed_mon = survey_mon - birth_mon
gen death_elapsed_diff = age_died_mon - elapsed_mon
tab death_elapsed, m

//Dummy for whether okay to keep this obs or not, based on age/date info
**okay, b/c we expect the age of death to be less than the difference in time between birth and survey
**The obs which within a month, is 6 or 7 months, fine b/c >28 days and < 11 mons age of death, so category not affected
tab elapsed_mon age_died_mon if  death_elapsed_diff == 1, m
gen elapsed_death_okay = 1 if death_elapsed_diff <= 1



**the 2007 obs must be within 8 months of survey (b/c took place June-Aug 2007)
tab irh13_mm irh13_yy if elapsed_death_okay ==., m
tab age_died_days age_died_mon if irh13_yy == 2007 & irh13_mm == .y & elapsed_death_okay == .
replace elapsed_mon = 8 if irh13_yy == 2007 & irh13_mm == .y & elapsed_death_okay == .
replace age_died_mon = 8 if irh13_yy == 2007 & age_died_mon == 72 & irh13_mm == .y & elapsed_death_okay == .
replace age_died_days = 243.5 if irh13_yy == 2007 & age_died_mon == 72 & irh13_mm == .y & elapsed_death_okay == .
replace elapsed_death_okay = 1 if irh13_yy == 2007 & irh13_mm == .y & elapsed_death_okay == .

**the 2006 obs are most likely within 18 months of the survey (range from Dec 2005 - Feb 2006 or after to be included)
**definitely fall within 24 months, include in both to err on side of conservatism
replace elapsed_mon = 17 if irh13_yy == 2006 & irh13_mm == .y & elapsed_death_okay == .
replace elapsed_death_okay =1 if irh13_yy == 2006 & irh13_mm == .y & elapsed_death_okay == .

**XXAdded these 5 XX
**Correct 2006 obs which have age of death greater than time elapsed since birth
replace elapsed_death_okay = 1 if irh13_yy == 2006 & elapsed_mon == 18 & age_died_mon == 24
replace age_died_days = 60.875 if irh13_yy == 2006 & elapsed_mon == 18 & age_died_mon == 24
replace age_died_mon = 2 if irh13_yy == 2006 & elapsed_mon == 18 & age_died_mon == 24

replace elapsed_death_okay = 1 if irh13_yy == 2006 & elapsed_mon == 14 & age_died_mon == 48
replace age_died_days = 121.75 if irh13_yy == 2006 & elapsed_mon == 14 & age_died_mon == 48
replace age_died_mon = 4 if irh13_yy == 2006 & elapsed_mon == 14 & age_died_mon == 48

replace elapsed_death_okay = 1 if irh13_yy == 2006 & elapsed_mon == 15 & age_died_mon == 30
replace age_died_days = 456.5625 if irh13_yy == 2006 & elapsed_mon == 15 & age_died_mon == 30
replace age_died_mon = 15 if irh13_yy == 2006 & elapsed_mon == 15 & age_died_mon == 30

**Correct 2005 obs which have age of death greater than time elapsed since birth
replace elapsed_death_okay = 1 if irh13_yy == 2005 & elapsed_mon == 18 & age_died_mon == 36
replace age_died_days = 91.3125 if irh13_yy == 2005 & elapsed_mon == 18 & age_died_mon == 36
replace age_died_mon = 3 if irh13_yy == 2005 & elapsed_mon == 18 & age_died_mon == 36

replace elapsed_death_okay = 1 if irh13_yy == 2005 & elapsed_mon == 22 & age_died_mon == 27
replace age_died_days = 669.625 if irh13_yy == 2005 & elapsed_mon == 22 & age_died_mon == 27
replace age_died_mon = 22 if irh13_yy == 2005 & elapsed_mon == 22 & age_died_mon == 27
**XX**

**Making specific obs changes as suggested by Ben
replace age_died_mon = 3 if iid == "36820090202" & elapsed_death_okay == .
replace age_died_days = 91.3125 if iid =="36820090202" & elapsed_death_okay == .
replace elapsed_death_okay = 1 if iid == "36820090202" & elapsed_death_okay == .

replace age_died_mon = 2 if iid == "47320020405" & elapsed_death_okay == .
replace age_died_days = 60.875 if iid == "47320020405" & elapsed_death_okay == .
replace elapsed_death_okay = 1 if iid == "47320020405" & elapsed_death_okay == .

replace age_died_mon = 4 if iid == "47320020602" & elapsed_death_okay == .
replace age_died_days = 121.75 if iid == "47320020602" & elapsed_death_okay == .
replace elapsed_death_okay = 1 if iid == "47320020602" & elapsed_death_okay == .

replace age_died_mon = 4 if iid == "48220080202" & elapsed_death_okay == .
replace age_died_days = 121.75 if iid == "48220080202" & elapsed_death_okay == .
replace elapsed_death_okay = 1 if iid == "48220080202" & elapsed_death_okay == .

replace elapsed_mon = 23 if iid == "51520060302" & elapsed_death_okay == .
replace elapsed_death_okay = 1 if iid == "51520060302" & elapsed_death_okay == .

replace age_died_mon = 4 if iid == "53620060205" & elapsed_death_okay == .
replace age_died_days = 121.75 if iid == "53620060205" & elapsed_death_okay == .
replace elapsed_death_okay = 1 if iid == "53620060205" & elapsed_death_okay == .

replace age_died_mon = 6 if iid == "65720050402" & elapsed_death_okay == .
replace age_died_days = 182.625 if iid == "65720050402" & elapsed_death_okay == .
replace elapsed_death_okay = 1 if iid == "65720050402" & elapsed_death_okay == .

replace age_died_mon = 8 if iid == "44120030202" & elapsed_death_okay == .
replace age_died_days = 243.5 if iid == "44120030202" & elapsed_death_okay == .
replace elapsed_death_okay = 1 if iid == "44120030202" & elapsed_death_okay == .

replace age_died_mon = 10 if iid == "32820140402" & elapsed_death_okay == .
replace age_died_days = 304.375 if iid == "32820140402" & elapsed_death_okay == .
replace elapsed_death_okay = 1 if iid == "32820140402" & elapsed_death_okay == .

codebook elapsed_death_okay
codebook birth_mon birth_year if elapsed_death_okay == .


**the 2005 obs can't be within 18 months of the survey (need to be April, 2008 or after to be within 18 months)
**and most likely is not within 24 months of the survey (ambiguous anyway and would need to be June-Aug 2005)
replace elapsed_death_okay = 0 if irh13_yy == 2005 & elapsed_mon == .
**This not change anythign now because of way updated date related drops at start of file


**okay, b/c due to misentry of year/month category on survey, dealt with above
replace elapsed_death_okay = 1 if marker == 1

**okay, b/c not included in either of the mortality categories (0to28days, 0to12months)
replace elapsed_death_okay = 1 if age_died_mon > 12 & elapsed_mon> 24 & age_died_mon < . & elapsed_mon < .

**okay, b/c we know died under 12 months and occurred less than 18 months before, so category not affected
replace elapsed_death_okay = 1 if (age_died_mon >= 1 & age_died_mon < 12) & (elapsed_mon >= 1 & elapsed_mon <= 18)


tab elapsed_death_okay, m

tab death_elapsed if elapsed_death == 1, m
drop death_elapsed_diff
gen death_elapsed_diff = age_died_mon - elapsed_mon
tab death_elapsed if elapsed_death == 1, m

tab elapsed_mon age_died_mon if death_elapsed > 0, m



**XXdrop if == 0 line below included newXX**
drop if elapsed_death_okay == 0
drop marker elapsed_death_okay death_elapsed_diff

***

//Generate dummies for whether mother/child id and if dead/alive
gen mother_id_ind = 1
gen dead = 1


gen dead_0to28_days = 1 if age_died_days <= 28
replace dead_0to28_days = 0 if age_died_days > 28 & age_died_days < .

gen dead_0to12_mons = 1 if age_died_mon <= 12
replace dead_0to12_mons = 0 if age_died_mon > 12 & age_died_mon < .

gen dead_1to12_mons = 1 if age_died_mon >= 1 & age_died_mon <= 12
replace dead_1to12_mons = 0 if (age_died_mon < 1 |(age_died_mon > 12 & age_died_mon < .))

gen within_18 = 1 if elapsed_mon <= 18
replace within_18 = 0 if elapsed_mon > 18 & elapsed_mon < .
gen within_24 = 1 if elapsed_mon <= 24
replace within_24 = 0 if elapsed_mon > 24 & elapsed_mon < .
gen within_21 = 1 if elapsed_mon <= 21
replace within_21 = 0 if elapsed_mon > 21 & elapsed_mon < .


gen between_12to24 = 1 if elapsed_mon > 12 & elapsed_mon <= 24
replace between_12to24 = 0 if elapsed_mon <=12 | (elapsed_mon > 24 & elapsed_mon < .)
gen between_12to21 = 1 if elapsed_mon > 12 & elapsed_mon <= 21
replace between_12to21 = 0 if elapsed_mon <= 12 | (elapsed_mon > 21 & elapsed_mon < .)

gen born_2005 = (irh13_yy == 2005)


keep iid survey_mon birth_mon birth_year dead* mother_id age_died_mon age_died_days elapsed_mon survey_year within* between_12to24 between_12to21 born_2005
rename iid id
****

append using `kids_alive'


gen dead_0to28_days_last18 = dead_0to28_days if within_18 == 1
gen dead_0to12_mons_last24 = dead_0to12_mons if within_24 == 1
gen dead_0to12_mons_12to24 = dead_0to12_mons if between_12to24 == 1
gen dead_1to12_mons_last24 = dead_1to12_mons if within_24 == 1

gen dead_0to12_mons_last21 = dead_0to12_mons if within_21 == 1
gen dead_0to12_mons_12to21 = dead_0to12_mons if between_12to21 == 1

//Generate variable identifying household (absent of 4th digit specific to book) for future merges
gen HH_id= substr(id,1,3) + substr(id,5,5)
sort HH_id

tempfile infant_mortality_input
save `infant_mortality_input', replace


****

use Data\R, clear

gen panel_hh_id_w2 = substr(rid, 1,3) + substr(rid,5,5) + "00" 
gen panel_hh_id_back_w2 = substr(rid, 1,3) + substr(rid,5,5) + "00"

gen panel_hh_id_w3 = substr(rid, 1,3) + substr(rid,5,5) + "00" + "00"
gen panel_hh_id_back_w3 = substr(rid, 1,3) + substr(rid,5,5) + "00" + "00"


//Generate variables identifying household and subdistrict for future merges

gen Location_ID= substr(rid,1,3)
gen HH_id = substr(rid,1,3) + substr(rid,5,5)

keep HH_id Location_ID  panel_hh_id* panel_hh_id_back*

sort HH_id
merge HH_id using `infant_mortality_input', uniqmaster _merge(_m1)
tab _m1

drop if _m1 == 1
tab _m1

sort Location_ID
tempfile infant_mortality_input2
save `infant_mortality_input2', replace

use ..\kecs_info_clean
egen generasi = rowmax(gen_year1 gen_year2)
gen type = 3



gen kab_id = llk02_cd

keep Location_ID type kab_id

sort Location_ID

//Combine infant mortality info with info on kecamatan type
merge Location_ID using `infant_mortality_input2', uniqmaster _merge(_m2)
tab _m2
drop if _m2==1
tab _m2


//Generating variables to look panel individuals across waves
gen rid= substr(id,1,3) + "1" + substr(id,5,5)
gen panel_id_w2 = substr(kid_id,1,4) + substr(kid_id,5,5) + "00" + substr(kid_id,10,2) if kid_id != ""
gen panel_id_w3 = substr(kid_id,1,4) + substr(kid_id,5,5) + "00" + "00" + substr(kid_id,10,2) if kid_id != ""

order id panel_id_w2


foreach x of var dead_0to12_mons_last24 dead_1to12_mons_last24 dead_0to28_days_last18 dead_0to12_mons_12to24 dead_0to12_mons_last21 dead_0to12_mons_12to21{
	rename `x' `x'_w1
}
  
compress
save infant_mortality_w1, replace

//Generasi only
keep if type==3

save infant_mortality_generasi_w1, replace


