set more off

cd "Wave III"


******************************************************************************************
//Creating mother level information on date of survey for use in determining children's ages
******************************************************************************************

use Data\I, clear

duplicates drop


//Generate survey dates
gen survey_start_day = substr(istart_d,1,2)
destring survey_start_day, replace 
gen survey_start_mon = substr(istart_d,4,2)
destring survey_start_mon, replace 
gen survey_start_year = substr(istart_d,7,2)
destring survey_start_year, replace 
replace survey_start_year = survey_start_year + 2000

gen survey_finish_day = substr(ifinish_d,1,2)
destring survey_finish_day, replace 
gen survey_finish_mon = substr(ifinish_d,4,2)
destring survey_finish_mon, replace 
gen survey_finish_year = substr(ifinish_d,7,2)
destring survey_finish_year, replace 
replace survey_finish_year = survey_finish_year + 2000

gen survey_start_date=	mdy(survey_start_mon, survey_start_day, survey_start_year) 
gen survey_finish_date=	mdy(survey_finish_mon, survey_finish_day, survey_finish_year)
gen survey_days_elapse = survey_finish_date - survey_start_date

summ survey_days_elapse, d

gen survey_date = survey_start_date
gen survey_month = ym(survey_start_year, survey_start_mon) 
gen survey_year = survey_start_year

gen survey_m_specif = survey_start_mon

drop survey_start* survey_finish*


tempfile survey_date_info
save `survey_date_info'


merge iid using Data\I_CH, uniqmaster
tab _m
tab ich01 _m, m
drop if _m == 1

//If ich03_cd is . means is not in household, still born, miscarriage, or live then died



sort iid
tempfile pregnancy_last24months
save `pregnancy_last24months'


keep iid survey_date survey_month
duplicates drop
tempfile pregnancy_last24months_id
save `pregnancy_last24months_id'



***************************************************************************
//Get info on kids born and remained alive from I_CH 
***************************************************************************

use Data\I_CH, clear
rename iid id

//Keeping only live births
keep if ich02 == 4

//Generating the child level id number for merges using information from the household rosters
tostring(ich03_cd), gen(kid) format(%02.0f)
gen kid_id = substr(id,1,3) + "4" + substr(id,5,9) + kid
duplicates tag kid_id, gen(tagx)

//Dropping births alive and then died (tally elsewhere, where have age at death)
drop if ich03_cd >= 61 & ich03_cd <= 64
//Dropping stillbirths
drop if ich03_cd >= 71 & ich03_cd <.


//Merging using datasets created from marriedwomen16to49years do file
sort kid_id
merge kid_id using kids_in_house, uniqusing _merge(kid_in_house_merge)
tab kid_in_house_merge


**All but 18 (16) of the kids from household roster marked as being under 18 months (12-24 months) merge in, so okay
tab live_in_house_18_ind kid_in_house, m
tab live_in_house_12to24_ind kid_in_house, m
tab live_in_house_21_ind kid_in_house, m
tab live_in_house_24_ind kid_in_house, m
tab live_in_house_12to21_ind kid_in_house, m

tab kid_id if live_in_house_18_ind == 1 & kid_in_house_merge == 2
tab kid_id if live_in_house_12to24_ind == 1 & kid_in_house_merge == 2
tab kid_id if live_in_house_21_ind == 1 & kid_in_house_merge == 2
tab kid_id if live_in_house_24_ind == 1 & kid_in_house_merge == 2
tab kid_id if live_in_house_12to21_ind == 1 & kid_in_house_merge == 2

tab live_in_house_18_ind live_in_house_over18_ind, m

drop if kid_in_house_merge == 2

sort kid_id
merge kid_id using kids_out_house, uniqusing _merge(kid_out_house_merge) update
tab kid_out_house_merge

**Both children from household roster marked as being under 18 months merge in , so okay

tab live_out_house_18_ind kid_out_house, m
tab live_out_house_12to24_ind kid_out_house, m
tab live_out_house_21_ind kid_out_house, m
tab live_out_house_24_ind kid_out_house, m
tab live_out_house_12to21_ind kid_out_house, m

tab kid_id if live_out_house_18_ind == 1 & kid_out_house_merge == 2
tab kid_id if live_out_house_12to24_ind == 1 & kid_out_house_merge == 2
tab kid_id if live_out_house_21_ind == 1 & kid_out_house_merge == 2
tab kid_id if live_out_house_24_ind == 1 & kid_out_house_merge == 2
tab kid_id if live_out_house_12to21_ind == 1 & kid_out_house_merge == 2

tab live_out_house_18_ind live_out_house_over18_ind, m

drop if kid_out_house_merge == 2

**## Come back and check on these merges again (for in and out)

**All "" or "51" as would expect
**We have some 51
tab kid live_out_house, m
**All are non "", "51", or "52" as would expect
tab kid live_in_house, m

//For alive and in house
gen within_18 = 1 if live_in_house_18_ind == 1 & ich03_cd < 51
replace within_18 = 0 if live_in_house_over18_ind == 1 & ich03_cd < 51

gen between_12to24 = 1 if live_in_house_12to24_ind == 1 & ich03_cd < 51
gen within_24 = 1 if live_in_house_24_ind == 1 & ich03_cd < 51
gen within_21 = 1 if live_in_house_21_ind == 1 & ich03_cd < 51
gen between_12to21 = 1 if live_in_house_12to21_ind == 1 & ich03_cd < 51

//For alive and out of house
replace within_18 = 1 if live_out_house_18_ind == 1 & ich03_cd == 51
replace within_18 = 0 if live_out_house_over18_ind == 1 & ich03_cd == 51

replace between_12to24 = 1 if live_out_house_12to24_ind == 1 & ich03_cd == 51
replace within_24 = 1 if live_out_house_24_ind == 1 & ich03_cd == 51
replace within_21 = 1 if live_out_house_21_ind == 1 & ich03_cd == 51
replace between_12to21 = 1 if live_out_house_12to21_ind == 1 & ich03_cd == 51

rename id  mother_id
gen id = kid_id

**If mother_id_ind == 0 then "id" is kid's id, if mother_id_ind == 1 then "id" is mother's id 
gen mother_id_ind = 0
gen dead = 0
gen dead_0to28_days = 0
gen dead_0to12_mons = 0
gen dead_1to12_mons = 0
gen within_24_old_version = 1



**We have 21 observations which are neither out of household nor dead, but not match with live in household
drop if within_24 == .

tempfile kids_alive
save `kids_alive'



*********************************************************
//Get info on children born live but then died from I_RH
*********************************************************

use Data\I_RH13, clear

sort iid

**The survey dates are between Oct-Dec 2009, so any children born before Oct. 2007 will be beyond 24 months
**We drop these observations for each of analysis below

**drop if irh13_yy < 2007
keep if irh13_yy >= 2008 | (irh13_yy == 2007 & irh13_mm >= 10 & irh13_mm < .)


**Dropping values for which missing years 
**Also, very unlikely to have forgotten the year if was within the last 2 years
drop if irh13_yy >= .

sort iid
//Merge info on survey date
merge iid using `survey_date_info', uniqusing
tab _merge
keep if _merge == 3


//Generate birth month years 
gen birth_mon = ym(irh13_yy, irh13_mm)
gen birth_year = irh13_yy

g birthday = mdy(irh13_mm,15,irh13_yy)

***** deal with kids with missing birthday
replace birthday = mdy(1,1,2008) if irh13_yy == 2007 & birthday == .
replace birthday = mdy(6,1,2008) if irh13_yy == 2008 & birthday == .
replace birthday = mdy(6,1,2009) if irh13_yy == 2009 & birthday == .

replace birth_mon = ym(1,2008) if irh13_yy == 2007 & birth_mon == .
replace birth_mon = ym(6,2008) if irh13_yy == 2008 & birth_mon == .
replace birth_mon = ym(6,2009) if irh13_yy == 2009 & birth_mon == .


//Generate age in months at death
gen age_died_mon = 0 if irh15u == 1 | irh15u == 2 
replace age_died_mon = floor(ibh15n/30.4735) if irh15u == 3
replace age_died_mon = ibh15n if irh15u == 4
//replace age_died_mon = 12*ibh15n if irh15u == 5
replace age_died_mon = ym(irh13a_mm,irh13a_yy) - birth_mon if irh15u == 5

gen age_died_days = 0 if irh15u == 1 | irh15u == 2
replace age_died_days = ibh15n if irh15u == 3
replace age_died_days = 30.4375*ibh15n if irh15u == 4
**replace age_died_days = 365.25*ibh15n if irh15u == 5
replace age_died_mon = mdy(irh13a_mm,15,irh13a_yy) - birthday if irh15u == 5

** Need to impute the missing months from birth_date_mon?
gen elapsed_mon = survey_mon - birth_mon

gen death_elapsed_diff = age_died_mon - elapsed_mon
tab death_elapsed, m

**Correcting clearly wrong entries (2 children, age 19 and 20 years at time of death, assume should be month)
replace irh15u = 4 if death_elapsed_diff == 197
replace irh15u = 4 if death_elapsed_diff == 216

****


drop age_died* elapsed_mon death_elapsed_diff



//Generate age in months at death
gen age_died_mon = 0 if irh15u == 1 | irh15u == 2 
replace age_died_mon = floor(ibh15n/30.4735) if irh15u == 3
replace age_died_mon = ibh15n if irh15u == 4
replace age_died_mon = 12*ibh15n if irh15u == 5

gen age_died_days = 0 if irh15u == 1 | irh15u == 2
replace age_died_days = ibh15n if irh15u == 3
replace age_died_days = 30.4375*ibh15n if irh15u == 4
replace age_died_days = 365.25*ibh15n if irh15u == 5

gen elapsed_mon = survey_mon - birth_mon
gen death_elapsed_diff = age_died_mon - elapsed_mon
tab death_elapsed, m




//Dummy for whether okay to keep this obs or not, based on age/date info
gen elapsed_death_okay = 1 if death_elapsed_diff <= 0


**


tab irh13_mm irh13_yy if elapsed_death_okay ==., m
tab age_died_mon if irh13_yy == 2009 & elapsed_mon == .


replace elapsed_death_okay = 0 if irh13_yy == 2007 & elapsed_mon == .


**the 2009 obs okay b/c the survey month was in Oct-Dec 2009 & age died was 7 months, assume Jan
replace elapsed_death_okay = 1 if irh13_yy == 2009 & elapsed_mon == .
replace elapsed_mon = 9 if irh13_yy == 2009 & elapsed_mon == .

**
**these 6 obs are from 2008, missing birth info, 4 died within 10 days birth, so this ambiguous, can't tell which side of April-June 2008 they fall on
** def within 24 months though, to be conservative with make within 18 too
**1 of 5 obs died 6 months after birth some time in 2008, ambiguous whether born before/after April-June 2008, as with others make within 18 and 24 months 

tab age_died_days age_died_mon if irh13_yy == 2008 & elapsed_death_okay == ., m
replace elapsed_mon = 18 if irh13_yy == 2008 & elapsed_death_okay == . & age_died_days <= 10
replace elapsed_mon = 18 if irh13_yy == 2008 & elapsed_death_okay == . & age_died_mon == 6
replace elapsed_mon = 18 if irh13_yy == 2008 & elapsed_death_okay == . & age_died_mon == 2
replace elapsed_death_okay = 1 if irh13_yy == 2008 & elapsed_death_okay == .



drop death_elapsed_diff
gen death_elapsed_diff = age_died_mon - elapsed_mon
tab death_elapsed_diff, m


codebook elapsed_death_okay

drop if elapsed_death_okay == 0
drop elapsed_death_okay death_elapsed_diff

***


//Generate dummies for whether mother/child id and if dead/alive
gen mother_id_ind = 1
gen dead = 1

gen dead_0to28_days = 1 if age_died_days <= 28
replace dead_0to28_days = 0 if age_died_days > 28 & age_died_days < .

gen dead_0to12_mons = 1 if age_died_mon <= 12
replace dead_0to12_mons = 0 if age_died_mon > 12 & age_died_mon < .

gen dead_1to12_mons = 1 if age_died_mon >= 1 & age_died_mon <= 12
replace dead_1to12_mons = 0 if (age_died_mon < 1 |(age_died_mon > 12 & age_died_mon < .))


gen within_18 = 1 if elapsed_mon <= 18
replace within_18 = 0 if elapsed_mon > 18 & elapsed_mon < .
gen within_24 = 1 if elapsed_mon <= 24
replace within_24 = 0 if elapsed_mon > 24 & elapsed_mon < .
gen within_21 = 1 if elapsed_mon <= 21
replace within_21 = 0 if elapsed_mon > 21 & elapsed_mon < .

gen between_12to24 = 1 if elapsed_mon > 12 & elapsed_mon <= 24
replace between_12to24 = 0 if elapsed_mon <=12 | (elapsed_mon > 24 & elapsed_mon < .)
gen between_12to21 = 1 if elapsed_mon > 12 & elapsed_mon <= 21
replace between_12to21 = 0 if elapsed_mon <= 12 | (elapsed_mon > 21 & elapsed_mon < .)

gen born_2007 = (irh13_yy == 2007)


keep iid survey_mon birth_mon birth_year dead* mother_id age_died_mon age_died_days elapsed_mon survey_year within* between_12to24 between_12to21 born_2007
rename iid id

gen HH_id = substr(id,1,3) + substr(id,5,9)
save dead_kids, replace
drop HH_id

****


append using `kids_alive'


gen dead_0to28_days_last18 = dead_0to28_days if within_18 == 1
gen dead_0to12_mons_last24 = dead_0to12_mons if within_24 == 1
gen dead_1to12_mons_last24 = dead_1to12_mons if within_24 == 1
gen dead_0to12_mons_12to24 = dead_0to12_mons if between_12to24 == 1

gen dead_0to12_mons_last21 = dead_0to12_mons if within_21 == 1
gen dead_0to12_mons_12to21 = dead_0to12_mons if between_12to21 == 1


//Generate variable identifying household (absent of 4th digit specific to book) for future merges
gen HH_id= substr(id,1,3) + substr(id,5,9)
sort HH_id

tempfile infant_mortality_input
save `infant_mortality_input', replace


****

use Data\R, clear

duplicates drop

duplicates drop rid, force

gen panel_hh = (rar00x == 1 | rar00x == 2)
gen panel_hh_id_w3 = substr(rid, 1,3) + substr(rid,5,9)

//Generate variables identifying household and subdistrict for future merges
gen Location_ID= substr(rid,1,3)
gen HH_id = substr(rid,1,3) + substr(rid,5,9)

keep HH_id Location_ID panel_hh panel_hh_id_w3

sort HH_id
merge HH_id using `infant_mortality_input', uniqmaster _merge(_m1)
tab _m1

drop if _m1 == 1
tab _m1

sort Location_ID
tempfile infant_mortality_input2
save `infant_mortality_input2', replace

use ..\kecs_info_clean
egen generasi = rowmax(gen_year1 gen_year2)
gen type = 3



gen kab_id = llk02_cd

keep Location_ID type kab_id

sort Location_ID


//Combine infant mortality info with info on kecamatan type
merge Location_ID using `infant_mortality_input2', uniqmaster _merge(_m2)
tab _m2
drop if _m2==1
tab _m2


//Generating variables to look panel individuals across waves
gen rid= substr(id,1,3) + "1" + substr(id,5,9)
sort kid_id
tempfile temp
save `temp', replace



**Generating for merges with children alive and living with mother (we have kid's id for those observations)
use Data\R_AR_01, clear
duplicates drop

tostring rar00_07 rar00, replace format(%02.0f)
gen kid_id = substr(rid,1,3) + "4" + substr(rid,5,9) + rar00

rename rar00 rar00_kid
rename rar00_07 rar00_07_kid
rename rar01a rar01a_kid
keep rar00_kid rar00_07_kid rar01a_kid kid_id

keep rar00_kid rar00_07_kid rar01a_kid kid_id

sort kid_id
merge kid_id using `temp', uniqmaster _merge(_ind_roster_info_merge)
tab _ind_roster_info_merge
drop if _ind_roster_info_merge == 1

gen panel_id_w3 = kid_id
gen art_split_w3 = substr(kid_id,10,2)

**
replace panel_id_w3 = substr(panel_id,1,9) + "00" + "00" + rar00_07 if rar00_07 != "00" & rar00_07 != ""
sort panel_id_w3
**

order id panel_id_w3


foreach x of var dead_0to12_mons_last24 dead_1to12_mons_last24 dead_0to28_days_last18 dead_0to12_mons_12to24 dead_0to12_mons_last21 dead_0to12_mons_12to21{
	rename `x' `x'_w3
}
  
compress
save infant_mortality_w3, replace

//Generasi only
keep if type==3

save infant_mortality_generasi_w3, replace



