clear
set more off

cd "Wave II"

/*In this file, data in the files I_CH and I from the section of the survey 'Book 1B: Married Woman 16-49 Years Old' to determine the following variables:
pre_natal_visits:		the total number of pre-natal visits, previous 18 months 
pre_natal_dummy:		whether or not >=4 pre-natal visits took place, previous 18 months
iron_pills_dummy:		whether or not >=90 iron pills were given, previous 18 months
good_assisted_delivery:	whether or not delivery was assited by a doctor or midwife, previous 18 months
post_natal_visits:	the total number of post-natal visits within 40 days of pregnancy, previous 18 months
post_natal_dummy:		whether or not >=2 post-natal visits took place, previous 18 months

iron_pills_categ		categories for how many iron pills received, previous 18 months 0 "Did not receive any" 1 "1-30 pills" 2 "31-60 pills" 3 "61-90 pills" 4 ">90 pills" 8 "Do Not Know, but did receive"

*/

******************************************************************************************
//Creating mother level information on date of survey for use in determining children's ages
******************************************************************************************

use Data\I, clear

//Generate survey dates using first survey attempt with at least partial completion
gen survey_date=mdy(iivw_mm_1, iivw_dd_1, iivw_yy_1) if ihkw_1==1 | ihkw_1==2
replace survey_date=mdy(iivw_mm_2, iivw_dd_2, iivw_yy_2) if survey_date==. & ihkw_2==1 | ihkw_2==2
replace survey_date=mdy(iivw_mm_3, iivw_dd_3, iivw_yy_3) if survey_date==. & ihkw_3==1 | ihkw_3==2

gen survey_month = ym(iivw_yy_1, iivw_mm_1) if ihkw_1==1 | ihkw_1==2
replace survey_month= ym(iivw_yy_2, iivw_mm_2) if survey_month==. & ihkw_2==1 | ihkw_2==2
replace survey_month= ym(iivw_yy_3, iivw_mm_3) if survey_month==. & ihkw_3==1 | ihkw_3==2

merge iid using Data\I_CH, uniqmaster
tab _m
tab ich01 _m, m
drop if _m == 1

//If ich03_cd is . means is not in household, still born, miscarriage, or live then died

sort iid
tempfile pregnancy_last24months
save `pregnancy_last24months'

keep iid survey_date survey_month irh01a
duplicates drop

tempfile temp1
save `temp1'


***Merging in information for linking to wave 1 info on mothers (b/c of panel related pregnancy history skips)
use Data\R_AR_01, clear
duplicates drop

tostring rar00_07 rar00, replace format(%02.0f)
gen iid = substr(rid,1,3) + "2" + substr(rid,5,7) + rar00
keep rar00 rar00_07 rar01a iid

sort iid
merge iid using `temp1', uniqmaster _merge(_ind_roster_info_merge)
tab _ind_roster_info_merge
keep if _ind_roster_info_merge == 3


gen panel_id_w2 = iid
replace panel_id_w2 = substr(panel_id_w2,1,9) + "00" + rar00_07 if rar00_07 != "00" & rar00_07 != ""
sort iid




tempfile pregnancy_last24months_id
save `pregnancy_last24months_id'


***************************************************************************
//Info on current pregnancies and total births per mother in the last 24 months
***************************************************************************
use Data\I_CH, clear

gen x = 1
bys iid: egen births_last24 = total(x)
drop x

gen curr_preg_18 = 1 if ich02 == 1
replace curr_preg_18 = 0 if ich02 != 1
gen curr_preg = 1
replace curr_preg_18 = 0 if ich02 != 1
bys iid: egen curr_preg_18_tot = total(curr_preg_18)
bys iid: egen curr_preg_tot = total(curr_preg)

keep curr_preg_18_tot curr_preg_tot births_last24 iid
duplicates drop 

sort iid
tempfile current
save `current'

*****************************************************************
//Info on pregnancies for children alive and living in house
*****************************************************************

use Data\R, clear
//Generate survey dates using first survey attempt with at least partial completion
gen survey_date=mdy(rivw_mm_1, rivw_dd_1, rivw_yy_1) if rhkw_1==1 | rhkw_1==2
replace survey_date=mdy(rivw_mm_2, rivw_dd_2, rivw_yy_2) if survey_date==. & rhkw_2==1 | rhkw_2==2
replace survey_date=mdy(rivw_mm_3, rivw_dd_3, rivw_yy_3) if survey_date==. & rhkw_3==1 | rhkw_3==2

gen survey_month = ym(rivw_yy_1, rivw_mm_1) if rhkw_1==1 | rhkw_1==2
replace survey_month= ym(rivw_yy_2, rivw_mm_2) if survey_month==. & rhkw_2==1 | rhkw_2==2
replace survey_month= ym(rivw_yy_3, rivw_mm_3) if survey_month==. & rhkw_3==1 | rhkw_3==2

keep rid survey_date survey_month rar00x
sort rid

merge rid using Data\R_AR_01, uniqmaster
tab _m

//drop if don't have info on mother's number (dead, not in house or missing)
drop if rar06 >= 51
tostring rar06, gen(mother_id) format(%02.0f)

gen iid = substr(rid,1,3) + "2" + substr(rid,5,7) + mother_id

**XXUpdated from drop if rar04_yy < 2006XX
keep if rar04_yy >= 2007 | (rar04_yy == 2006 & rar04_mm >= 10 & rar04_mm < .)

gen born_2006 = (rar04_yy == 2006)

//Replace missing days with 15 if neither month nor year values for children's birth dates missing
replace rar04_dd=15 if rar04_dd>=. & rar04_mm <. & rar04_yy <.

//Replace nonleap year February 29's with February 28's; correct 31's to 30's in certain months
replace rar04_dd=28 if rar04_dd==29 & rar04_mm==2 & rar04_yy!=2004
replace rar04_dd=30 if rar04_dd==31 & (rar04_mm==2 | rar04_mm==4 | rar04_mm==6 | rar04_mm==8 | rar04_mm==11)

//Generate child's birth dates
gen birth_date=mdy(rar04_mm, rar04_dd, rar04_yy)
**the missings are true (.y, .z)

**Survey was between Oct-Dec 2008, so if born in 2008, then within 10-12 months; if born in Jan 2007, born within 21-23 months, so 2007 within 24, ambiguous on 18 or 21 months

gen birth_diff = survey_date - birth_date

gen live_in_house_18 = 1 if birth_diff <= 547.875
replace live_in_house_18 = 0 if birth_diff > 547.875 & birth_diff < .
replace live_in_house_18 = 1 if rar04_yy == 2008

gen live_in_house_over18 		= 1 if birth_diff > 547.875 & birth_diff < .
replace live_in_house_over18 	= 0 if birth_diff <= 547.875
replace live_in_house_over18 = 0 if rar04_yy == 2008 

gen live_in_house_12to24 = 1 if birth_diff > 365.25 & birth_diff <= 730.50
replace live_in_house_12to24 = 0 if birth_diff <= 365.25 | (birth_diff > 730.50 & birth_diff < .)
replace live_in_house_12to24 = 0 if rar04_yy == 2008

gen live_in_house_24 = 1 if birth_diff <= 730.50
replace live_in_house_24 = 0 if birth_diff > 730.50 & birth_diff < .
replace live_in_house_24 = 1 if rar04_yy == 2008 | rar04_yy == 2007

gen live_in_house_21 = 1 if birth_diff <= 639.1875 
replace live_in_house_21 = 0 if birth_diff > 639.1875 & birth_diff < .
replace live_in_house_21 = 1 if rar04_yy == 2008

gen live_in_house_12to21 = 1 if birth_diff > 365.25 & birth_diff <= 639.1875
replace live_in_house_12to21 = 0 if birth_diff <= 365.25 | (birth_diff > 639.1875 & birth_diff < .)
replace live_in_house_12to21 = 0 if rar04_yy == 2008

gen live_in_house = 1


//Merging with mother dataset on births in last 24 months
sort iid
merge iid using `pregnancy_last24months_id', uniqusing _merge(_mx)
tab _mx
codebook rar04_yy if _mx == 1
**almost all 2006

tab live_in_house _mx, m
tab live_in_house_18 _mx , m
tab live_in_house_over18 _mx, m
tab live_in_house_12to24 _mx, m
tab live_in_house_24 _mx, m
tab live_in_house_21 _mx, m
tab live_in_house_12to21 _mx, m


**Have a small number of births within 18 months from household survey that not match up with any mother we surveyed
**But vast majority merge in okay (3943 of 3969)

//Keeping only if matching with mother surveyed from I_CH
keep if _mx == 3

gen live_in_bdiff_miss = 1 if birth_diff == . & live_in_house_18 != 1

tempfile kids_input
save `kids_input'

bys iid: egen live_in_house_18_tot = total(live_in_house_18)
bys iid: egen live_in_house_over18_tot = total(live_in_house_over18)
bys iid: egen live_in_house_tot = total(live_in_house)
bys iid: egen live_in_bdiff_miss_tot = total(live_in_bdiff_miss)

gen preg_type = 4
keep live_in_house_18_tot live_in_bdiff_miss_tot live_in_house_tot iid survey_date survey_month live_in_house_over18_tot 
duplicates drop

//Saving mother level dataset with total number of kids under 18 living in house
sort iid
tempfile live_in_house
save `live_in_house'

//Creating kid level information from household roster for direct merge later
use `kids_input', clear
tostring(rar00), gen(kid) format(%02.0f)
gen kid_id = substr(rid,1,3) + "4" + substr(rid,5,7) + kid
duplicates drop


rename live_in_house_18 live_in_house_18_ind
rename live_in_house_over18 live_in_house_over18_ind 
rename live_in_house_12to24 live_in_house_12to24_ind
rename live_in_house_24 live_in_house_24_ind
rename live_in_house_21 live_in_house_21_ind
rename live_in_house_12to21 live_in_house_12to21_ind

keep kid_id live_in_house_18_ind live_in_house_over18_ind live_in_house_12to24_ind live_in_house_24 live_in_house_21 live_in_house_12to21 live_in_house birth_diff born_2006
sort kid_id

//Saving kid level dataset with info on under 18 and living in house
tempfile kids
save `kids'
save kids_in_house, replace


*****************************************************************
//Info on pregnancies for children alive but not living in house
*****************************************************************

use Data\R, clear
//Generate survey dates using first survey attempt with at least partial completion
gen survey_date=mdy(rivw_mm_1, rivw_dd_1, rivw_yy_1) if rhkw_1==1 | rhkw_1==2
replace survey_date=mdy(rivw_mm_2, rivw_dd_2, rivw_yy_2) if survey_date==. & rhkw_2==1 | rhkw_2==2
replace survey_date=mdy(rivw_mm_3, rivw_dd_3, rivw_yy_3) if survey_date==. & rhkw_3==1 | rhkw_3==2

gen survey_month = ym(rivw_yy_1, rivw_mm_1) if rhkw_1==1 | rhkw_1==2
replace survey_month= ym(rivw_yy_2, rivw_mm_2) if survey_month==. & rhkw_2==1 | rhkw_2==2
replace survey_month= ym(rivw_yy_3, rivw_mm_3) if survey_month==. & rhkw_3==1 | rhkw_3==2

keep rid survey_date survey_month rar00x
sort rid

merge rid using Data\R_AR_26, uniqmaster
tab _m
keep if _m == 3

//drop if don't have info on mother's number (dead, out of household, missing)
drop if rar32 >= 51
tostring rar32, gen(mother_id) format(%02.0f)

gen iid = substr(rid,1,3) + "2" + substr(rid,5,7) + mother_id

keep if rar30_yy >= 2007 | (rar30_yy == 2006 & rar30_mm >= 10 & rar30_mm < .)
**$$

gen born_2006 = (rar30_yy == 2006)

//Replace missing days with 15 if neither month nor year values for children's birth dates missing
replace rar30_dd=15 if rar30_dd>=. & rar30_mm <. & rar30_yy <.

//Replace nonleap year February 29's with February 28's
replace rar30_dd=28 if rar30_dd==29 & rar30_mm==2 & rar30_yy!=2004
replace rar30_dd=30 if rar30_dd==31 & (rar30_mm==2 | rar30_mm==4 | rar30_mm==6 | rar30_mm==8 | rar30_mm==1)

//Generate child's birth dates
gen birth_date=mdy(rar30_mm, rar30_dd, rar30_yy)
**the missings are true (.y, .z)

gen birth_diff = survey_date - birth_date

gen live_out_house_18 = 1 if birth_diff <= 547.875
replace live_out_house_18 = 0 if birth_diff > 547.875 & birth_diff < .
replace live_out_house_18 = 1 if rar30_yy == 2008

gen live_out_house_over18 = 1 if birth_diff > 547.875 & birth_diff < .
replace live_out_house_over18 = 0 if birth_diff <= 547.875 
replace live_out_house_over18 = 0 if rar30_yy == 2008

gen live_out_house_12to24 = 1 if birth_diff > 365.25 & birth_diff <= 730.50
replace live_out_house_12to24 = 0 if birth_diff <= 365.25 | (birth_diff > 730.50 & birth_diff < .)
replace live_out_house_12to24 = 0 if rar30_yy == 2008

gen live_out_house_24 = 1 if birth_diff <= 730.50
replace live_out_house_24 = 0 if birth_diff > 730.50 & birth_diff < .
replace live_out_house_24 = 1 if rar30_yy == 2008 | rar30_yy == 2007

gen live_out_house_21 = 1 if birth_diff <= 639.1875 
replace live_out_house_21 = 0 if birth_diff > 639.1875 & birth_diff < .
replace live_out_house_21 = 1 if rar30_yy == 2008

gen live_out_house_12to21 = 1 if birth_diff > 365.25 & birth_diff <= 639.1875
replace live_out_house_12to21 = 0 if birth_diff <= 365.25 | (birth_diff > 639.1875 & birth_diff < .)
replace live_out_house_12to21 = 0 if rar30_yy == 2008

gen live_out_house = 1


//Merging with mother dataset on births in last 24 months
sort iid
merge iid using `pregnancy_last24months_id', uniqusing _merge(_mx)
tab _mx

tab live_out_house _mx, m
tab live_out_house_18 _mx , m
tab live_out_house_12to24 _mx, m
tab live_out_house_21 _mx, m
tab live_out_house_24 _mx, m
tab live_out_house_12to21 _mx, m

**Have a small number of births within 18 months from household survey that not match up with any mother we surveyed
**But majority merge in okay (4 of 7)

//Keeping only if matching with mother surveyed from I_CH
keep if _mx == 3

gen live_out_bdiff_miss = 1 if birth_diff == . & live_out_house_18 != 1
tempfile kids_out_input
save `kids_out_input'

bys iid: egen live_out_house_18_tot = total(live_out_house_18)
bys iid: egen live_out_house_over18_tot = total(live_out_house_over18)
bys iid: egen live_out_house_tot = total(live_out_house)
bys iid: egen live_out_bdiff_miss_tot = total(live_out_bdiff_miss)

gen preg_type = 4
keep live_out_house_18_tot live_out_bdiff_miss_tot live_out_house_tot iid live_out_house_over18_tot
duplicates drop

//Saving mother level dataset with total number of kids under 18 living in house
sort iid
tempfile live_out_house
save `live_out_house'


//Creating child level dataset
use `kids_out_input', clear
//51 is used to signify those who live outside of household for individuals
//tostring(rar00), gen(kid) format(%02.0f)
gen kid_id = substr(rid,1,3) + "4" + substr(rid,5,7) + "51"
//keep if live_out_house_18 == 1
duplicates drop
**No duplicates

duplicates report kid_id
**No duplicates in terms of kid_id, so need not worry about when merge in later

rename live_out_house_18 live_out_house_18_ind
rename live_out_house_over18 live_out_house_over18_ind 
rename live_out_house_12to24 live_out_house_12to24_ind
rename live_out_house_24 live_out_house_24_ind
rename live_out_house_21 live_out_house_21_ind
rename live_out_house_12to21 live_out_house_12to21_ind

**XXAdded keeping in rar30_yy rar30_mm for the overlap period mortality calculationsXX
keep kid_id live_out_house_18_ind live_out_house_over18_ind live_out_house_12to24_ind live_out_house_24_ind live_out_house_21_ind live_out_house_12to21_ind live_out_house birth_diff born_2006 rar30_yy rar30_mm
sort kid_id


//Saving kid level dataset with info on under 18 but not living in house
tempfile kids_out
save `kids_out'
save kids_out_house, replace


*****************************************************************
//Info on still born pregancies
*****************************************************************
//Merging with mother dataset on births in last 24 months
use `pregnancy_last24months_id', clear
sort iid
merge iid using Data\I_RH19, uniqmaster
tab irh01a _m, m
**All new as expected

//Keeping only if matching with mother surveyed from I_CH
keep if _m == 3

tempfile stillborn_w2_info
save `stillborn_w2_info'


use `pregnancy_last24months_id', clear
sort panel_id_w2
tempfile tempx
save `tempx'


//Merging with information from wave I, for panel mothers
use "..\Wave I\Data\I_RH19", clear

gen panel_id_w2 = substr(iid,1,4) + substr(iid,5,5) + "00" + substr(iid,10,2) 
sort panel_id_w2

merge panel_id_w2 using `tempx', uniqusing _merge(_m2)
tab irh01a _m2, m
**All panel as expected
keep if _m2 == 3

append using `stillborn_w2_info'
tab _merge _m2, m


**Dropping empty observations (true missings are distinguished with .y)
drop if irh19_yy == .

keep if irh19_yy >= 2007 | (irh19_yy == 2006 & irh19_mm >= 10 & irh19_mm < .)
**$$

//Generate child's birth month info
gen birth_month= ym(irh19_yy, irh19_mm)

gen birth_diff_mon = survey_month - birth_month

gen stillborn_18 = 1 if birth_diff_mon <= 18
replace stillborn_18 = 0 if birth_diff_mon > 18 & birth_diff_mon < .
replace stillborn_18 = 1 if irh19_yy == 2008
**we knows obs in 2009 are less than 18 months, even without month info, so capture any previous 2009 missings

gen stillborn_over18 		= 1 if birth_diff_mon > 18 & birth_diff_mon < .
replace stillborn_over18 = 0 if birth_diff_mon <= 18 
replace stillborn_over18 = 0 if irh19_yy == 2008

gen stillborn = 1

gen preg_type = 3

gen stillborn_bdiff_miss = 1 if birth_diff_mon == . & stillborn_18 != 1

bys iid: egen stillborn_18_tot = total(stillborn_18)
bys iid: egen stillborn_over18_tot = total(stillborn_over18)
bys iid: egen stillborn_tot = total(stillborn)
bys iid: egen stillborn_bdiff_miss_tot = total(stillborn_bdiff_miss)


//Saving mother level dataset with total number of still births in last 18 months
keep stillborn_tot stillborn_18_tot stillborn_bdiff_miss_tot iid stillborn_over18_tot
duplicates drop
sort iid
tempfile stillborn
save `stillborn'

****************************************************************
//Info on miscarriage pregnancies
****************************************************************
//Merging with mother dataset on births in last 24 months
use `pregnancy_last24months_id', clear
merge iid using Data\I_RH23, uniqmaster
tab _m

//Keeping only if matching with mother surveyed from I_CH
keep if _m == 3

tempfile miscarriage_w2_info
save `miscarriage_w2_info'


use `pregnancy_last24months_id', clear
sort panel_id_w2
tempfile tempx
save `tempx'


//Merging with information from wave I, for panel mothers
use "..\Wave I\Data\I_RH23", clear

gen panel_id_w2 = substr(iid,1,4) + substr(iid,5,5) + "00" + substr(iid,10,2) 
sort panel_id_w2

merge panel_id_w2 using `tempx', uniqusing _merge(_m2)
tab irh01a _m2, m
**All panel as expected
keep if _m2 == 3

append using `miscarriage_w2_info'
tab _merge _m2, m

keep if irh23_yy >= 2007 | (irh23_yy == 2006 & irh23_mm >= 10 & irh23_mm < .)
**$$

//Generate miscarriage month info
gen miscarry_month= ym(irh23_yy, irh23_mm)

gen miscarry_diff_mon = survey_month - miscarry_month

gen miscarry_18 = 1 if miscarry_diff_mon <= 18
replace miscarry_18 = 0 if miscarry_diff_mon > 18 & miscarry_diff_mon < .
replace miscarry_18 = 1 if irh23_yy == 2008

gen miscarry_over18 		= 1 if miscarry_diff_mon > 18 & miscarry_diff_mon < .
replace miscarry_over18 = 0 if miscarry_diff_mon <= 18 
replace miscarry_over18 = 0 if irh23_yy == 2008

gen miscarry = 1

gen preg_type = 2

gen miscarry_bdiff_miss = 1 if miscarry_diff_mon == . & miscarry_18 != 1

bys iid: egen miscarry_18_tot = total(miscarry_18)
bys iid: egen miscarry_over18_tot = total(miscarry_over18)
bys iid: egen miscarry_tot = total(miscarry)
bys iid: egen miscarry_bdiff_miss_tot = total(miscarry_bdiff_miss)

//Saving mother level dataset with total number of miscarriages in last 18 months
keep miscarry_18_tot miscarry_tot miscarry_bdiff_miss_tot iid miscarry_over18_tot
duplicates drop
sort iid
tempfile miscarry
save `miscarry'

****************************************************************
//Info on pregnancies for children born alive then died
****************************************************************
//Merging with mother dataset on births in last 24 months
use `pregnancy_last24months_id', clear
merge iid using Data\I_RH13, uniqmaster
tab _m

//Keeping only if matching with mother surveyed from I_CH
keep if _m == 3

tempfile livethendied_w2_info
save `livethendied_w2_info'


use `pregnancy_last24months_id', clear
sort panel_id_w2
tempfile tempx
save `tempx'


//Merging with information from wave I, for panel mothers
use "..\Wave I\Data\I_RH13", clear

gen panel_id_w2 = substr(iid,1,4) + substr(iid,5,5) + "00" + substr(iid,10,2) 
sort panel_id_w2

merge panel_id_w2 using `tempx', uniqusing _merge(_m2)
tab irh01a _m2, m
**All panel as expected
keep if _m2 == 3

append using `livethendied_w2_info'
tab _merge _m2, m

keep if irh13_yy >= 2007 | (irh13_yy == 2006 & irh13_mm >= 10 & irh13_mm < .)

**$$

**Dropping empty observations (true missings are distinguished with .y)
drop if irh13_yy == .

//Generate birth month info
gen birth_month = ym(irh13_yy, irh13_mm)

gen birth_diff_mon = survey_month - birth_month

gen born_2006 = (irh13_yy == 2006)

gen live_then_died_18 = 1 if birth_diff_mon <= 18
replace live_then_died_18 = 0 if birth_diff_mon > 18 & birth_diff_mon < .
replace live_then_died_18 = 1 if irh13_yy == 2008

gen live_then_died_over18 		= 1 if birth_diff_mon > 18 & birth_diff_mon < .
replace live_then_died_over18 = 0 if birth_diff_mon <= 18 
replace live_then_died_over18 = 0 if irh13_yy == 2008

gen live_then_died = 1

gen preg_type = 4

gen live_then_died_bdiff_miss = 1 if birth_diff_mon == . & live_then_died_18 != 1

bys iid: egen live_then_died_18_tot = total(live_then_died_18)
bys iid: egen live_then_died_over18_tot = total(live_then_died_over18)
bys iid: egen live_then_died_tot = total(live_then_died)
bys iid: egen live_then_died_bdiff_miss_tot = total(live_then_died_bdiff_miss)


//Saving mother level dataset with total number of miscarriages in last 18 months
keep live_then_died_tot live_then_died_18_tot live_then_died_bdiff_miss_tot iid live_then_died_over18_tot
duplicates drop
sort iid
tempfile live_then_died
save `live_then_died'

********************************************************************************************
//Merging all the mother level information on the total number of births in the last 18 months
********************************************************************************************

merge iid using `miscarry', sort _merge(_m1)
tab _m1
//drop _m1

merge iid using `stillborn', sort _merge(_m2)
tab _m2
//drop _m2

merge iid using `live_out_house', sort _merge(_m3)
tab _m3
//drop _m3

merge iid using `live_in_house', sort _merge(_m4)
tab _m4
//drop _m4

merge iid using `current', sort _merge(_m5)
tab _m5
//drop _m5

**If all were missing then would have a false zero, check into this (done: no cases where this the case)

//Creating a tally of the total number of births in the last 18 months & 18-24 months for each mother using info from the HH rosters and the I_RH datasets
gen births_last18 = 0
gen births_over18 = 0
foreach x of var live_then_died_18_tot miscarry_18_tot stillborn_18_tot live_out_house_18_tot live_in_house_18_tot curr_preg_18_tot{
	replace births_last18 = births_last18 + 1 if `x' == 1
	replace births_last18 = births_last18 + 2 if `x' == 2
	replace births_over18 = births_over18 + 1 if `x' == 1
	replace births_over18 = births_over18 + 2 if `x' == 2
}

//Creating a tally of the number of missing dates
gen missing_dates_last18 = 0
foreach x in live_then_died miscarry stillborn live_out live_in{
	replace missing_dates_last18 = missing_dates_last18 + `x'_bdiff_miss_tot if `x'_bdiff_miss_tot != .
	}

sort iid
tempfile birth_info
save `birth_info'


******************************************************************************************************************
//Merging the totals for each birth type and cumulative at the mother level with the kid level pregnancy information
******************************************************************************************************************

merge iid using Data\I_CH, uniqmaster _merge(_mm)
tab _mm
**All 3's, as would expect

//Keeping only if mother has had some sort of pregnancy in the last 18 months
//drop if births_last18 == 0

//Creating variables tallying the total number of each type of pregnancy by mother (within the last 24 months)
gen preg_1 = 1 if ich02 == 1
gen preg_2 = 1 if ich02 == 2
gen preg_3 = 1 if ich02 == 3
gen preg_4 = 1 if ich02 == 4

foreach x of var preg_1 preg_2 preg_3 preg_4{
	bys iid: egen `x'_2 = total(`x')
	replace `x' = `x'_2
	drop `x'_2
	}

//Generating the child level id number for merges using information from the household rosters
tostring(ich03_cd), gen(kid) format(%02.0f)
gen kid_id = substr(iid,1,3) + "4" + substr(iid,5,7) + kid
duplicates tag kid_id, gen(tagx)


**Wave 2 initially, all kid = ., so okay



**********************************************************************************************************
//Merging in information from the household rosters on kids living in the household and out of the household
**********************************************************************************************************
//In household
sort kid_id
merge kid_id using `kids', uniqusing _merge(kid_in_house_merge)
tab kid_in_house_merge

drop if kid_in_house_merge == 2

**The live_in_house_18_tot== 1 isnt really a straightforward comparison b/c live_in_house_18_tot at mom level not kid (so will have some non-missings because other kids in that household live in house,etc)
codebook live_in_house_18_tot if kid_in_house_merge == 1 & ich02 == 4
codebook live_in_house_18_tot if kid_in_house_merge == 3

***********
//Out of household
sort kid_id
merge kid_id using `kids_out', uniqusing _merge(kid_out_house_merge)
tab kid_out_house_merge

drop if kid_out_house_merge == 2

**The == 1 isnt really a straightforward comparison b/c live_out_house_18 at mom level not kid
codebook live_out_house_18_tot if kid_out_house_merge == 1
codebook live_out_house_18_tot if kid_out_house_merge == 3


gen still_alive = 1 if kid_in_house_merge == 3 | kid_out_house_merge == 3
**tab ich02 still_alive, m

*************************************************************************************************************
//Determining which child level observations were within the last 18 months
*************************************************************************************************************

//If the number of births tallied in the last 18 months is equal to the number of births counted from the child specific information, create a marker for comparison
//We do not use this directly due to issues of mother's with children who are found in the I_CH dataset recalling information on other children in the I_RH datasets
//who are not found in the I_CH dataset (this therefore would lead to a births_last18 tally which would be higher than otherwise, so we could have children who are actually
//not in the last 18 months become marked as being so; we keep the marker to use in comparison for confirmation of proper categorization in okay_18 below)

gen all_18 = 1 if births_last18 >= births_last24
gen okay_18_alt = 1 if all_18 == 1

//If currently pregnant with child at time of interview, definitely within last 18 months
gen okay_18 = 1 if ich02 == 1

//Marking as okay if found in the household roster, live in house, and under 18 months
codebook ich02 live_in_house_18_tot if kid_in_house_merge == 3 
replace okay_18 = 1 if kid_in_house_merge == 3 & live_in_house_18_ind == 1
gen okay_over18 = 1 if kid_in_house_merge == 3 & live_in_house_over18_ind == 1

//Marking as okay if found in the live out of household roster, live out of house, and under 18 months
codebook ich02 live_out_house_18_tot if kid_out_house_merge == 3
replace okay_18 = 1 if kid_out_house_merge == 3 & live_out_house_18_ind == 1
replace okay_over18 = 1 if kid_out_house_merge == 3 & live_out_house_over18_ind == 1

**ich02 == 1 is always okay_18 == 1 b/c currently pregnant at time of survey

tempfile temp1
save `temp1'

**Check on ich02_line issue, we only have "1"'s and "."'s, why?
**For now dropping all households with 3 births, so can safely assume "." ~ "2" in ich02_line
duplicates tag iid, gen(tag)
codebook tag
keep if tag == 2
tab ich02, m
tab still_alive birth_diff if ich02 == 4, m
tempfile temp2
save `temp2'

use `temp1', clear
duplicates tag iid, gen(tag)
drop if tag == 2

//Marking those observations for which we know we only have one of that type per mother and we know that we have one within 18 months
replace okay_18 = 1 if ich02 == 2 & preg_2 == 1 & miscarry_18_tot == 1
replace okay_18 = 1 if ich02 == 3 & preg_3 == 1 & stillborn_18_tot == 1
replace okay_18 = 1 if ich02 == 4 & preg_4 == 1 & live_then_died_18_tot == 1 & still_alive != 1

replace okay_over18 = 1 if ich02 == 2 & preg_2 == 1 & miscarry_over18_tot == 1
replace okay_over18 = 1 if ich02 == 3 & preg_3 == 1 & stillborn_over18_tot == 1
replace okay_over18 = 1 if ich02 == 4 & preg_4 == 1 & live_then_died_over18_tot == 1 & still_alive != 1



//Marking those observations for which we know we only have two of that type per mother and we know that we have two within 18 months
replace okay_18 = 1 if ich02 == 2 & preg_2 == 2 & miscarry_18_tot == 1 & ich02_line == 1
replace okay_18 = 1 if ich02 == 2 & preg_2 == 2 & miscarry_18_tot == 2 & ich02_line <= .
replace okay_18 = 1 if ich02 == 3 & preg_3 == 2 & stillborn_18_tot == 1 & ich02_line == 1
replace okay_18 = 1 if ich02 == 3 & preg_3 == 2 & stillborn_18_tot == 2 & ich02_line <= .
replace okay_18 = 1 if ich02 == 4 & preg_4 == 2 & live_then_died_18_tot == 1 & ich02_line == 1 & still_alive != 1
replace okay_18 = 1 if ich02 == 4 & preg_4 == 2 & live_then_died_18_tot == 2 & ich02_line <= . & still_alive != 1

replace okay_over18 = 1 if ich02 == 2 & preg_2 == 2 & miscarry_over18_tot == 1 & ich02_line == .
replace okay_over18 = 1 if ich02 == 2 & preg_2 == 2 & miscarry_over18_tot == 2 & ich02_line <= .
replace okay_over18 = 1 if ich02 == 3 & preg_3 == 2 & stillborn_over18_tot == 1 & ich02_line == .
replace okay_over18 = 1 if ich02 == 3 & preg_3 == 2 & stillborn_over18_tot == 2 & ich02_line <= .
replace okay_over18 = 1 if ich02 == 4 & preg_4 == 2 & live_then_died_over18_tot == 1 & ich02_line == . & still_alive != 1
replace okay_over18 = 1 if ich02 == 4 & preg_4 == 2 & live_then_died_over18_tot == 2 & ich02_line <= . & still_alive != 1


//Dealing with specific problems in cases which arise due to combination of 3 categories within ich02 == 4 (live then died, in house, out house)
replace okay_18 = 1 if ich02 == 4 & preg_4 == 2 & live_then_died_18_tot == 1 & ich02_line == . & (live_out_house_18_tot == 1 | live_in_house_18_tot == 1) & still_alive != 1
replace okay_18 = 1 if ich02 == 4 & preg_4 == 2 & live_in_house_18_tot == 1 & ich02_line == . & (live_then_died_18_tot == 1 | live_out_house_18_tot == 1) & still_alive == 1
replace okay_18 = 1 if ich02 == 4 & preg_4 == 2 & live_out_house_18_tot == 1 & ich02_line == . & (live_then_died_18_tot == 1 | live_in_house_18_tot == 1) & still_alive == 1

replace okay_over18 = 1 if ich02 == 4 & preg_4 == 2 & live_then_died_over18_tot == 1 & ich02_line == 1 & (live_out_house_over18_tot == 1 | live_in_house_over18_tot == 1) & still_alive != 1
replace okay_over18 = 1 if ich02 == 4 & preg_4 == 2 & live_in_house_over18_tot == 1 & ich02_line == 1 & (live_then_died_over18_tot == 1 | live_out_house_over18_tot == 1) & still_alive == 1
replace okay_over18 = 1 if ich02 == 4 & preg_4 == 2 & live_out_house_over18_tot == 1 & ich02_line == 1 & (live_then_died_over18_tot == 1 | live_in_house_over18_tot == 1) & still_alive == 1



***Taking into account cases where there are more children mentioned in the appropriate RH dataset than are included in the I_CH dataset
***(therefore the _18_tot tally is higher than expected)
**This could be due to misentry of child id's causing merge issue

replace okay_18 = 1 if ich02 == 2 & preg_2 == 1 & ich02_line == 1 & miscarry_18_tot > 0 & miscarry_18_tot < .
replace okay_18 = 1 if ich02 == 3 & preg_3 == 1 & ich02_line == 1 & stillborn_18_tot > 0 & stillborn_18_tot < .
replace okay_18 = 1 if ich02 == 4 & preg_4 == 1 & ich02_line == 1 & live_then_died_18_tot > 0 & live_then_died_18_tot < . & still_alive != 1

replace okay_over18 = 1 if ich02 == 2 & preg_2 == 1 & ich02_line == . & miscarry_over18_tot > 0 & miscarry_over18_tot < .
replace okay_over18 = 1 if ich02 == 3 & preg_3 == 1 & ich02_line == . & stillborn_over18_tot > 0 & stillborn_over18_tot < .
replace okay_over18 = 1 if ich02 == 4 & preg_4 == 1 & ich02_line == . & live_then_died_over18_tot > 0 & live_then_died_over18_tot < . & still_alive != 1




**Replacing some "."'s with "0"'s when we know that all the possible "1"'s for a mother have been allocated
bys iid: egen okay_sum = total(okay_18)
replace okay_18 = 0 if okay_18 == . & okay_sum == births_last18



replace okay_18_alt = 0 if okay_18_alt == . & okay_18 == 0
replace okay_18_alt = 1 if okay_18_alt == . & okay_18 == 1

bys iid: egen okay_sum_alt = total(okay_18_alt)
tab okay_18_alt okay_18, m
//These 8 missings come cases where the different categories sum up to births_last18 >= births_last24 due to issue mentioned above, so in the _alt specification
//observations for which the specific category (_18) is missing (ex: live_then_died_18_tot == . but births_last18 = births_last24 due to other _18_tot being too high)

//Can see that okay sum is equal to births_last18 in all cases except where we have births_last18 > births_last24, 
// or where we have the 8 cases from above, his makes sense since birth_last24 tallied from within I_CH
tab okay_sum births_last18, m
tab okay_sum_alt births_last18, m
tab births_last24 births_last18, m


**These all under 18 months
codebook birth_diff if okay_18 == 1 & okay_over18 != 1
**These all over 18 months
codebook birth_diff if okay_over18 == 1 & okay_18 != 1
**These all under 18 months
tab birth_diff if okay_18 == 1 & okay_over18 == 1

**The second part captures those observations that are miscarriages, stillborn, or born alive and then died for panel mothers (b/c we had to determine which ones fell between 18 and 24 months and then drop them)
keep if okay_18 == 1 | (okay_over18 != 1 & ((still_alive != 1 & ich04 == 4) | ich02 == 2 | ich02 == 3))

//Reincorporating the 7 3 birth mothers
append using `temp2'

drop *_tot *_18* preg* tagx kid_in_house_merge kid_out_house_merge okay* _m* births* missing* kid

sort iid
save births_18_okay_w2, replace


*******************************************************************************************************

//Now creating relevant variables on previous 18 months subset of pregnancies

********************************************************************************************************

//keep iid ich02 ich07 ich08a ich08b ich08c ich08d ich08e ich08f ich08g ich08h ich08v ich10a ich10b ich10c ich10d ich10e ich10f ich10g ich10h ich10v ich12a ich12b ich12c ich12d ich12e ich12f ich12g ich12h ich12v ich20 ich21 ich23 ich25 ich27 ich31 ich32a ich32b ich32c ich32d ich32e ich32f ich32g ich32h ich32v ich33a ich33b ich33c ich33d ich33e ich33f ich33g ich33h ich33v 

//Look for true missing values in pre-natal visits
//tab ich07, missing

//Recode nonmissing .'s as 0's 
foreach x of var ich08a ich08b ich08c ich08d ich08e ich08f ich08g ich08h ich08i ich08v ich10a ich10b ich10c ich10d ich10e ich10f ich10g ich10h ich10i ich10v ich12a ich12b ich12c ich12d ich12e ich12f ich12g ich12h ich12i ich12v{
replace `x'=0 if `x'==. & ich07!=.
}

//complications in pregnancy
g any_complications = 1 if ich27 == 3
replace any_complications = 0 if ich27 == 1

//Inspect variable values
//tab1 ich07 ich08a ich08b ich08c ich08d ich08e ich08f ich08g ich08h ich08i ich08v ich10a ich10b ich10c ich10d ich10e ich10f ich10g ich10h ich10i ich10v ich12a ich12b ich12c ich12d ich12e ich12f ich12g ich12h ich12i ich12v, missing

//Calculate total number of pre-natal visits
gen pre_natal_visits=0
foreach x of var ich08a ich08b ich08c ich08d ich08e ich08f ich08h ich08i ich08v ich10a ich10b ich10c ich10d ich10e ich10f ich10h ich10i ich10v ich12a ich12b ich12c ich12d ich12e ich12f ich12h ich12i ich12v{
	replace pre_natal_visits=pre_natal_visits+`x' if `x'<.
}
**Removing ich08g, ich10g, ich12g (dukun bayi) from the sum total

replace pre_natal_visits=. if ich07==.
replace pre_natal_visits = 20 if pre_natal_visits > 20 & pre_natal_visits < .

//Generate dummy for greater than/equal 4 pre-natal visits
gen pre_natal_dummy=1 if pre_natal_visits>=4 & pre_natal_visits<.
replace pre_natal_dummy=0 if pre_natal_visits<4

//Inspect variable values
//tab pre_natal_visits pre_natal_dummy, missing

//Look for missing values of iron pill delivery
//tab ich21, missing

//Generate dummy variable for > 90 iron pills received during pregnancy 
gen iron_pills_dummy=1 if ich21==4
replace iron_pills_dummy=0 if ich21<4 | ich20 == 3

gen iron_pills_categ = ich21
replace iron_pills_categ = 0 if ich20 == 3
replace iron_pills_categ = .y if ich21 == 8
label define ironcat 0 "Did not receive any" 1 "1-30 pills" 2 "31-60 pills" 3 "61-90 pills" 4 ">90 pills" 8 "Do Not Know, but did receive" .y "Do Not Know, but did receive"
label values iron_pills_categ ironcat

//Inspect variable values
//tab ich21 iron_pills_dummy, missing

//Generate dummy variable for delivery assisted by doctor or midwife
multparse ich25 dummy
gen good_assisted_delivery=1 if dummy_A==1 | dummy_B==1
replace good_assisted_delivery=0 if dummy_A!=1 & dummy_B!=1 & ich25!=""

//Inspect variable values
//tab ich25 good_assisted_delivery, missing

//Look for true missing values in post-natal vists
//tab ich31, missing

//Recode nonmissing .'s as 0's
foreach x of var ich32a ich32b ich32c ich32d ich32e ich32f ich32g ich32h ich32i ich32v ich33a ich33b ich33c ich33d ich33e ich33f ich33g ich33h ich33i ich33v{
replace `x'=0 if `x'==. & ich31!=.
}

//Inspect variable values
//tab1 ich31 ich32a ich32b ich32c ich32d ich32e ich32f ich32g ich32h ich32v ich33a ich33b ich33c ich33d ich33e ich33f ich33g ich33h ich33v, missing

//Calculate total number of post-natal visits
gen post_natal_visits=0
foreach x of var ich32a ich32b ich32c ich32d ich32e ich32f ich32h ich32i ich32v ich33a ich33b ich33c ich33d ich33e ich33f ich33h ich33i ich33v{
replace post_natal_visits=post_natal_visits+`x' if `x'<.
}
**Removing ich32g, ich33g (dukun bayi) from the sum total

replace post_natal_visits=. if ich31==.
replace post_natal_visits = 10 if post_natal_visits > 10 & post_natal_visits < .

//Generate dummy variable for >=2 post-natal visits
gen post_natal_dummy=1 if post_natal_visits>=2 & post_natal_visits<.
replace post_natal_dummy=0 if post_natal_visits<2 

//Explain missings
tab1 pre_natal_visits pre_natal_dummy, missing
tab iron_pills_dummy, missing 
tab ich20 iron_pills_dummy, missing
tab good_assisted_delivery, missing 
tab ich23 good_assisted_delivery, missing
tab1 post_natal_visits post_natal_dummy, missing 
tab ich23 post_natal_dummy, missing

sort iid
tempfile temp8
save `temp8'
clear

use Data\I

//keep iid isup_cd iedit_cd


sort iid
merge iid using `temp8', uniqmaster _merge(_merge2)
tab _merge2
keep if _merge2 == 3

//Generate variable for observation type (Married woman 16-49 years old == 6)
gen obs_type = 6
label define obstype_label 6 "Married Woman 16-49 years old"
label values obs_type obstype_label

//Keep relevant variables
//keep iid obs_type pre_natal_visits pre_natal_dummy iron_pills_dummy good_assisted_delivery post_natal_visits post_natal_dummy ich20 ich23 isup_cd iedit_cd any_complications 


foreach x of var pre_natal_visits pre_natal_dummy  iron_pills_dummy iron_pills_categ good_assisted_delivery post_natal_visits post_natal_dummy{
	rename `x' `x'_w2
	}

//Rename variables for consistency in future merges
gen id = iid
order id
drop iid
/*rename isup_cd sup_code
rename iedit_cd editor_code*/

//Generating variables to look panel individuals across waves
gen rid= substr(id,1,3) + "1" + substr(id,5,7)
sort rid
tempfile temp
save `temp'

use Data\R, clear

gen panel_hh = (rar00x == 1 | rar00x == 2)
gen panel_hh_id_w2 = substr(rid, 1,3) + substr(rid,5,7)


keep rid panel_hh panel_hh_id_w2 rar00x
sort rid

merge rid using `temp', uniqmaster _merge(_mx)
tab _mx
keep if _mx == 3



//Generating Variables for identification to check in merges
gen hh_serial_no_w2 = icov1_cd


order id
sort id

tempfile temp
save `temp'

//Merging in age information
use Data\R_AR_01, clear
duplicates drop
tostring rar00, replace format(%02.0f)

gen id = substr(rid,1,3) + "2" + substr(rid,5,7) + rar00

//Replace missing days with 15 if neither month nor year values for children's birth dates missing
replace rar04_dd=15 if rar04_dd>=. & rar04_mm<. & rar04_yy<.

//Replace nonleap year February 29's with February 28's
replace rar04_dd=28 if rar04_dd==29 & rar04_mm==2 & rar04_yy!=2004 & rar04_yy!=2000 & rar04_yy!=1996 & rar04_yy!=1992 & rar04_yy!=1988 & rar04_yy!=1984 & rar04_yy!=1980 & rar04_yy!=1976 & rar04_yy!=1972 & rar04_yy!=1968 & rar04_yy!=1964 & rar04_yy!=1960 & rar04_yy!=1956 

keep id rar04_*
sort id

merge id using `temp', uniqmaster
tab _merge

keep if _merge == 3
drop _m*


//Generate birth dates
gen birth_date_mother=mdy(rar04_mm,rar04_dd,rar04_yy)

sort id
tempfile temp
save `temp'

use Data\I, clear

rename iid id

//Generate survey dates using first survey attempt with at least partial completion
gen survey_date=mdy(iivw_mm_1, iivw_dd_1, iivw_yy_1) if ihkw_1==1 | ihkw_1==2
replace survey_date=mdy(iivw_mm_2, iivw_dd_2, iivw_yy_2) if survey_date==. & ihkw_2==1 | ihkw_2==2
replace survey_date=mdy(iivw_mm_3, iivw_dd_3, iivw_yy_3) if survey_date==. & ihkw_3==1 | ihkw_3==2

gen survey_month = ym(iivw_yy_1, iivw_mm_1) if ihkw_1==1 | ihkw_1==2
replace survey_month= ym(iivw_yy_2, iivw_mm_2) if survey_month==. & ihkw_2==1 | ihkw_2==2
replace survey_month= ym(iivw_yy_3, iivw_mm_3) if survey_month==. & ihkw_3==1 | ihkw_3==2

gen survey_year = iivw_yy_1 if ihkw_1==1 | ihkw_1==2
replace survey_year= iivw_yy_2 if survey_year==. & ihkw_2==1 | ihkw_2==2
replace survey_year= iivw_yy_3 if survey_year==. & ihkw_3==1 | ihkw_3==2

gen panel_2007 = (icov3 == 1)

keep id survey_date survey_year survey_month panel_2007

sort id
merge id using `temp', uniqmaster
tab _m
keep if _m == 3
drop _m

gen age = survey_date - birth_date_mother
gen age_years = floor(age/365.25)
//replace age_years = survey_year - rar04_yy if age_years == .

sort id
tempfile temp2
save `temp2'

***

use Data\R_AR_01, clear
duplicates drop

tostring rar00_07 rar00, replace format(%02.0f)
gen id = substr(rid,1,3) + "2" + substr(rid,5,7) + rar00


keep rar00 rar00_07 rar01a id

sort id
merge id using `temp2', uniqmaster _merge(_ind_roster_info_merge)
tab _ind_roster_info_merge
keep if _ind_roster_info_merge == 3



gen panel_id_w2 = id
gen art_split_w2 = substr(id,10,2)

**
replace panel_id_w2 = substr(panel_id,1,9) + "00" + rar00_07 if rar00_07 != "00" & rar00_07 != ""
sort panel_id_w2
**

compress
save marriedwoman16to49years_w2, replace


