clear
set more off

cd "Wave III"

/*In this file, data in the files I_CH and I from the section of the survey 'Book 1B: Married Woman 16-49 Years Old' to determine the following variables:
pre_natal_visits:		the total number of pre-natal visits, previous 18 months 
pre_natal_dummy:		whether or not >=4 pre-natal visits took place, previous 18 months
iron_pills_dummy:		whether or not >=90 iron pills were given, previous 18 months
good_assisted_delivery:	whether or not delivery was assited by a doctor or midwife, previous 18 months
post_natal_visits:	the total number of post-natal visits within 40 days of pregnancy, previous 18 months
post_natal_dummy:		whether or not >=2 post-natal visits took place, previous 18 months

iron_pills_categ		categories for how many iron pills received, previous 18 months 0 "Did not receive any" 1 "1-30 pills" 2 "31-60 pills" 3 "61-90 pills" 4 ">90 pills" 8 "Do Not Know, but did receive"

*/




****First determining which pregnancies occurred in the previous 18 months, as these are the only ones we are interested in at this point

set more off

******************************************************************************************
//Creating mother level information on date of survey for use in determining children's ages
******************************************************************************************

use Data\I, clear

duplicates drop


**Survey dates are Oct-Dec 2009

//Generate survey dates
gen survey_start_day = substr(istart_d,1,2)
destring survey_start_day, replace 
gen survey_start_mon = substr(istart_d,4,2)
destring survey_start_mon, replace 
gen survey_start_year = substr(istart_d,7,2)
destring survey_start_year, replace 
replace survey_start_year = survey_start_year + 2000

gen survey_finish_day = substr(ifinish_d,1,2)
destring survey_finish_day, replace 
gen survey_finish_mon = substr(ifinish_d,4,2)
destring survey_finish_mon, replace 
gen survey_finish_year = substr(ifinish_d,7,2)
destring survey_finish_year, replace 
replace survey_finish_year = survey_finish_year + 2000

gen survey_start_date=	mdy(survey_start_mon, survey_start_day, survey_start_year) 
gen survey_finish_date=	mdy(survey_finish_mon, survey_finish_day, survey_finish_year)
gen survey_days_elapse = survey_finish_date - survey_start_date

summ survey_days_elapse, d
**Very short time elapsed and 1 obs which has start date as 1 day after finish, we use survey start date as survey_date

gen survey_date = survey_start_date
gen survey_month = ym(survey_start_year, survey_start_mon) 

drop survey_start* survey_finish*



merge iid using Data\I_CH, uniqmaster
tab _m
tab ich01 _m, m
drop if _m == 1

//If ich03_cd is . means is not in household, still born, miscarriage, or live then died

codebook survey_date


sort iid
tempfile pregnancy_last24months
save `pregnancy_last24months'

keep iid survey_date survey_month icov3
duplicates drop

tempfile temp1
save `temp1'

***Merging in information for linking to wave 1 info on mothers (b/c of panel related pregnancy history skips)
use Data\R_AR_01, clear
duplicates drop

tempfile R_AR_01_duplicates_drop
save `R_AR_01_duplicates_drop'

tostring rar00_07 rar00, replace format(%02.0f)
gen iid = substr(rid,1,3) + "2" + substr(rid,5,9) + rar00
keep rar00 rar00_07 rar01a iid rid

sort iid
merge iid using `temp1', uniqmaster _merge(_ind_roster_info_merge)
tab _ind_roster_info_merge
keep if _ind_roster_info_merge == 3


gen panel_id_w3 = iid
replace panel_id_w3 = substr(panel_id_w3,1,9) + "00" + "00" + rar00_07 if rar00_07 != "00" & rar00_07 != ""


sort iid

tempfile pregnancy_last24months_id
save `pregnancy_last24months_id'


***************************************************************************
//Info on current pregnancies and total births per mother in the last 24 months
***************************************************************************
use Data\I_CH, clear

gen x = 1
bys iid: egen births_last24 = total(x)
drop x

gen curr_preg_18 = 1 if ich02 == 1
replace curr_preg_18 = 0 if ich02 != 1
gen curr_preg = 1
replace curr_preg = 0 if ich02 != 1
bys iid: egen curr_preg_18_tot = total(curr_preg_18)
bys iid: egen curr_preg_tot = total(curr_preg)

keep curr_preg_18_tot curr_preg_tot births_last24 iid
duplicates drop 

sort iid
tempfile current
save `current'

*****************************************************************
//Info on pregnancies for children alive and living in house
*****************************************************************

use Data\R, clear

duplicates drop

//Generate survey dates
gen survey_start_day = substr(rstart_d,1,2)
destring survey_start_day, replace 
gen survey_start_mon = substr(rstart_d,4,2)
destring survey_start_mon, replace 
gen survey_start_year = substr(rstart_d,7,2)
destring survey_start_year, replace 
replace survey_start_year = survey_start_year + 2000

gen survey_finish_day = substr(rfinish_d,1,2)
destring survey_finish_day, replace 
gen survey_finish_mon = substr(rfinish_d,4,2)
destring survey_finish_mon, replace 
gen survey_finish_year = substr(rfinish_d,7,2)
destring survey_finish_year, replace 
replace survey_finish_year = survey_finish_year + 2000

gen survey_start_date=	mdy(survey_start_mon, survey_start_day, survey_start_year) 
gen survey_finish_date=	mdy(survey_finish_mon, survey_finish_day, survey_finish_year)
gen survey_days_elapse = survey_finish_date - survey_start_date

summ survey_days_elapse, d

gen survey_date = survey_start_date
gen survey_month = ym(survey_start_year, survey_start_mon) 

drop survey_start* survey_finish*

duplicates drop rid, force

keep rid survey_date survey_month rar00x
sort rid

tempfile household_survey_dates
save `household_survey_dates'

merge rid using `R_AR_01_duplicates_drop', uniqmaster
tab _m

//drop if don't have info on mother's number (dead, not in house or missing)
drop if rar06 >= 51
tostring rar06, gen(mother_id) format(%02.0f)

gen iid = substr(rid,1,3) + "2" + substr(rid,5,9) + mother_id

keep if rar04_yy >= 2008 | (rar04_yy == 2007 & rar04_mm >= 10 & rar04_mm < .)

gen born_2007 = (rar04_yy == 2007)

//Replace missing days with 15 if neither month nor year values for children's birth dates missing
replace rar04_dd=15 if rar04_dd>=. & rar04_mm <. & rar04_yy <.

//Replace nonleap year February 29's with February 28's; correct 31's to 30's in certain months
replace rar04_dd=28 if rar04_dd==29 & rar04_mm==2 & rar04_yy!=2004 & rar04_yy != 2008
replace rar04_dd=30 if rar04_dd==31 & (rar04_mm==2 | rar04_mm==4 | rar04_mm==6 | rar04_mm==8 | rar04_mm==11)

//Generate child's birth dates
gen birth_date=mdy(rar04_mm, rar04_dd, rar04_yy)
**the missings are true (.y, .z)

gen birth_diff = survey_date - birth_date

**Survey was between Oct-Dec 2009, so if born in 2009, then within 10-12 months; if born in Jan 2008, within 21-23 months, so 2008 obs are def within 24, ambiguous on 18 and 21 months

gen live_in_house_18 = 1 if birth_diff <= 547.875
replace live_in_house_18 = 0 if birth_diff > 547.875 & birth_diff < .
replace live_in_house_18 = 1 if rar04_yy == 2009

gen live_in_house_over18 		= 1 if birth_diff > 547.875 & birth_diff < .
replace live_in_house_over18 	= 0 if birth_diff <= 547.875
replace live_in_house_over18 = 0 if rar04_yy == 2009 

gen live_in_house_12to24 = 1 if birth_diff > 365.25 & birth_diff <= 730.50
replace live_in_house_12to24 = 0 if birth_diff <= 365.25 | (birth_diff > 730.50 & birth_diff < .)
replace live_in_house_12to24 = 0 if rar04_yy == 2009

gen live_in_house_24 = 1 if birth_diff <= 730.50
replace live_in_house_24 = 0 if birth_diff > 730.50 & birth_diff < .
replace live_in_house_24 = 1 if rar04_yy == 2009 | rar04_yy == 2008

gen live_in_house_21 = 1 if birth_diff <= 639.1875 
replace live_in_house_21 = 0 if birth_diff > 639.1875 & birth_diff < .
replace live_in_house_21 = 1 if rar04_yy == 2009

gen live_in_house_12to21 = 1 if birth_diff > 365.25 & birth_diff <= 639.1875
replace live_in_house_12to21 = 0 if birth_diff <= 365.25 | (birth_diff > 639.1875 & birth_diff < .)
replace live_in_house_12to21 = 0 if rar04_yy == 2009

gen live_in_house = 1


//Merging with mother dataset on births in last 24 months
sort iid
merge iid using `pregnancy_last24months_id', uniqusing _merge(_mx)
tab _mx


tab live_in_house _mx, m
tab live_in_house_18 _mx , m
tab live_in_house_over18 _mx, m
tab live_in_house_12to24 _mx, m
tab live_in_house_24 _mx, m
tab live_in_house_21 _mx, m
tab live_in_house_12to21 _mx, m


//Keeping only if matching with mother surveyed from I_CH
keep if _mx == 3

gen live_in_bdiff_miss = 1 if birth_diff == . & live_in_house_18 != 1

tempfile kids_input
save `kids_input'

bys iid: egen live_in_house_18_tot = total(live_in_house_18)
bys iid: egen live_in_house_over18_tot = total(live_in_house_over18)
bys iid: egen live_in_house_tot = total(live_in_house)
bys iid: egen live_in_bdiff_miss_tot = total(live_in_bdiff_miss)

gen preg_type = 4
keep live_in_house_18_tot live_in_bdiff_miss_tot live_in_house_tot iid survey_date survey_month live_in_house_over18_tot 
duplicates drop

//Saving mother level dataset with total number of kids under 18 living in house
sort iid
tempfile live_in_house
save `live_in_house'

//Creating kid level information from household roster for direct merge later
use `kids_input', clear
tostring(rar00), gen(kid) format(%02.0f)
gen kid_id = substr(rid,1,3) + "4" + substr(rid,5,9) + kid
//keep if live_in_house_18 == 1
duplicates drop


rename live_in_house_18 live_in_house_18_ind
rename live_in_house_over18 live_in_house_over18_ind 
rename live_in_house_12to24 live_in_house_12to24_ind
rename live_in_house_24 live_in_house_24_ind
rename live_in_house_21 live_in_house_21_ind
rename live_in_house_12to21 live_in_house_12to21_ind

keep kid_id live_in_house_18_ind live_in_house_over18_ind live_in_house_12to24_ind live_in_house_24 live_in_house_21 live_in_house_12to21 live_in_house birth_diff born_2007
sort kid_id

//Saving kid level dataset with info on under 18 and living in house
tempfile kids
save `kids'
save kids_in_house, replace


*****************************************************************
//Info on pregnancies for children alive but not living in house
*****************************************************************

use `household_survey_dates', clear

merge rid using Data\R_AR_26, uniqmaster
tab _m
keep if _m == 3


//drop if don't have info on mother's number (dead, out of household, missing)
drop if rar32 >= 51
tostring rar32, gen(mother_id) format(%02.0f)

gen iid = substr(rid,1,3) + "2" + substr(rid,5,9) + mother_id

keep if rar30_yy >= 2008 | (rar30_yy == 2007 & rar30_mm >= 10 & rar30_mm < .)

gen born_2007 = (rar30_yy == 2007)

//Replace missing days with 15 if neither month nor year values for children's birth dates missing
replace rar30_dd=15 if rar30_dd>=. & rar30_mm <. & rar30_yy <.

//Replace nonleap year February 29's with February 28's
replace rar30_dd=28 if rar30_dd==29 & rar30_mm==2 & rar30_yy!=2004 & rar30_yy!=2008
replace rar30_dd=30 if rar30_dd==31 & (rar30_mm==2 | rar30_mm==4 | rar30_mm==6 | rar30_mm==8 | rar30_mm==11)

//Generate child's birth dates
gen birth_date=mdy(rar30_mm, rar30_dd, rar30_yy)
**the missings are true (.y, .z)

gen birth_diff = survey_date - birth_date

**Survey between Oct-Dec 2009, so if born in 2009 then within 10-12 months

gen live_out_house_18 = 1 if birth_diff <= 547.875
replace live_out_house_18 = 0 if birth_diff > 547.875 & birth_diff < .
replace live_out_house_18 = 1 if rar30_yy == 2009

gen live_out_house_over18 = 1 if birth_diff > 547.875 & birth_diff < .
replace live_out_house_over18 = 0 if birth_diff <= 547.875 
replace live_out_house_over18 = 0 if rar30_yy == 2009

gen live_out_house_12to24 = 1 if birth_diff > 365.25 & birth_diff <= 730.50
replace live_out_house_12to24 = 0 if birth_diff <= 365.25 | (birth_diff > 730.50 & birth_diff < .)
replace live_out_house_12to24 = 0 if rar30_yy == 2009

gen live_out_house_24 = 1 if birth_diff <= 730.50
replace live_out_house_24 = 0 if birth_diff > 730.50 & birth_diff < .
replace live_out_house_24 = 1 if rar30_yy == 2009 | rar30_yy == 2008

gen live_out_house_21 = 1 if birth_diff <= 639.1875 
replace live_out_house_21 = 0 if birth_diff > 639.1875 & birth_diff < .
replace live_out_house_21 = 1 if rar30_yy == 2009

gen live_out_house_12to21 = 1 if birth_diff > 365.25 & birth_diff <= 639.1875
replace live_out_house_12to21 = 0 if birth_diff <= 365.25 | (birth_diff > 639.1875 & birth_diff < .)
replace live_out_house_12to21 = 0 if rar30_yy == 2009

gen live_out_house = 1


//Merging with mother dataset on births in last 24 months
sort iid
merge iid using `pregnancy_last24months_id', uniqusing _merge(_mx)
tab _mx

tab live_out_house _mx, m
tab live_out_house_18 _mx , m
tab live_out_house_12to24 _mx, m
tab live_out_house_21 _mx, m
tab live_out_house_24 _mx, m
tab live_out_house_12to21 _mx, m


//Keeping only if matching with mother surveyed from I_CH
keep if _mx == 3

gen live_out_bdiff_miss = 1 if birth_diff == . & live_out_house_18 != 1
tempfile kids_out_input
save `kids_out_input'

bys iid: egen live_out_house_18_tot = total(live_out_house_18)
bys iid: egen live_out_house_over18_tot = total(live_out_house_over18)
bys iid: egen live_out_house_tot = total(live_out_house)
bys iid: egen live_out_bdiff_miss_tot = total(live_out_bdiff_miss)

gen preg_type = 4
keep live_out_house_18_tot live_out_bdiff_miss_tot live_out_house_tot iid live_out_house_over18_tot
duplicates drop

//Saving mother level dataset with total number of kids under 18 living in house
sort iid
tempfile live_out_house
save `live_out_house'


//Creating child level dataset
use `kids_out_input', clear
//51 is used to signify those who live outside of household for individuals
//If not match in for mortality calcs etc., check to see if mom has a "52" child, etc.
gen kid_id = substr(rid,1,3) + "4" + substr(rid,5,9) + "51"
duplicates drop
**No duplicates

duplicates report kid_id
**No duplicates in terms of kid_id, so need not worry about when merge in later

rename live_out_house_18 live_out_house_18_ind
rename live_out_house_over18 live_out_house_over18_ind 
rename live_out_house_12to24 live_out_house_12to24_ind
rename live_out_house_24 live_out_house_24_ind
rename live_out_house_21 live_out_house_21_ind
rename live_out_house_12to21 live_out_house_12to21_ind

keep kid_id live_out_house_18_ind live_out_house_over18_ind live_out_house_12to24_ind live_out_house_24_ind live_out_house_21_ind live_out_house_12to21_ind live_out_house birth_diff born_2007 rar30_mm rar30_yy
sort kid_id



//Saving kid level dataset with info on under 18 but not living in house
tempfile kids_out
save `kids_out'
save kids_out_house, replace


*****************************************************************
//Info on still born pregancies
*****************************************************************
//Merging with mother dataset on births in last 24 months
use `pregnancy_last24months_id', clear
sort iid
merge iid using Data\I_RH19, uniqmaster
tab icov3 _m, m
tab irh19_yy _m, m

//Keeping only if matching with mother surveyed from I_CH
keep if _m == 3


tempfile stillborn_w3_info
save `stillborn_w3_info'


**Dropping empty observations (true missings are distinguished with .y)
drop if irh19_yy == .

keep if irh19_yy >= 2008 | (irh19_yy == 2007 & irh19_mm >= 10 & irh19_mm < .)


//Generate child's birth month info
gen birth_month= ym(irh19_yy, irh19_mm)

gen birth_diff_mon = survey_month - birth_month

gen stillborn_18 = 1 if birth_diff_mon <= 18
replace stillborn_18 = 0 if birth_diff_mon > 18 & birth_diff_mon < .
replace stillborn_18 = 1 if irh19_yy == 2009
**we knows obs in 2009 are less than 18 months, even without month info, so capture any previous 2009 missings

gen stillborn_over18 		= 1 if birth_diff_mon > 18 & birth_diff_mon < .
replace stillborn_over18 = 0 if birth_diff_mon <= 18 
replace stillborn_over18 = 0 if irh19_yy == 2009

gen stillborn = 1

gen preg_type = 3

gen stillborn_bdiff_miss = 1 if birth_diff_mon == . & stillborn_18 != 1

tempfile kids_stillborn_input
save `kids_stillborn_input'

bys iid: egen stillborn_18_tot = total(stillborn_18)
bys iid: egen stillborn_over18_tot = total(stillborn_over18)
bys iid: egen stillborn_tot = total(stillborn)
bys iid: egen stillborn_bdiff_miss_tot = total(stillborn_bdiff_miss)


//Saving mother level dataset with total number of still births in last 18 months
keep stillborn_tot stillborn_18_tot stillborn_bdiff_miss_tot iid stillborn_over18_tot
duplicates drop
sort iid
tempfile stillborn
save `stillborn'

//Creating child level dataset
use `kids_stillborn_input', clear
tostring irh19x, replace
gen kid_id = substr(rid,1,3) + "4" + substr(rid,5,9) + irh19x
duplicates drop
**No duplicates

duplicates report kid_id
**No duplicates in terms of kid_id, so need not worry about when merge in later

rename stillborn_18 stillborn_18_ind
rename stillborn_over18 stillborn_over18_ind 


keep kid_id stillborn_18_ind stillborn_over18_ind stillborn birth_diff
sort kid_id


//Saving kid stillborn under 18 
tempfile kids_stillborn
save `kids_stillborn'
save kids_stillborn, replace


****************************************************************
//Info on miscarriage pregnancies
****************************************************************
//Merging with mother dataset on births in last 24 months
use `pregnancy_last24months_id', clear
merge iid using Data\I_RH23, uniqmaster
tab icov3 _m, m


//Keeping only if matching with mother surveyed from I_CH
keep if _m == 3

tempfile miscarriage_w3_info
save `miscarriage_w3_info'


keep if irh23_yy >= 2008 | (irh23_yy == 2007 & irh23_mm >= 10 & irh23_mm < .)

//Generate miscarriage month info
gen miscarry_month= ym(irh23_yy, irh23_mm)

gen miscarry_diff_mon = survey_month - miscarry_month

gen miscarry_18 = 1 if miscarry_diff_mon <= 18
replace miscarry_18 = 0 if miscarry_diff_mon > 18 & miscarry_diff_mon < .
replace miscarry_18 = 1 if irh23_yy == 2009

gen miscarry_over18 		= 1 if miscarry_diff_mon > 18 & miscarry_diff_mon < .
replace miscarry_over18 = 0 if miscarry_diff_mon <= 18 
replace miscarry_over18 = 0 if irh23_yy == 2009

gen miscarry = 1

gen preg_type = 2

gen miscarry_bdiff_miss = 1 if miscarry_diff_mon == . & miscarry_18 != 1

bys iid: egen miscarry_18_tot = total(miscarry_18)
bys iid: egen miscarry_over18_tot = total(miscarry_over18)
bys iid: egen miscarry_tot = total(miscarry)
bys iid: egen miscarry_bdiff_miss_tot = total(miscarry_bdiff_miss)

//Saving mother level dataset with total number of miscarriages in last 18 months
keep miscarry_18_tot miscarry_tot miscarry_bdiff_miss_tot iid miscarry_over18_tot
duplicates drop
sort iid
tempfile miscarry
save `miscarry'


****************************************************************
//Info on pregnancies for children born alive then died
****************************************************************
//Merging with mother dataset on births in last 24 months
use `pregnancy_last24months_id', clear
merge iid using Data\I_RH13, uniqmaster
tab icov3 _m, m

//Keeping only if matching with mother surveyed from I_CH
keep if _m == 3

tempfile livethendied_w3_info
save `livethendied_w3_info'

keep if irh13_yy >= 2008 | (irh13_yy == 2007 & irh13_mm >= 10 & irh13_mm < .)


**Dropping empty observations (true missings are distinguished with .y)
drop if irh13_yy == .

//Generate birth month info
gen birth_month = ym(irh13_yy, irh13_mm)

gen birth_diff_mon = survey_month - birth_month

gen born_2007 = (irh13_yy == 2007)

gen live_then_died_18 = 1 if birth_diff_mon <= 18
replace live_then_died_18 = 0 if birth_diff_mon > 18 & birth_diff_mon < .
replace live_then_died_18 = 1 if irh13_yy == 2009

gen live_then_died_over18 		= 1 if birth_diff_mon > 18 & birth_diff_mon < .
replace live_then_died_over18 = 0 if birth_diff_mon <= 18 
replace live_then_died_over18 = 0 if irh13_yy == 2009

gen live_then_died = 1

gen preg_type = 4

gen live_then_died_bdiff_miss = 1 if birth_diff_mon == . & live_then_died_18 != 1

tempfile kids_live_then_died_input
save `kids_live_then_died_input', replace

bys iid: egen live_then_died_18_tot = total(live_then_died_18)
bys iid: egen live_then_died_over18_tot = total(live_then_died_over18)
bys iid: egen live_then_died_tot = total(live_then_died)
bys iid: egen live_then_died_bdiff_miss_tot = total(live_then_died_bdiff_miss)


//Saving mother level dataset with total number of miscarriages in last 18 months
keep live_then_died_tot live_then_died_18_tot live_then_died_bdiff_miss_tot iid live_then_died_over18_tot
duplicates drop
sort iid
tempfile live_then_died
save `live_then_died'


//Creating child level dataset
use `kids_live_then_died_input', clear
tostring irh13x, replace
gen kid_id = substr(rid,1,3) + "4" + substr(rid,5,9) + irh13x
duplicates drop
**No duplicates

duplicates report kid_id
**No duplicates in terms of kid_id, so need not worry about when merge in later

rename live_then_died_18 live_then_died_18_ind
rename live_then_died_over18 live_then_died_over18_ind 


keep kid_id live_then_died_18_ind live_then_died_over18_ind live_then_died birth_diff born_2007
sort kid_id


//Saving kid level dataset with info on under 18 but died
tempfile kids_live_then_died
save `kids_live_then_died'
save kids_live_then_died, replace



********************************************************************************************
//Merging all the mother level information on the total number of births in the last 18 months
********************************************************************************************
use `live_then_died', clear

merge iid using `miscarry', sort _merge(_m1)
tab _m1
//drop _m1

merge iid using `stillborn', sort _merge(_m2)
tab _m2
//drop _m2

merge iid using `live_out_house', sort _merge(_m3)
tab _m3
//drop _m3

merge iid using `live_in_house', sort _merge(_m4)
tab _m4
//drop _m4

merge iid using `current', sort _merge(_m5)
tab _m5
//drop _m5


//Creating a tally of the total number of births in the last 18 months & 18-24 months for each mother using info from the HH rosters and the I_RH datasets
gen births_last18 = 0
gen births_over18 = 0
foreach x of var live_then_died_18_tot miscarry_18_tot stillborn_18_tot live_out_house_18_tot live_in_house_18_tot curr_preg_18_tot{
	replace births_last18 = births_last18 + 1 if `x' == 1
	replace births_last18 = births_last18 + 2 if `x' == 2
}

foreach x of var live_then_died_over18_tot miscarry_over18_tot stillborn_over18_tot live_out_house_over18_tot live_in_house_over18_tot{
	replace births_over18 = births_over18 + 1 if `x' == 1
	replace births_over18 = births_over18 + 2 if `x' == 2
}

//Creating a tally of the number of missing dates
gen missing_dates_last18 = 0
foreach x in live_then_died miscarry stillborn live_out live_in{
	replace missing_dates_last18 = missing_dates_last18 + `x'_bdiff_miss_tot if `x'_bdiff_miss_tot != .
	}

sort iid
tempfile birth_info
save `birth_info'


******************************************************************************************************************
//Merging the totals for each birth type and cumulative at the mother level with the kid level pregnancy information
******************************************************************************************************************

merge iid using Data\I_CH, uniqmaster _merge(_mm)
tab _mm


//Creating variables tallying the total number of each type of pregnancy by mother (within the last 24 months)
gen preg_1 = 1 if ich02 == 1
gen preg_2 = 1 if ich02 == 2
gen preg_3 = 1 if ich02 == 3
gen preg_4 = 1 if ich02 == 4

foreach x of var preg_1 preg_2 preg_3 preg_4{
	bys iid: egen `x'_2 = total(`x')
	replace `x' = `x'_2
	drop `x'_2
	}



**Dropping case which comes up as not matching because have two kids listed in born live then died (2 months (kid = 62) and 22 months (kid = 61)), but the ich03 code (61) in I_CH only matches with the 22 month child, can't be sure if this code should be switched or just don't have info on 2 months
drop if iid == "013201005000003" 
**Correcting case whether mother had two kids one born live then died in 2003 (kid == 61) and one in 2009 (kid == 62), but in I_CH have kid_id as 61, that kid not born in last 24 months, so assume is miscoding and should be 62
replace ich03_cd = 62 if iid == "303201102000002"
**Correcting case where we have one kid born live then died in 2009 (kid == 61) but in I_CH have kid_id as 71 (which would indicate a stillbirth, not a live then died as should be), assume this is miscoding and should be 61
replace ich03_cd = 61 if iid == "507200303000002"
**Correcting case where we have one currenty pregnancy and one kid live then died (both kid == 62), replace current pregnancy with missing for ich03_cd
replace ich03_cd = . if ich02 == 1 & iid == "303201102000002"

//Generating the child level id number for merges using information from the household rosters
tostring(ich03_cd), gen(kid) format(%02.0f)
gen kid_id = substr(iid,1,3) + "4" + substr(iid,5,9) + kid
duplicates tag kid_id, gen(tagx)




**********************************************************************************************************
//Merging in information from the household rosters on kids living in the household and out of the household
**********************************************************************************************************
//In household
sort kid_id
merge kid_id using `kids', uniqusing _merge(kid_in_house_merge)
tab kid_in_house_merge

drop if kid_in_house_merge == 2

drop if kid_in_house_merge == 3 & ich02 == 1


***********
//Out of household
sort kid_id
merge kid_id using `kids_out', uniqusing _merge(kid_out_house_merge)
tab kid_out_house_merge

drop if kid_out_house_merge == 2


gen still_alive = 1 if kid_in_house_merge == 3 | kid_out_house_merge == 3

*************
//Live then died
sort kid_id
merge kid_id using `kids_live_then_died', uniqusing _merge(kid_live_then_died_merge)
tab kid_live_then_died_merge

drop if kid_live_then_died_merge == 2


*************
//Stillborn
sort kid_id
merge kid_id using `kids_stillborn', uniqusing _merge(kid_stillborn_merge)
tab kid_stillborn

drop if kid_stillborn == 2



*************************************************************************************************************
//Determining which child level observations were within the last 18 months
*************************************************************************************************************

//If the number of births tallied in the last 18 months is equal to the number of births counted from the child specific information, create a marker for comparison
//We do not use this directly due to issues of mother's with children who are found in the I_CH dataset recalling information on other children in the I_RH datasets
//who are not found in the I_CH dataset (this therefore would lead to a births_last18 tally which would be higher than otherwise, so we could have children who are actually
//not in the last 18 months become marked as being so; we keep the marker to use in comparison for confirmation of proper categorization in okay_18 below)

gen all_18 = 1 if births_last18 >= births_last24
gen okay_18_alt = 1 if all_18 == 1

//If currently pregnant with child at time of interview, definitely within last 18 months
gen okay_18 = 1 if ich02 == 1
gen okay_over18 = 0 if ich02 == 1

gen okay_18_v2 = 1 if ich02 == 1
gen okay_over18_v2 = 0 if ich02 == 1


//Marking as okay if found in the household roster, live in house, and under 18 months
codebook ich02 live_in_house_18_tot if kid_in_house_merge == 3 
replace okay_18 = 1 if kid_in_house_merge == 3 & live_in_house_18_ind == 1
replace okay_over18 = 1 if kid_in_house_merge == 3 & live_in_house_over18_ind == 1

replace okay_18_v2 = 1 if kid_in_house_merge == 3 & live_in_house_18_ind == 1
replace okay_over18_v2 = 1 if kid_in_house_merge == 3 & live_in_house_over18_ind == 1


//Marking as okay if found in the live out of household roster, live out of house, and under 18 months
codebook ich02 live_out_house_18_tot if kid_out_house_merge == 3
replace okay_18 = 1 if kid_out_house_merge == 3 & live_out_house_18_ind == 1
replace okay_over18 = 1 if kid_out_house_merge == 3 & live_out_house_over18_ind == 1

replace okay_18_v2 = 1 if kid_out_house_merge == 3 & live_out_house_18_ind == 1
replace okay_over18_v2 = 1 if kid_out_house_merge == 3 & live_out_house_over18_ind == 1


//Marking as okay if born live then died and under 18 months  (for version 2) 
codebook ich02 live_then_died_18_tot if kid_live_then_died == 3
replace okay_18_v2 = 1 if kid_live_then_died_merge == 3 & live_then_died_18_ind == 1
replace okay_over18_v2 = 1 if kid_live_then_died_merge == 3 & live_then_died_over18_ind == 1


//Marking as okay if stillborn and under 18 months (for version 2) 
codebook ich02 stillborn_18_tot if kid_stillborn == 3
replace okay_18_v2 = 1 if kid_stillborn_merge == 3 & stillborn_18_ind == 1
replace okay_over18_v2 = 1 if kid_stillborn_merge == 3 & stillborn_over18_ind == 1


**ich02 == 1 is always okay_18 == 1 b/c currently pregnant at time of survey

tempfile temp1
save `temp1'


//Marking those observations for which we know we only have one of that type per mother and we know that we have one within 18 months
replace okay_18 = 1 if ich02 == 2 & preg_2 == 1 & miscarry_18_tot == 1
replace okay_18 = 1 if ich02 == 3 & preg_3 == 1 & stillborn_18_tot == 1
replace okay_18 = 1 if ich02 == 4 & preg_4 == 1 & live_then_died_18_tot == 1 & still_alive != 1

replace okay_18_v2 = 1 if ich02 == 2 & preg_2 == 1 & miscarry_18_tot == 1

replace okay_over18 = 1 if ich02 == 2 & preg_2 == 1 & miscarry_over18_tot == 1
replace okay_over18 = 1 if ich02 == 3 & preg_3 == 1 & stillborn_over18_tot == 1
replace okay_over18 = 1 if ich02 == 4 & preg_4 == 1 & live_then_died_over18_tot == 1 & still_alive != 1

replace okay_over18_v2 = 1 if ich02 == 2 & preg_2 == 1 & miscarry_over18_tot == 1


//Marking those observations for which we know we only have two of that type per mother and we know that we have two within 18 months
replace okay_18 = 1 if ich02 == 2 & preg_2 == 2 & miscarry_18_tot == 1 & ich02_line == 1
replace okay_18 = 1 if ich02 == 2 & preg_2 == 2 & miscarry_18_tot == 2 & ich02_line <= 2
replace okay_18 = 1 if ich02 == 3 & preg_3 == 2 & stillborn_18_tot == 1 & ich02_line == 1
replace okay_18 = 1 if ich02 == 3 & preg_3 == 2 & stillborn_18_tot == 2 & ich02_line <= 2
replace okay_18 = 1 if ich02 == 4 & preg_4 == 2 & live_then_died_18_tot == 1 & ich02_line == 1 & still_alive != 1
replace okay_18 = 1 if ich02 == 4 & preg_4 == 2 & live_then_died_18_tot == 2 & ich02_line <= 2 & still_alive != 1

replace okay_18_v2 = 1 if ich02 == 2 & preg_2 == 2 & miscarry_18_tot == 1 & ich02_line == 1
replace okay_18_v2 = 1 if ich02 == 2 & preg_2 == 2 & miscarry_18_tot == 2 & ich02_line <= 2


replace okay_over18 = 1 if ich02 == 2 & preg_2 == 2 & miscarry_over18_tot == 1 & ich02_line == 2
replace okay_over18 = 1 if ich02 == 2 & preg_2 == 2 & miscarry_over18_tot == 2 & ich02_line <= 2
replace okay_over18 = 1 if ich02 == 3 & preg_3 == 2 & stillborn_over18_tot == 1 & ich02_line == 2
replace okay_over18 = 1 if ich02 == 3 & preg_3 == 2 & stillborn_over18_tot == 2 & ich02_line <= 2
replace okay_over18 = 1 if ich02 == 4 & preg_4 == 2 & live_then_died_over18_tot == 1 & ich02_line == 2 & still_alive != 1
replace okay_over18 = 1 if ich02 == 4 & preg_4 == 2 & live_then_died_over18_tot == 2 & ich02_line <= 2 & still_alive != 1

replace okay_over18_v2 = 1 if ich02 == 2 & preg_2 == 2 & miscarry_over18_tot == 1 & ich02_line == 2
replace okay_over18_v2 = 1 if ich02 == 2 & preg_2 == 2 & miscarry_over18_tot == 2 & ich02_line <= 2


//Marking those observations for which we know we have three of that type per mother and we know that we have three within 18 months
replace okay_18 = 1 if ich02 == 2 & preg_2 == 3 & miscarry_18_tot == 1 & ich02_line == 1
replace okay_18 = 1 if ich02 == 2 & preg_2 == 3 & miscarry_18_tot == 2 & ich02_line <= 2
replace okay_18 = 1 if ich02 == 2 & preg_2 == 3 & miscarry_18_tot == 3 & ich02_line <= 3
replace okay_18 = 1 if ich02 == 3 & preg_3 == 3 & stillborn_18_tot == 1 & ich02_line == 1
replace okay_18 = 1 if ich02 == 3 & preg_3 == 3 & stillborn_18_tot == 2 & ich02_line <= 2
replace okay_18 = 1 if ich02 == 3 & preg_3 == 3 & stillborn_18_tot == 3 & ich02_line <= 3
replace okay_18 = 1 if ich02 == 4 & preg_4 == 3 & live_then_died_18_tot == 1 & ich02_line == 1 & still_alive != 1
replace okay_18 = 1 if ich02 == 4 & preg_4 == 3 & live_then_died_18_tot == 2 & ich02_line <= 2 & still_alive != 1
replace okay_18 = 1 if ich02 == 4 & preg_4 == 3 & live_then_died_18_tot == 3 & ich02_line <= 3 & still_alive != 1

replace okay_18_v2 = 1 if ich02 == 2 & preg_2 == 3 & miscarry_18_tot == 1 & ich02_line == 1
replace okay_18_v2 = 1 if ich02 == 2 & preg_2 == 3 & miscarry_18_tot == 2 & ich02_line <= 2
replace okay_18_v2 = 1 if ich02 == 2 & preg_2 == 3 & miscarry_18_tot == 3 & ich02_line <= 3


replace okay_over18 = 1 if ich02 == 2 & preg_2 == 3 & miscarry_over18_tot == 1 & ich02_line == 3
replace okay_over18 = 1 if ich02 == 2 & preg_2 == 3 & miscarry_over18_tot == 2 & ich02_line >= 2
replace okay_over18 = 1 if ich02 == 2 & preg_2 == 3 & miscarry_over18_tot == 3 & ich02_line >= 1
replace okay_over18 = 1 if ich02 == 3 & preg_3 == 3 & stillborn_over18_tot == 1 & ich02_line == 3
replace okay_over18 = 1 if ich02 == 3 & preg_3 == 3 & stillborn_over18_tot == 2 & ich02_line >= 2
replace okay_over18 = 1 if ich02 == 3 & preg_3 == 3 & stillborn_over18_tot == 3 & ich02_line >= 1
replace okay_over18 = 1 if ich02 == 4 & preg_4 == 3 & live_then_died_over18_tot == 1 & ich02_line == 3 & still_alive != 1
replace okay_over18 = 1 if ich02 == 4 & preg_4 == 3 & live_then_died_over18_tot == 2 & ich02_line >= 2 & still_alive != 1
replace okay_over18 = 1 if ich02 == 4 & preg_4 == 3 & live_then_died_over18_tot == 3 & ich02_line >= 1 & still_alive != 1

replace okay_over18_v2 = 1 if ich02 == 2 & preg_2 == 3 & miscarry_over18_tot == 1 & ich02_line == 3
replace okay_over18_v2 = 1 if ich02 == 2 & preg_2 == 3 & miscarry_over18_tot == 2 & ich02_line >= 2
replace okay_over18_v2 = 1 if ich02 == 2 & preg_2 == 3 & miscarry_over18_tot == 3 & ich02_line >= 1


//Dealing with specific problems in cases which arise due to combination of 3 categories within ich02 == 4 (live then died, in house, out house)
replace okay_18 = 1 if ich02 == 4 & preg_4 == 2 & live_then_died_18_tot == 1 & ich02_line == 2 & (live_out_house_18_tot == 1 | live_in_house_18_tot == 1) & still_alive != 1
replace okay_18 = 1 if ich02 == 4 & preg_4 == 2 & live_in_house_18_tot == 1 & ich02_line == 2 & (live_then_died_18_tot == 1 | live_out_house_18_tot == 1) & still_alive == 1
replace okay_18 = 1 if ich02 == 4 & preg_4 == 2 & live_out_house_18_tot == 1 & ich02_line == 2 & (live_then_died_18_tot == 1 | live_in_house_18_tot == 1) & still_alive == 1


replace okay_over18 = 1 if ich02 == 4 & preg_4 == 2 & live_then_died_over18_tot == 1 & ich02_line == 1 & (live_out_house_over18_tot == 1 | live_in_house_over18_tot == 1) & still_alive != 1
replace okay_over18 = 1 if ich02 == 4 & preg_4 == 2 & live_in_house_over18_tot == 1 & ich02_line == 1 & (live_then_died_over18_tot == 1 | live_out_house_over18_tot == 1) & still_alive == 1
replace okay_over18 = 1 if ich02 == 4 & preg_4 == 2 & live_out_house_over18_tot == 1 & ich02_line == 1 & (live_then_died_over18_tot == 1 | live_in_house_over18_tot == 1) & still_alive == 1


replace okay_18 = 1 if ich02 == 4 & preg_4 == 3 & live_then_died_18_tot == 1 & ich02_line == 2 & (live_out_house_18_tot == 1 | live_in_house_18_tot == 1) & still_alive != 1
replace okay_18 = 1 if ich02 == 4 & preg_4 == 3 & live_then_died_18_tot == 1 & ich02_line == 3 & ((live_out_house_18_tot == 2 | live_in_house_18_tot == 2) | (live_out_house_18_tot == 1 & live_in_house_18_tot == 1)) & still_alive != 1
replace okay_18 = 1 if ich02 == 4 & preg_4 == 3 & live_then_died_18_tot == 2 & ich02_line == 3 & (live_out_house_18_tot == 1 | live_in_house_18_tot == 1) & still_alive != 1
replace okay_18 = 1 if ich02 == 4 & preg_4 == 3 & live_in_house_18_tot == 1 & ich02_line == 2 & (live_then_died_18_tot == 1 | live_out_house_18_tot == 1) & still_alive == 1
replace okay_18 = 1 if ich02 == 4 & preg_4 == 3 & live_in_house_18_tot == 1 & ich02_line == 3 & ((live_then_died_18_tot == 2 | live_out_house_18_tot == 2) | (live_then_died_18_tot == 1 & live_out_house_18_tot == 1)) & still_alive != 1
replace okay_18 = 1 if ich02 == 4 & preg_4 == 3 & live_in_house_18_tot == 2 & ich02_line == 3 & (live_then_died_18_tot == 1 | live_out_house_18_tot == 1) & still_alive != 1
replace okay_18 = 1 if ich02 == 4 & preg_4 == 3 & live_out_house_18_tot == 1 & ich02_line == 3 & (live_then_died_18_tot == 2 | live_in_house_18_tot == 2) & still_alive == 1
replace okay_18 = 1 if ich02 == 4 & preg_4 == 3 & live_out_house_18_tot == 1 & ich02_line == 3 & ((live_then_died_18_tot == 2 | live_in_house_18_tot == 2) | (live_then_died_18_tot == 1 & live_in_house_18_tot == 1)) & still_alive != 1
replace okay_18 = 1 if ich02 == 4 & preg_4 == 3 & live_out_house_18_tot == 2 & ich02_line == 3 & (live_then_died_18_tot == 1 | live_in_house_18_tot == 1) & still_alive != 1


replace okay_over18 = 1 if ich02 == 4 & preg_4 == 3 & live_then_died_over18_tot == 1 & ich02_line == 2 & (live_out_house_over18_tot == 1 | live_in_house_over18_tot == 1) & still_alive != 1
replace okay_over18 = 1 if ich02 == 4 & preg_4 == 3 & live_then_died_over18_tot == 1 & ich02_line == 3 & ((live_out_house_over18_tot == 2 | live_in_house_over18_tot == 2) | (live_out_house_over18_tot == 1 & live_in_house_over18_tot == 1)) & still_alive != 1
replace okay_over18 = 1 if ich02 == 4 & preg_4 == 3 & live_then_died_over18_tot == 2 & ich02_line == 3 & (live_out_house_over18_tot == 1 | live_in_house_over18_tot == 1) & still_alive != 1
replace okay_over18 = 1 if ich02 == 4 & preg_4 == 3 & live_in_house_over18_tot == 1 & ich02_line == 2 & (live_then_died_over18_tot == 1 | live_out_house_over18_tot == 1) & still_alive == 1
replace okay_over18 = 1 if ich02 == 4 & preg_4 == 3 & live_in_house_over18_tot == 1 & ich02_line == 3 & ((live_then_died_over18_tot == 2 | live_out_house_over18_tot == 2) | (live_then_died_over18_tot == 1 & live_out_house_over18_tot == 1)) & still_alive != 1
replace okay_over18 = 1 if ich02 == 4 & preg_4 == 3 & live_in_house_over18_tot == 2 & ich02_line == 3 & (live_then_died_over18_tot == 1 | live_out_house_over18_tot == 1) & still_alive != 1
replace okay_over18 = 1 if ich02 == 4 & preg_4 == 3 & live_out_house_over18_tot == 1 & ich02_line == 3 & (live_then_died_over18_tot == 2 | live_in_house_over18_tot == 2) & still_alive == 1
replace okay_over18 = 1 if ich02 == 4 & preg_4 == 3 & live_out_house_over18_tot == 1 & ich02_line == 3 & ((live_then_died_over18_tot == 2 | live_in_house_over18_tot == 2) | (live_then_died_over18_tot == 1 & live_in_house_over18_tot == 1)) & still_alive != 1
replace okay_over18 = 1 if ich02 == 4 & preg_4 == 3 & live_out_house_over18_tot == 2 & ich02_line == 3 & (live_then_died_over18_tot == 1 | live_in_house_over18_tot == 1) & still_alive != 1



replace okay_18 = 1 if ich02 == 2 & preg_2 == 1 & ich02_line == 1 & miscarry_18_tot > 0 & miscarry_18_tot < .
replace okay_18 = 1 if ich02 == 2 & preg_2 == 2 & ich02_line <= 2 & miscarry_18_tot > 1 & miscarry_18_tot < .
replace okay_18 = 1 if ich02 == 3 & preg_3 == 1 & ich02_line == 1 & stillborn_18_tot > 0 & stillborn_18_tot < .
replace okay_18 = 1 if ich02 == 3 & preg_3 == 2 & ich02_line <= 2 & stillborn_18_tot > 1 & stillborn_18_tot < .
replace okay_18 = 1 if ich02 == 4 & preg_4 == 1 & ich02_line == 1 & live_then_died_18_tot > 0 & live_then_died_18_tot < . & still_alive != 1
replace okay_18 = 1 if ich02 == 4 & preg_4 == 2 & ich02_line <= 2 & live_then_died_18_tot > 1 & live_then_died_18_tot < . & still_alive != 1


replace okay_18_v2 = 1 if ich02 == 2 & preg_2 == 1 & ich02_line == 1 & miscarry_18_tot > 0 & miscarry_18_tot < .
replace okay_18_v2 = 1 if ich02 == 2 & preg_2 == 2 & ich02_line <= 2 & miscarry_18_tot > 1 & miscarry_18_tot < .

replace okay_over18 = 1 if ich02 == 2 & preg_2 == 1 & ich02_line == 3 & miscarry_over18_tot > 0 & miscarry_over18_tot < .
replace okay_over18 = 1 if ich02 == 2 & preg_2 == 2 & ich02_line >= 2 & miscarry_over18_tot > 1 & miscarry_over18_tot < .
replace okay_over18 = 1 if ich02 == 3 & preg_3 == 1 & ich02_line == 3 & stillborn_over18_tot > 0 & stillborn_over18_tot < .
replace okay_over18 = 1 if ich02 == 3 & preg_3 == 2 & ich02_line >= 2 & stillborn_over18_tot > 1 & stillborn_over18_tot < .
replace okay_over18 = 1 if ich02 == 4 & preg_4 == 1 & ich02_line == 3 & live_then_died_over18_tot > 0 & live_then_died_over18_tot < . & still_alive != 1
replace okay_over18 = 1 if ich02 == 4 & preg_4 == 1 & ich02_line >= 2 & live_then_died_over18_tot > 1 & live_then_died_over18_tot < . & still_alive != 1

replace okay_over18_v2 = 1 if ich02 == 2 & preg_2 == 1 & ich02_line == 3 & miscarry_over18_tot > 0 & miscarry_over18_tot < .
replace okay_over18_v2 = 1 if ich02 == 2 & preg_2 == 1 & ich02_line >= 2 & miscarry_over18_tot > 1 & miscarry_over18_tot < .



**Replacing some "."'s with "0"'s when we know that all the possible "1"'s for a mother have been allocated
bys iid: egen okay_sum = total(okay_18)
bys iid: egen okay_sum_v2 = total(okay_18_v2)

replace okay_18 = 0 if okay_18 == . & okay_sum == births_last18
replace okay_18_v2 = 0 if okay_18_v2 == . & okay_sum_v2 == births_last18


replace okay_18_alt = 0 if okay_18_alt == . & okay_18 == 0
replace okay_18_alt = 1 if okay_18_alt == . & okay_18 == 1

bys iid: egen okay_sum_alt = total(okay_18_alt)
tab okay_18_alt okay_18, m
//These 8 missings come cases where the different categories sum up to births_last18 >= births_last24 due to issue mentioned above, so in the _alt specification
//observations for which the specific category (_18) is missing (ex: live_then_died_18_tot == . but births_last18 = births_last24 due to other _18_tot being too high)


tab okay_18 okay_18_v2, m


//Can see that okay sum is equal to births_last18 in all cases except where we have births_last18 > births_last24, 
// or where we have the 8 cases from above, his makes sense since birth_last24 tallied from within I_CH
tab okay_sum births_last18, m
tab okay_sum_v2 births_last18, m
tab okay_sum_alt births_last18, m
tab births_last24 births_last18, m



**These all under 18 months
codebook birth_diff if okay_18 == 1 & okay_over18 != 1
codebook birth_diff if okay_18_v2 == 1 & okay_over18_v2 != 1
**These all over 18 months
codebook birth_diff if okay_over18 == 1 & okay_18 != 1
codebook birth_diff if okay_over18_v2 == 1 & okay_18_v2 != 1
**These all under 18 months
tab birth_diff if okay_18 == 1 & okay_over18 == 1
tab birth_diff if okay_18_v2 == 1 & okay_over18_v2 == 1

codebook birth_diff if okay_18 == .
codebook birth_diff if okay_18_v2 == .

replace okay_18 = 0 if birth_diff > 547.875 & birth_diff < . & okay_18 == .
replace okay_18 = 0 if birth_diff_mon > 18 & birth_diff_mon < . & okay_18 == .
replace okay_18_v2 = 0 if birth_diff > 547.875  & birth_diff < . & okay_18_v2 == .
replace okay_18_v2 = 0 if birth_diff_mon > 18 & birth_diff_mon < . & okay_18_v2 == .

replace okay_over18 = 0 if birth_diff <= 547.875 & okay_over18 == .
replace okay_over18 = 0 if birth_diff_mon <= 18 & okay_over18 == .
replace okay_over18_v2 = 0 if birth_diff <= 547.875 & okay_over18_v2 == .
replace okay_over18_v2 = 0 if birth_diff_mon <= 18 & okay_over18_v2 == .


tab okay_18 okay_18_v2, m
tab okay_over18 okay_over18_v2, m

tab okay_18 okay_over18,m
tab okay_18_v2 okay_over18_v2, m


keep if okay_18 == 1 | (okay_over18 != 1 & (ich02 == 2))


drop *_tot *_18* preg* tagx kid_in_house_merge kid_out_house_merge okay* _m* births* missing* kid *18_ind *24_ind *21_ind

sort iid
save births_18_okay_w3, replace


*******************************************************************************************************

//Now creating relevant variables on previous 18 months subset of pregnancies

********************************************************************************************************


//Recode nonmissing .'s as 0's 
foreach x of var ich08a ich08b ich08c ich08d ich08e ich08f ich08g ich08h ich08i ich08v ich10a ich10b ich10c ich10d ich10e ich10f ich10g ich10h ich10i ich10v ich12a ich12b ich12c ich12d ich12e ich12f ich12g ich12h ich12i ich12v{
replace `x'=0 if `x'==. & ich07!=.
}

//complications in pregnancy
g any_complications = 1 if ich27 == 3
replace any_complications = 0 if ich27 == 1


//Calculate total number of pre-natal visits
gen pre_natal_visits=0
foreach x of var ich08a ich08b ich08c ich08d ich08e ich08f ich08h ich08i ich08v ich10a ich10b ich10c ich10d ich10e ich10f ich10h ich10i ich10v ich12a ich12b ich12c ich12d ich12e ich12f ich12h ich12i ich12v{
	replace pre_natal_visits=pre_natal_visits+`x' if `x'<.
}
**Removing ich08g, ich10g, ich12g (dukun bayi) from the sum total

replace pre_natal_visits=. if ich07==.
replace pre_natal_visits = 20 if pre_natal_visits > 20 & pre_natal_visits < .

//Generate dummy for greater than/equal 4 pre-natal visits
gen pre_natal_dummy=1 if pre_natal_visits>=4 & pre_natal_visits<.
replace pre_natal_dummy=0 if pre_natal_visits<4


//Generate dummy variable for > 90 iron pills received during pregnancy 
gen iron_pills_dummy=1 if ich21==4
replace iron_pills_dummy=0 if ich21<4 | ich20 == 3

gen iron_pills_categ = ich21
replace iron_pills_categ = 0 if ich20 == 3
replace iron_pills_categ = .y if ich21 == 8
label define ironcat 0 "Did not receive any" 1 "1-30 pills" 2 "31-60 pills" 3 "61-90 pills" 4 ">90 pills" 8 "Do Not Know, but did receive" .y "Do Not Know, but did receive"
label values iron_pills_categ ironcat


//Generate dummy variable for delivery assisted by doctor or midwife
multparse ich25 dummy
gen good_assisted_delivery=1 if dummy_A==1 | dummy_B==1
replace good_assisted_delivery=0 if dummy_A!=1 & dummy_B!=1 & ich25!=""


//Recode nonmissing .'s as 0's
foreach x of var ich32a ich32b ich32c ich32d ich32e ich32f ich32g ich32h ich32i ich32v ich33a ich33b ich33c ich33d ich33e ich33f ich33g ich33h ich33i ich33v{
replace `x'=0 if `x'==. & ich31!=.
}


//Calculate total number of post-natal visits
gen post_natal_visits=0
foreach x of var ich32a ich32b ich32c ich32d ich32e ich32f ich32h ich32i ich32v ich33a ich33b ich33c ich33d ich33e ich33f ich33h ich33i ich33v{
	replace post_natal_visits=post_natal_visits+`x' if `x'<.
}
**Removing ich32g, ich33g (dukun bayi) from the sum total

replace post_natal_visits=. if ich31==.
replace post_natal_visits = 10 if post_natal_visits > 10 & post_natal_visits < .

//Generate dummy variable for >=2 post-natal visits
gen post_natal_dummy=1 if post_natal_visits>=2 & post_natal_visits<.
replace post_natal_dummy=0 if post_natal_visits<2 

//Explain missings
tab1 pre_natal_visits pre_natal_dummy, missing
tab iron_pills_dummy, missing 
tab ich20 iron_pills_dummy, missing
tab good_assisted_delivery, missing 
tab ich23 good_assisted_delivery, missing
tab1 post_natal_visits post_natal_dummy, missing 
tab ich23 post_natal_dummy, missing

sort iid
tempfile temp8
save `temp8'
clear

use Data\I


duplicates drop

sort iid
merge iid using `temp8', uniqmaster _merge(_merge2)
tab _merge2
keep if _merge2 == 3

//Generate variable for observation type (Married woman 16-49 years old == 1)
gen obs_type=6
label define obstype_label 6 "Married Woman 16-49 years old"
label values obs_type obstype_label



foreach x of var pre_natal_visits pre_natal_dummy  iron_pills_dummy iron_pills_categ good_assisted_delivery post_natal_visits post_natal_dummy{
	rename `x' `x'_w3
}

//Rename variables for consistency in future merges
gen id = iid
order id
drop iid

//Generating variables to look panel individuals across waves
gen rid= substr(id,1,3) + "1" + substr(id,5,9)
sort rid
tempfile temp
save `temp'

use Data\R, clear

duplicates drop

duplicates drop rid, force

gen panel_hh = (rar00x == 1 | rar00x == 2)
gen panel_hh_id_w3 = substr(rid, 1,3) + substr(rid,5,9)

keep rid panel_hh panel_hh_id_w3 rar00x
sort rid

merge rid using `temp', uniqmaster _merge(_mx)
tab _mx
keep if _mx == 3



//Generating Variables for identification to check in merges

gen hh_serial_no_w3 = icov1_cd


order id
sort id

tempfile temp
save `temp'

//Merging in age information
use Data\R_AR_01, clear
duplicates drop
tostring rar00, replace format(%02.0f)

gen id = substr(rid,1,3) + "2" + substr(rid,5,9) + rar00

//Replace missing days with 15 if neither month nor year values for children's birth dates missing
replace rar04_dd=15 if rar04_dd>=. & rar04_mm<. & rar04_yy<.

//Replace nonleap year February 29's with February 28's
replace rar04_dd=28 if rar04_dd==29 & rar04_mm==2 & rar04_yy!=2008 & rar04_yy!=2004 & rar04_yy!=2000 & rar04_yy!=1996 & rar04_yy!=1992 & rar04_yy!=1988 & rar04_yy!=1984 & rar04_yy!=1980 & rar04_yy!=1976 & rar04_yy!=1972 & rar04_yy!=1968 & rar04_yy!=1964 & rar04_yy!=1960 & rar04_yy!=1956 

keep id rar04_*
sort id

merge id using `temp', uniqmaster
tab _merge

keep if _merge == 3
drop _m*


//Generate birth dates
gen birth_date_mother=mdy(rar04_mm,rar04_dd,rar04_yy)

sort id
tempfile temp
save `temp'

use Data\I, clear


duplicates drop

rename iid id

//Generate survey dates
gen survey_start_day = substr(istart_d,1,2)
destring survey_start_day, replace 
gen survey_start_mon = substr(istart_d,4,2)
destring survey_start_mon, replace 
gen survey_start_year = substr(istart_d,7,2)
destring survey_start_year, replace 
replace survey_start_year = survey_start_year + 2000

gen survey_finish_day = substr(ifinish_d,1,2)
destring survey_finish_day, replace 
gen survey_finish_mon = substr(ifinish_d,4,2)
destring survey_finish_mon, replace 
gen survey_finish_year = substr(ifinish_d,7,2)
destring survey_finish_year, replace 
replace survey_finish_year = survey_finish_year + 2000

gen survey_start_date=	mdy(survey_start_mon, survey_start_day, survey_start_year) 
gen survey_finish_date=	mdy(survey_finish_mon, survey_finish_day, survey_finish_year)
gen survey_days_elapse = survey_finish_date - survey_start_date

summ survey_days_elapse, d

gen survey_date = survey_start_date
gen survey_month = ym(survey_start_year, survey_start_mon)
gen survey_year = survey_start_year 

drop survey_start* survey_finish*

gen panel_2007 = (icov3 == 1)
gen panel_2008 = (icov3 == 2)

keep id survey_date survey_year survey_month panel_2007 panel_2008

sort id
merge id using `temp', uniqmaster
tab _m
keep if _m == 3
drop _m

gen age = survey_date - birth_date_mother
gen age_years = floor(age/365.25)

sort id
tempfile temp2
save `temp2'

***

use Data\R_AR_01, clear
duplicates drop

tostring rar00_07 rar00, replace format(%02.0f)
gen id = substr(rid,1,3) + "2" + substr(rid,5,9) + rar00


keep rar00 rar00_07 rar01a id

sort id
merge id using `temp2', uniqmaster _merge(_ind_roster_info_merge)
tab _ind_roster_info_merge
keep if _ind_roster_info_merge == 3



gen panel_id_w3 = id
gen art_split = substr(id,12,2)

replace panel_id_w3 = substr(panel_id_w3,1,9) + "00" + "00" + rar00_07 if rar00_07 != "00" & rar00_07 != ""
sort panel_id_w3


compress
save marriedwoman16to49years_w3, replace


