clear
set more off

cd "Wave I"

cap log close
log using school_budget_vars, replace

******************
use Data\S, clear

gen SMP = (slk05 == 1 | slk05 == 2| slk05 == 3)

keep if SMP == 1

//Total budget for Student Year (APBS)
gen total_APBS = sag02
replace total_APBS = 0 if sag01 == 3

//Total Revenues
gen total_revs = sag04

//BOS Central Gov Revenues
gen BOS_central_revs = sag05a

//Non-BOS Central Gov Revenues
gen nonBOS_cent_revs = sag05b

//Provincial Revenues
gen prov_revs = sag06

//District Revenues
egen dist_revs = rowtotal(sag07a sag07b sag07c)
replace dist_revs = . if (sag07a >= . & sag07b >= . & sag07c >= .)

//Educational Foundation [private]
egen yaya_pendid = rowtotal(sag08a sag08b sag08c)
replace yaya_pendid = . if (sag08a >= . & sag08b >= . & sag08c >= .)

//Non-educational private institutions 
gen lembaga_swasta = sag09

//Parent Fees
egen parent_fees = rowtotal(sag10a sag10b sag10c sag10d)
replace parent_fees = . if (sag10a >= . & sag10b >= . & sag10c >= . & sag10d >= .)


//Other Sources
gen other_sources = sag11


//Expenses
gen BOS_expenses = sag25


keep sid total_APBS total_revs BOS_central_revs nonBOS_cent_revs prov_revs dist_revs yaya_pendid lembaga_swasta parent_fees other_sources BOS_expenses SMP
sort sid

tempfile revs_fees
save `revs_fees'

**
use Data\S_MSTYPE, clear

//Parent School Fees
gen reg_fee_x = sms10 if smstype == 1
gen re_reg_fee_x = sms10 if smstype == 2
gen oblig_contr_x = sms10 if smstype == 3
gen sem_exam_fee_x = sms10 if smstype == 4
gen fin_exam_fee_x = sms10 if smstype == 5

foreach y in reg_fee re_reg_fee oblig_contr sem_exam_fee fin_exam_fee{
	bys sid: egen `y' = max(`y'_x)
	drop `y'_x
}

keep sid reg_fee re_reg_fee oblig_contr sem_exam_fee fin_exam_fee
duplicates drop

egen par_sch_fees_tot = rowtotal(reg_fee re_reg_fee oblig_contr sem_exam_fee fin_exam_fee)
replace par_sch_fees_tot = . if (reg_fee >=. & re_reg_fee >= . & oblig_contr >= . & sem_exam_fee >= . & fin_exam_fee >= .)

sort sid

merge sid using `revs_fees', unique
tab _m
drop _m

foreach z of var reg_fee re_reg_fee oblig_contr sem_exam_fee fin_exam_fee par_sch_fees_tot total_APBS total_revs BOS_central_revs nonBOS_cent_revs prov_revs dist_revs yaya_pendid lembaga_swasta parent_fees other_sources BOS_expenses{
	replace `z' = log(`z') if `z' != 0
	gen `z'_SMP = `z' if SMP == 1
	drop `z'
	rename `z'_SMP `z'_SMP_w1
}

gen ea_code = substr(sid,1,3)
gen obs_type = 3

order sid ea_code *_w1 obs_type

label define obs_labelx 1 "Puskesmas" 2 "Bidan" 3 "School"
label values obs_type obs_labelx

save school_budget_vars_w1, replace

log close
